# Automatically generated by `_icons_generate_enum.py`
# See https://tabler-icons.io/
from typing import NewType

IconName = NewType("IconName", str)
"""Name of an icon. Should be generated via `viser.Icon.*`."""

class Icon:
    """'Enum' class for referencing Tabler icons.

    We don't subclass enum.Enum for performance reasons -- importing an enum with
    thousands of names can result in import times in the hundreds of milliseconds.
    """

    ICON_123: IconName = IconName("123")
    ICON_24_HOURS: IconName = IconName("24-hours")
    ICON_2FA: IconName = IconName("2fa")
    ICON_360: IconName = IconName("360")
    ICON_360_VIEW: IconName = IconName("360-view")
    ICON_3D_CUBE_SPHERE: IconName = IconName("3d-cube-sphere")
    ICON_3D_CUBE_SPHERE_OFF: IconName = IconName("3d-cube-sphere-off")
    ICON_3D_ROTATE: IconName = IconName("3d-rotate")
    A_B: IconName = IconName("a-b")
    A_B_2: IconName = IconName("a-b-2")
    A_B_OFF: IconName = IconName("a-b-off")
    ABACUS: IconName = IconName("abacus")
    ABACUS_OFF: IconName = IconName("abacus-off")
    ABC: IconName = IconName("abc")
    ACCESS_POINT: IconName = IconName("access-point")
    ACCESS_POINT_OFF: IconName = IconName("access-point-off")
    ACCESSIBLE: IconName = IconName("accessible")
    ACCESSIBLE_OFF: IconName = IconName("accessible-off")
    ACCESSIBLE_OFF_FILLED: IconName = IconName("accessible-off-filled")
    ACTIVITY: IconName = IconName("activity")
    ACTIVITY_HEARTBEAT: IconName = IconName("activity-heartbeat")
    AD: IconName = IconName("ad")
    AD_2: IconName = IconName("ad-2")
    AD_CIRCLE: IconName = IconName("ad-circle")
    AD_CIRCLE_FILLED: IconName = IconName("ad-circle-filled")
    AD_CIRCLE_OFF: IconName = IconName("ad-circle-off")
    AD_FILLED: IconName = IconName("ad-filled")
    AD_OFF: IconName = IconName("ad-off")
    ADDRESS_BOOK: IconName = IconName("address-book")
    ADDRESS_BOOK_OFF: IconName = IconName("address-book-off")
    ADJUSTMENTS: IconName = IconName("adjustments")
    ADJUSTMENTS_ALT: IconName = IconName("adjustments-alt")
    ADJUSTMENTS_BOLT: IconName = IconName("adjustments-bolt")
    ADJUSTMENTS_CANCEL: IconName = IconName("adjustments-cancel")
    ADJUSTMENTS_CHECK: IconName = IconName("adjustments-check")
    ADJUSTMENTS_CODE: IconName = IconName("adjustments-code")
    ADJUSTMENTS_COG: IconName = IconName("adjustments-cog")
    ADJUSTMENTS_DOLLAR: IconName = IconName("adjustments-dollar")
    ADJUSTMENTS_DOWN: IconName = IconName("adjustments-down")
    ADJUSTMENTS_EXCLAMATION: IconName = IconName("adjustments-exclamation")
    ADJUSTMENTS_FILLED: IconName = IconName("adjustments-filled")
    ADJUSTMENTS_HEART: IconName = IconName("adjustments-heart")
    ADJUSTMENTS_HORIZONTAL: IconName = IconName("adjustments-horizontal")
    ADJUSTMENTS_MINUS: IconName = IconName("adjustments-minus")
    ADJUSTMENTS_OFF: IconName = IconName("adjustments-off")
    ADJUSTMENTS_PAUSE: IconName = IconName("adjustments-pause")
    ADJUSTMENTS_PIN: IconName = IconName("adjustments-pin")
    ADJUSTMENTS_PLUS: IconName = IconName("adjustments-plus")
    ADJUSTMENTS_QUESTION: IconName = IconName("adjustments-question")
    ADJUSTMENTS_SEARCH: IconName = IconName("adjustments-search")
    ADJUSTMENTS_SHARE: IconName = IconName("adjustments-share")
    ADJUSTMENTS_STAR: IconName = IconName("adjustments-star")
    ADJUSTMENTS_UP: IconName = IconName("adjustments-up")
    ADJUSTMENTS_X: IconName = IconName("adjustments-x")
    AERIAL_LIFT: IconName = IconName("aerial-lift")
    AFFILIATE: IconName = IconName("affiliate")
    AFFILIATE_FILLED: IconName = IconName("affiliate-filled")
    AIR_BALLOON: IconName = IconName("air-balloon")
    AIR_CONDITIONING: IconName = IconName("air-conditioning")
    AIR_CONDITIONING_DISABLED: IconName = IconName("air-conditioning-disabled")
    ALARM: IconName = IconName("alarm")
    ALARM_FILLED: IconName = IconName("alarm-filled")
    ALARM_MINUS: IconName = IconName("alarm-minus")
    ALARM_MINUS_FILLED: IconName = IconName("alarm-minus-filled")
    ALARM_OFF: IconName = IconName("alarm-off")
    ALARM_PLUS: IconName = IconName("alarm-plus")
    ALARM_PLUS_FILLED: IconName = IconName("alarm-plus-filled")
    ALARM_SNOOZE: IconName = IconName("alarm-snooze")
    ALARM_SNOOZE_FILLED: IconName = IconName("alarm-snooze-filled")
    ALBUM: IconName = IconName("album")
    ALBUM_OFF: IconName = IconName("album-off")
    ALERT_CIRCLE: IconName = IconName("alert-circle")
    ALERT_CIRCLE_FILLED: IconName = IconName("alert-circle-filled")
    ALERT_HEXAGON: IconName = IconName("alert-hexagon")
    ALERT_HEXAGON_FILLED: IconName = IconName("alert-hexagon-filled")
    ALERT_OCTAGON: IconName = IconName("alert-octagon")
    ALERT_OCTAGON_FILLED: IconName = IconName("alert-octagon-filled")
    ALERT_SMALL: IconName = IconName("alert-small")
    ALERT_SQUARE: IconName = IconName("alert-square")
    ALERT_SQUARE_FILLED: IconName = IconName("alert-square-filled")
    ALERT_SQUARE_ROUNDED: IconName = IconName("alert-square-rounded")
    ALERT_SQUARE_ROUNDED_FILLED: IconName = IconName("alert-square-rounded-filled")
    ALERT_TRIANGLE: IconName = IconName("alert-triangle")
    ALERT_TRIANGLE_FILLED: IconName = IconName("alert-triangle-filled")
    ALIEN: IconName = IconName("alien")
    ALIEN_FILLED: IconName = IconName("alien-filled")
    ALIGN_BOX_BOTTOM_CENTER: IconName = IconName("align-box-bottom-center")
    ALIGN_BOX_BOTTOM_CENTER_FILLED: IconName = IconName(
        "align-box-bottom-center-filled"
    )
    ALIGN_BOX_BOTTOM_LEFT: IconName = IconName("align-box-bottom-left")
    ALIGN_BOX_BOTTOM_LEFT_FILLED: IconName = IconName("align-box-bottom-left-filled")
    ALIGN_BOX_BOTTOM_RIGHT: IconName = IconName("align-box-bottom-right")
    ALIGN_BOX_BOTTOM_RIGHT_FILLED: IconName = IconName("align-box-bottom-right-filled")
    ALIGN_BOX_CENTER_BOTTOM: IconName = IconName("align-box-center-bottom")
    ALIGN_BOX_CENTER_MIDDLE: IconName = IconName("align-box-center-middle")
    ALIGN_BOX_CENTER_MIDDLE_FILLED: IconName = IconName(
        "align-box-center-middle-filled"
    )
    ALIGN_BOX_CENTER_STRETCH: IconName = IconName("align-box-center-stretch")
    ALIGN_BOX_CENTER_TOP: IconName = IconName("align-box-center-top")
    ALIGN_BOX_LEFT_BOTTOM: IconName = IconName("align-box-left-bottom")
    ALIGN_BOX_LEFT_BOTTOM_FILLED: IconName = IconName("align-box-left-bottom-filled")
    ALIGN_BOX_LEFT_MIDDLE: IconName = IconName("align-box-left-middle")
    ALIGN_BOX_LEFT_MIDDLE_FILLED: IconName = IconName("align-box-left-middle-filled")
    ALIGN_BOX_LEFT_STRETCH: IconName = IconName("align-box-left-stretch")
    ALIGN_BOX_LEFT_TOP: IconName = IconName("align-box-left-top")
    ALIGN_BOX_LEFT_TOP_FILLED: IconName = IconName("align-box-left-top-filled")
    ALIGN_BOX_RIGHT_BOTTOM: IconName = IconName("align-box-right-bottom")
    ALIGN_BOX_RIGHT_BOTTOM_FILLED: IconName = IconName("align-box-right-bottom-filled")
    ALIGN_BOX_RIGHT_MIDDLE: IconName = IconName("align-box-right-middle")
    ALIGN_BOX_RIGHT_MIDDLE_FILLED: IconName = IconName("align-box-right-middle-filled")
    ALIGN_BOX_RIGHT_STRETCH: IconName = IconName("align-box-right-stretch")
    ALIGN_BOX_RIGHT_TOP: IconName = IconName("align-box-right-top")
    ALIGN_BOX_RIGHT_TOP_FILLED: IconName = IconName("align-box-right-top-filled")
    ALIGN_BOX_TOP_CENTER: IconName = IconName("align-box-top-center")
    ALIGN_BOX_TOP_CENTER_FILLED: IconName = IconName("align-box-top-center-filled")
    ALIGN_BOX_TOP_LEFT: IconName = IconName("align-box-top-left")
    ALIGN_BOX_TOP_LEFT_FILLED: IconName = IconName("align-box-top-left-filled")
    ALIGN_BOX_TOP_RIGHT: IconName = IconName("align-box-top-right")
    ALIGN_BOX_TOP_RIGHT_FILLED: IconName = IconName("align-box-top-right-filled")
    ALIGN_CENTER: IconName = IconName("align-center")
    ALIGN_JUSTIFIED: IconName = IconName("align-justified")
    ALIGN_LEFT: IconName = IconName("align-left")
    ALIGN_RIGHT: IconName = IconName("align-right")
    ALPHA: IconName = IconName("alpha")
    ALPHABET_CYRILLIC: IconName = IconName("alphabet-cyrillic")
    ALPHABET_GREEK: IconName = IconName("alphabet-greek")
    ALPHABET_LATIN: IconName = IconName("alphabet-latin")
    AMBULANCE: IconName = IconName("ambulance")
    AMPERSAND: IconName = IconName("ampersand")
    ANALYZE: IconName = IconName("analyze")
    ANALYZE_FILLED: IconName = IconName("analyze-filled")
    ANALYZE_OFF: IconName = IconName("analyze-off")
    ANCHOR: IconName = IconName("anchor")
    ANCHOR_OFF: IconName = IconName("anchor-off")
    ANGLE: IconName = IconName("angle")
    ANKH: IconName = IconName("ankh")
    ANTENNA: IconName = IconName("antenna")
    ANTENNA_BARS_1: IconName = IconName("antenna-bars-1")
    ANTENNA_BARS_2: IconName = IconName("antenna-bars-2")
    ANTENNA_BARS_3: IconName = IconName("antenna-bars-3")
    ANTENNA_BARS_4: IconName = IconName("antenna-bars-4")
    ANTENNA_BARS_5: IconName = IconName("antenna-bars-5")
    ANTENNA_BARS_OFF: IconName = IconName("antenna-bars-off")
    ANTENNA_OFF: IconName = IconName("antenna-off")
    APERTURE: IconName = IconName("aperture")
    APERTURE_OFF: IconName = IconName("aperture-off")
    API: IconName = IconName("api")
    API_APP: IconName = IconName("api-app")
    API_APP_OFF: IconName = IconName("api-app-off")
    API_OFF: IconName = IconName("api-off")
    APP_WINDOW: IconName = IconName("app-window")
    APP_WINDOW_FILLED: IconName = IconName("app-window-filled")
    APPLE: IconName = IconName("apple")
    APPS: IconName = IconName("apps")
    APPS_FILLED: IconName = IconName("apps-filled")
    APPS_OFF: IconName = IconName("apps-off")
    ARCHIVE: IconName = IconName("archive")
    ARCHIVE_FILLED: IconName = IconName("archive-filled")
    ARCHIVE_OFF: IconName = IconName("archive-off")
    ARMCHAIR: IconName = IconName("armchair")
    ARMCHAIR_2: IconName = IconName("armchair-2")
    ARMCHAIR_2_OFF: IconName = IconName("armchair-2-off")
    ARMCHAIR_OFF: IconName = IconName("armchair-off")
    ARROW_AUTOFIT_CONTENT: IconName = IconName("arrow-autofit-content")
    ARROW_AUTOFIT_CONTENT_FILLED: IconName = IconName("arrow-autofit-content-filled")
    ARROW_AUTOFIT_DOWN: IconName = IconName("arrow-autofit-down")
    ARROW_AUTOFIT_HEIGHT: IconName = IconName("arrow-autofit-height")
    ARROW_AUTOFIT_LEFT: IconName = IconName("arrow-autofit-left")
    ARROW_AUTOFIT_RIGHT: IconName = IconName("arrow-autofit-right")
    ARROW_AUTOFIT_UP: IconName = IconName("arrow-autofit-up")
    ARROW_AUTOFIT_WIDTH: IconName = IconName("arrow-autofit-width")
    ARROW_BACK: IconName = IconName("arrow-back")
    ARROW_BACK_UP: IconName = IconName("arrow-back-up")
    ARROW_BACK_UP_DOUBLE: IconName = IconName("arrow-back-up-double")
    ARROW_BADGE_DOWN: IconName = IconName("arrow-badge-down")
    ARROW_BADGE_DOWN_FILLED: IconName = IconName("arrow-badge-down-filled")
    ARROW_BADGE_LEFT: IconName = IconName("arrow-badge-left")
    ARROW_BADGE_LEFT_FILLED: IconName = IconName("arrow-badge-left-filled")
    ARROW_BADGE_RIGHT: IconName = IconName("arrow-badge-right")
    ARROW_BADGE_RIGHT_FILLED: IconName = IconName("arrow-badge-right-filled")
    ARROW_BADGE_UP: IconName = IconName("arrow-badge-up")
    ARROW_BADGE_UP_FILLED: IconName = IconName("arrow-badge-up-filled")
    ARROW_BAR_BOTH: IconName = IconName("arrow-bar-both")
    ARROW_BAR_DOWN: IconName = IconName("arrow-bar-down")
    ARROW_BAR_LEFT: IconName = IconName("arrow-bar-left")
    ARROW_BAR_RIGHT: IconName = IconName("arrow-bar-right")
    ARROW_BAR_TO_DOWN: IconName = IconName("arrow-bar-to-down")
    ARROW_BAR_TO_LEFT: IconName = IconName("arrow-bar-to-left")
    ARROW_BAR_TO_RIGHT: IconName = IconName("arrow-bar-to-right")
    ARROW_BAR_TO_UP: IconName = IconName("arrow-bar-to-up")
    ARROW_BAR_UP: IconName = IconName("arrow-bar-up")
    ARROW_BEAR_LEFT: IconName = IconName("arrow-bear-left")
    ARROW_BEAR_LEFT_2: IconName = IconName("arrow-bear-left-2")
    ARROW_BEAR_RIGHT: IconName = IconName("arrow-bear-right")
    ARROW_BEAR_RIGHT_2: IconName = IconName("arrow-bear-right-2")
    ARROW_BIG_DOWN: IconName = IconName("arrow-big-down")
    ARROW_BIG_DOWN_FILLED: IconName = IconName("arrow-big-down-filled")
    ARROW_BIG_DOWN_LINE: IconName = IconName("arrow-big-down-line")
    ARROW_BIG_DOWN_LINE_FILLED: IconName = IconName("arrow-big-down-line-filled")
    ARROW_BIG_DOWN_LINES: IconName = IconName("arrow-big-down-lines")
    ARROW_BIG_DOWN_LINES_FILLED: IconName = IconName("arrow-big-down-lines-filled")
    ARROW_BIG_LEFT: IconName = IconName("arrow-big-left")
    ARROW_BIG_LEFT_FILLED: IconName = IconName("arrow-big-left-filled")
    ARROW_BIG_LEFT_LINE: IconName = IconName("arrow-big-left-line")
    ARROW_BIG_LEFT_LINE_FILLED: IconName = IconName("arrow-big-left-line-filled")
    ARROW_BIG_LEFT_LINES: IconName = IconName("arrow-big-left-lines")
    ARROW_BIG_LEFT_LINES_FILLED: IconName = IconName("arrow-big-left-lines-filled")
    ARROW_BIG_RIGHT: IconName = IconName("arrow-big-right")
    ARROW_BIG_RIGHT_FILLED: IconName = IconName("arrow-big-right-filled")
    ARROW_BIG_RIGHT_LINE: IconName = IconName("arrow-big-right-line")
    ARROW_BIG_RIGHT_LINE_FILLED: IconName = IconName("arrow-big-right-line-filled")
    ARROW_BIG_RIGHT_LINES: IconName = IconName("arrow-big-right-lines")
    ARROW_BIG_RIGHT_LINES_FILLED: IconName = IconName("arrow-big-right-lines-filled")
    ARROW_BIG_UP: IconName = IconName("arrow-big-up")
    ARROW_BIG_UP_FILLED: IconName = IconName("arrow-big-up-filled")
    ARROW_BIG_UP_LINE: IconName = IconName("arrow-big-up-line")
    ARROW_BIG_UP_LINE_FILLED: IconName = IconName("arrow-big-up-line-filled")
    ARROW_BIG_UP_LINES: IconName = IconName("arrow-big-up-lines")
    ARROW_BIG_UP_LINES_FILLED: IconName = IconName("arrow-big-up-lines-filled")
    ARROW_BOUNCE: IconName = IconName("arrow-bounce")
    ARROW_CAPSULE: IconName = IconName("arrow-capsule")
    ARROW_CURVE_LEFT: IconName = IconName("arrow-curve-left")
    ARROW_CURVE_RIGHT: IconName = IconName("arrow-curve-right")
    ARROW_DOWN: IconName = IconName("arrow-down")
    ARROW_DOWN_BAR: IconName = IconName("arrow-down-bar")
    ARROW_DOWN_CIRCLE: IconName = IconName("arrow-down-circle")
    ARROW_DOWN_LEFT: IconName = IconName("arrow-down-left")
    ARROW_DOWN_LEFT_CIRCLE: IconName = IconName("arrow-down-left-circle")
    ARROW_DOWN_RHOMBUS: IconName = IconName("arrow-down-rhombus")
    ARROW_DOWN_RIGHT: IconName = IconName("arrow-down-right")
    ARROW_DOWN_RIGHT_CIRCLE: IconName = IconName("arrow-down-right-circle")
    ARROW_DOWN_SQUARE: IconName = IconName("arrow-down-square")
    ARROW_DOWN_TAIL: IconName = IconName("arrow-down-tail")
    ARROW_ELBOW_LEFT: IconName = IconName("arrow-elbow-left")
    ARROW_ELBOW_RIGHT: IconName = IconName("arrow-elbow-right")
    ARROW_FORK: IconName = IconName("arrow-fork")
    ARROW_FORWARD: IconName = IconName("arrow-forward")
    ARROW_FORWARD_UP: IconName = IconName("arrow-forward-up")
    ARROW_FORWARD_UP_DOUBLE: IconName = IconName("arrow-forward-up-double")
    ARROW_GUIDE: IconName = IconName("arrow-guide")
    ARROW_ITERATION: IconName = IconName("arrow-iteration")
    ARROW_LEFT: IconName = IconName("arrow-left")
    ARROW_LEFT_BAR: IconName = IconName("arrow-left-bar")
    ARROW_LEFT_CIRCLE: IconName = IconName("arrow-left-circle")
    ARROW_LEFT_RHOMBUS: IconName = IconName("arrow-left-rhombus")
    ARROW_LEFT_RIGHT: IconName = IconName("arrow-left-right")
    ARROW_LEFT_SQUARE: IconName = IconName("arrow-left-square")
    ARROW_LEFT_TAIL: IconName = IconName("arrow-left-tail")
    ARROW_LOOP_LEFT: IconName = IconName("arrow-loop-left")
    ARROW_LOOP_LEFT_2: IconName = IconName("arrow-loop-left-2")
    ARROW_LOOP_RIGHT: IconName = IconName("arrow-loop-right")
    ARROW_LOOP_RIGHT_2: IconName = IconName("arrow-loop-right-2")
    ARROW_MERGE: IconName = IconName("arrow-merge")
    ARROW_MERGE_BOTH: IconName = IconName("arrow-merge-both")
    ARROW_MERGE_LEFT: IconName = IconName("arrow-merge-left")
    ARROW_MERGE_RIGHT: IconName = IconName("arrow-merge-right")
    ARROW_MOVE_DOWN: IconName = IconName("arrow-move-down")
    ARROW_MOVE_LEFT: IconName = IconName("arrow-move-left")
    ARROW_MOVE_RIGHT: IconName = IconName("arrow-move-right")
    ARROW_MOVE_UP: IconName = IconName("arrow-move-up")
    ARROW_NARROW_DOWN: IconName = IconName("arrow-narrow-down")
    ARROW_NARROW_LEFT: IconName = IconName("arrow-narrow-left")
    ARROW_NARROW_RIGHT: IconName = IconName("arrow-narrow-right")
    ARROW_NARROW_UP: IconName = IconName("arrow-narrow-up")
    ARROW_RAMP_LEFT: IconName = IconName("arrow-ramp-left")
    ARROW_RAMP_LEFT_2: IconName = IconName("arrow-ramp-left-2")
    ARROW_RAMP_LEFT_3: IconName = IconName("arrow-ramp-left-3")
    ARROW_RAMP_RIGHT: IconName = IconName("arrow-ramp-right")
    ARROW_RAMP_RIGHT_2: IconName = IconName("arrow-ramp-right-2")
    ARROW_RAMP_RIGHT_3: IconName = IconName("arrow-ramp-right-3")
    ARROW_RIGHT: IconName = IconName("arrow-right")
    ARROW_RIGHT_BAR: IconName = IconName("arrow-right-bar")
    ARROW_RIGHT_CIRCLE: IconName = IconName("arrow-right-circle")
    ARROW_RIGHT_RHOMBUS: IconName = IconName("arrow-right-rhombus")
    ARROW_RIGHT_SQUARE: IconName = IconName("arrow-right-square")
    ARROW_RIGHT_TAIL: IconName = IconName("arrow-right-tail")
    ARROW_ROTARY_FIRST_LEFT: IconName = IconName("arrow-rotary-first-left")
    ARROW_ROTARY_FIRST_RIGHT: IconName = IconName("arrow-rotary-first-right")
    ARROW_ROTARY_LAST_LEFT: IconName = IconName("arrow-rotary-last-left")
    ARROW_ROTARY_LAST_RIGHT: IconName = IconName("arrow-rotary-last-right")
    ARROW_ROTARY_LEFT: IconName = IconName("arrow-rotary-left")
    ARROW_ROTARY_RIGHT: IconName = IconName("arrow-rotary-right")
    ARROW_ROTARY_STRAIGHT: IconName = IconName("arrow-rotary-straight")
    ARROW_ROUNDABOUT_LEFT: IconName = IconName("arrow-roundabout-left")
    ARROW_ROUNDABOUT_RIGHT: IconName = IconName("arrow-roundabout-right")
    ARROW_SHARP_TURN_LEFT: IconName = IconName("arrow-sharp-turn-left")
    ARROW_SHARP_TURN_RIGHT: IconName = IconName("arrow-sharp-turn-right")
    ARROW_UP: IconName = IconName("arrow-up")
    ARROW_UP_BAR: IconName = IconName("arrow-up-bar")
    ARROW_UP_CIRCLE: IconName = IconName("arrow-up-circle")
    ARROW_UP_LEFT: IconName = IconName("arrow-up-left")
    ARROW_UP_LEFT_CIRCLE: IconName = IconName("arrow-up-left-circle")
    ARROW_UP_RHOMBUS: IconName = IconName("arrow-up-rhombus")
    ARROW_UP_RIGHT: IconName = IconName("arrow-up-right")
    ARROW_UP_RIGHT_CIRCLE: IconName = IconName("arrow-up-right-circle")
    ARROW_UP_SQUARE: IconName = IconName("arrow-up-square")
    ARROW_UP_TAIL: IconName = IconName("arrow-up-tail")
    ARROW_WAVE_LEFT_DOWN: IconName = IconName("arrow-wave-left-down")
    ARROW_WAVE_LEFT_UP: IconName = IconName("arrow-wave-left-up")
    ARROW_WAVE_RIGHT_DOWN: IconName = IconName("arrow-wave-right-down")
    ARROW_WAVE_RIGHT_UP: IconName = IconName("arrow-wave-right-up")
    ARROW_ZIG_ZAG: IconName = IconName("arrow-zig-zag")
    ARROWS_CROSS: IconName = IconName("arrows-cross")
    ARROWS_DIAGONAL: IconName = IconName("arrows-diagonal")
    ARROWS_DIAGONAL_2: IconName = IconName("arrows-diagonal-2")
    ARROWS_DIAGONAL_MINIMIZE: IconName = IconName("arrows-diagonal-minimize")
    ARROWS_DIAGONAL_MINIMIZE_2: IconName = IconName("arrows-diagonal-minimize-2")
    ARROWS_DIFF: IconName = IconName("arrows-diff")
    ARROWS_DOUBLE_NE_SW: IconName = IconName("arrows-double-ne-sw")
    ARROWS_DOUBLE_NW_SE: IconName = IconName("arrows-double-nw-se")
    ARROWS_DOUBLE_SE_NW: IconName = IconName("arrows-double-se-nw")
    ARROWS_DOUBLE_SW_NE: IconName = IconName("arrows-double-sw-ne")
    ARROWS_DOWN: IconName = IconName("arrows-down")
    ARROWS_DOWN_UP: IconName = IconName("arrows-down-up")
    ARROWS_EXCHANGE: IconName = IconName("arrows-exchange")
    ARROWS_EXCHANGE_2: IconName = IconName("arrows-exchange-2")
    ARROWS_HORIZONTAL: IconName = IconName("arrows-horizontal")
    ARROWS_JOIN: IconName = IconName("arrows-join")
    ARROWS_JOIN_2: IconName = IconName("arrows-join-2")
    ARROWS_LEFT: IconName = IconName("arrows-left")
    ARROWS_LEFT_DOWN: IconName = IconName("arrows-left-down")
    ARROWS_LEFT_RIGHT: IconName = IconName("arrows-left-right")
    ARROWS_MAXIMIZE: IconName = IconName("arrows-maximize")
    ARROWS_MINIMIZE: IconName = IconName("arrows-minimize")
    ARROWS_MOVE: IconName = IconName("arrows-move")
    ARROWS_MOVE_HORIZONTAL: IconName = IconName("arrows-move-horizontal")
    ARROWS_MOVE_VERTICAL: IconName = IconName("arrows-move-vertical")
    ARROWS_RANDOM: IconName = IconName("arrows-random")
    ARROWS_RIGHT: IconName = IconName("arrows-right")
    ARROWS_RIGHT_DOWN: IconName = IconName("arrows-right-down")
    ARROWS_RIGHT_LEFT: IconName = IconName("arrows-right-left")
    ARROWS_SHUFFLE: IconName = IconName("arrows-shuffle")
    ARROWS_SHUFFLE_2: IconName = IconName("arrows-shuffle-2")
    ARROWS_SORT: IconName = IconName("arrows-sort")
    ARROWS_SPLIT: IconName = IconName("arrows-split")
    ARROWS_SPLIT_2: IconName = IconName("arrows-split-2")
    ARROWS_TRANSFER_DOWN: IconName = IconName("arrows-transfer-down")
    ARROWS_TRANSFER_UP: IconName = IconName("arrows-transfer-up")
    ARROWS_UP: IconName = IconName("arrows-up")
    ARROWS_UP_DOWN: IconName = IconName("arrows-up-down")
    ARROWS_UP_LEFT: IconName = IconName("arrows-up-left")
    ARROWS_UP_RIGHT: IconName = IconName("arrows-up-right")
    ARROWS_VERTICAL: IconName = IconName("arrows-vertical")
    ARTBOARD: IconName = IconName("artboard")
    ARTBOARD_FILLED: IconName = IconName("artboard-filled")
    ARTBOARD_OFF: IconName = IconName("artboard-off")
    ARTICLE: IconName = IconName("article")
    ARTICLE_FILLED_FILLED: IconName = IconName("article-filled-filled")
    ARTICLE_OFF: IconName = IconName("article-off")
    ASPECT_RATIO: IconName = IconName("aspect-ratio")
    ASPECT_RATIO_FILLED: IconName = IconName("aspect-ratio-filled")
    ASPECT_RATIO_OFF: IconName = IconName("aspect-ratio-off")
    ASSEMBLY: IconName = IconName("assembly")
    ASSEMBLY_OFF: IconName = IconName("assembly-off")
    ASSET: IconName = IconName("asset")
    ASTERISK: IconName = IconName("asterisk")
    ASTERISK_SIMPLE: IconName = IconName("asterisk-simple")
    AT: IconName = IconName("at")
    AT_OFF: IconName = IconName("at-off")
    ATOM: IconName = IconName("atom")
    ATOM_2: IconName = IconName("atom-2")
    ATOM_2_FILLED: IconName = IconName("atom-2-filled")
    ATOM_OFF: IconName = IconName("atom-off")
    AUGMENTED_REALITY: IconName = IconName("augmented-reality")
    AUGMENTED_REALITY_2: IconName = IconName("augmented-reality-2")
    AUGMENTED_REALITY_OFF: IconName = IconName("augmented-reality-off")
    AWARD: IconName = IconName("award")
    AWARD_FILLED: IconName = IconName("award-filled")
    AWARD_OFF: IconName = IconName("award-off")
    AXE: IconName = IconName("axe")
    AXIS_X: IconName = IconName("axis-x")
    AXIS_Y: IconName = IconName("axis-y")
    BABY_BOTTLE: IconName = IconName("baby-bottle")
    BABY_CARRIAGE: IconName = IconName("baby-carriage")
    BACKHOE: IconName = IconName("backhoe")
    BACKPACK: IconName = IconName("backpack")
    BACKPACK_OFF: IconName = IconName("backpack-off")
    BACKSLASH: IconName = IconName("backslash")
    BACKSPACE: IconName = IconName("backspace")
    BACKSPACE_FILLED: IconName = IconName("backspace-filled")
    BADGE: IconName = IconName("badge")
    BADGE_3D: IconName = IconName("badge-3d")
    BADGE_4K: IconName = IconName("badge-4k")
    BADGE_8K: IconName = IconName("badge-8k")
    BADGE_AD: IconName = IconName("badge-ad")
    BADGE_AR: IconName = IconName("badge-ar")
    BADGE_CC: IconName = IconName("badge-cc")
    BADGE_FILLED: IconName = IconName("badge-filled")
    BADGE_HD: IconName = IconName("badge-hd")
    BADGE_OFF: IconName = IconName("badge-off")
    BADGE_SD: IconName = IconName("badge-sd")
    BADGE_TM: IconName = IconName("badge-tm")
    BADGE_VO: IconName = IconName("badge-vo")
    BADGE_VR: IconName = IconName("badge-vr")
    BADGE_WC: IconName = IconName("badge-wc")
    BADGES: IconName = IconName("badges")
    BADGES_FILLED: IconName = IconName("badges-filled")
    BADGES_OFF: IconName = IconName("badges-off")
    BAGUETTE: IconName = IconName("baguette")
    BALL_AMERICAN_FOOTBALL: IconName = IconName("ball-american-football")
    BALL_AMERICAN_FOOTBALL_OFF: IconName = IconName("ball-american-football-off")
    BALL_BASEBALL: IconName = IconName("ball-baseball")
    BALL_BASKETBALL: IconName = IconName("ball-basketball")
    BALL_BOWLING: IconName = IconName("ball-bowling")
    BALL_FOOTBALL: IconName = IconName("ball-football")
    BALL_FOOTBALL_OFF: IconName = IconName("ball-football-off")
    BALL_TENNIS: IconName = IconName("ball-tennis")
    BALL_VOLLEYBALL: IconName = IconName("ball-volleyball")
    BALLOON: IconName = IconName("balloon")
    BALLOON_FILLED: IconName = IconName("balloon-filled")
    BALLOON_OFF: IconName = IconName("balloon-off")
    BALLPEN: IconName = IconName("ballpen")
    BALLPEN_FILLED: IconName = IconName("ballpen-filled")
    BALLPEN_OFF: IconName = IconName("ballpen-off")
    BAN: IconName = IconName("ban")
    BANDAGE: IconName = IconName("bandage")
    BANDAGE_FILLED: IconName = IconName("bandage-filled")
    BANDAGE_OFF: IconName = IconName("bandage-off")
    BARBELL: IconName = IconName("barbell")
    BARBELL_OFF: IconName = IconName("barbell-off")
    BARCODE: IconName = IconName("barcode")
    BARCODE_OFF: IconName = IconName("barcode-off")
    BARREL: IconName = IconName("barrel")
    BARREL_OFF: IconName = IconName("barrel-off")
    BARRIER_BLOCK: IconName = IconName("barrier-block")
    BARRIER_BLOCK_OFF: IconName = IconName("barrier-block-off")
    BASELINE: IconName = IconName("baseline")
    BASELINE_DENSITY_LARGE: IconName = IconName("baseline-density-large")
    BASELINE_DENSITY_MEDIUM: IconName = IconName("baseline-density-medium")
    BASELINE_DENSITY_SMALL: IconName = IconName("baseline-density-small")
    BASKET: IconName = IconName("basket")
    BASKET_FILLED: IconName = IconName("basket-filled")
    BASKET_OFF: IconName = IconName("basket-off")
    BAT: IconName = IconName("bat")
    BATH: IconName = IconName("bath")
    BATH_FILLED: IconName = IconName("bath-filled")
    BATH_OFF: IconName = IconName("bath-off")
    BATTERY: IconName = IconName("battery")
    BATTERY_1: IconName = IconName("battery-1")
    BATTERY_1_FILLED: IconName = IconName("battery-1-filled")
    BATTERY_2: IconName = IconName("battery-2")
    BATTERY_2_FILLED: IconName = IconName("battery-2-filled")
    BATTERY_3: IconName = IconName("battery-3")
    BATTERY_3_FILLED: IconName = IconName("battery-3-filled")
    BATTERY_4: IconName = IconName("battery-4")
    BATTERY_4_FILLED: IconName = IconName("battery-4-filled")
    BATTERY_AUTOMOTIVE: IconName = IconName("battery-automotive")
    BATTERY_CHARGING: IconName = IconName("battery-charging")
    BATTERY_CHARGING_2: IconName = IconName("battery-charging-2")
    BATTERY_ECO: IconName = IconName("battery-eco")
    BATTERY_FILLED: IconName = IconName("battery-filled")
    BATTERY_OFF: IconName = IconName("battery-off")
    BEACH: IconName = IconName("beach")
    BEACH_OFF: IconName = IconName("beach-off")
    BED: IconName = IconName("bed")
    BED_FILLED: IconName = IconName("bed-filled")
    BED_OFF: IconName = IconName("bed-off")
    BEER: IconName = IconName("beer")
    BEER_FILLED: IconName = IconName("beer-filled")
    BEER_OFF: IconName = IconName("beer-off")
    BELL: IconName = IconName("bell")
    BELL_BOLT: IconName = IconName("bell-bolt")
    BELL_CANCEL: IconName = IconName("bell-cancel")
    BELL_CHECK: IconName = IconName("bell-check")
    BELL_CODE: IconName = IconName("bell-code")
    BELL_COG: IconName = IconName("bell-cog")
    BELL_DOLLAR: IconName = IconName("bell-dollar")
    BELL_DOWN: IconName = IconName("bell-down")
    BELL_EXCLAMATION: IconName = IconName("bell-exclamation")
    BELL_FILLED: IconName = IconName("bell-filled")
    BELL_HEART: IconName = IconName("bell-heart")
    BELL_MINUS: IconName = IconName("bell-minus")
    BELL_MINUS_FILLED: IconName = IconName("bell-minus-filled")
    BELL_OFF: IconName = IconName("bell-off")
    BELL_PAUSE: IconName = IconName("bell-pause")
    BELL_PIN: IconName = IconName("bell-pin")
    BELL_PLUS: IconName = IconName("bell-plus")
    BELL_PLUS_FILLED: IconName = IconName("bell-plus-filled")
    BELL_QUESTION: IconName = IconName("bell-question")
    BELL_RINGING: IconName = IconName("bell-ringing")
    BELL_RINGING_2: IconName = IconName("bell-ringing-2")
    BELL_RINGING_2_FILLED: IconName = IconName("bell-ringing-2-filled")
    BELL_RINGING_FILLED: IconName = IconName("bell-ringing-filled")
    BELL_SCHOOL: IconName = IconName("bell-school")
    BELL_SEARCH: IconName = IconName("bell-search")
    BELL_SHARE: IconName = IconName("bell-share")
    BELL_STAR: IconName = IconName("bell-star")
    BELL_UP: IconName = IconName("bell-up")
    BELL_X: IconName = IconName("bell-x")
    BELL_X_FILLED: IconName = IconName("bell-x-filled")
    BELL_Z: IconName = IconName("bell-z")
    BELL_Z_FILLED: IconName = IconName("bell-z-filled")
    BETA: IconName = IconName("beta")
    BIBLE: IconName = IconName("bible")
    BIKE: IconName = IconName("bike")
    BIKE_OFF: IconName = IconName("bike-off")
    BINARY: IconName = IconName("binary")
    BINARY_OFF: IconName = IconName("binary-off")
    BINARY_TREE: IconName = IconName("binary-tree")
    BINARY_TREE_2: IconName = IconName("binary-tree-2")
    BIOHAZARD: IconName = IconName("biohazard")
    BIOHAZARD_OFF: IconName = IconName("biohazard-off")
    BLADE: IconName = IconName("blade")
    BLADE_FILLED: IconName = IconName("blade-filled")
    BLEACH: IconName = IconName("bleach")
    BLEACH_CHLORINE: IconName = IconName("bleach-chlorine")
    BLEACH_NO_CHLORINE: IconName = IconName("bleach-no-chlorine")
    BLEACH_OFF: IconName = IconName("bleach-off")
    BLOCKQUOTE: IconName = IconName("blockquote")
    BLUETOOTH: IconName = IconName("bluetooth")
    BLUETOOTH_CONNECTED: IconName = IconName("bluetooth-connected")
    BLUETOOTH_OFF: IconName = IconName("bluetooth-off")
    BLUETOOTH_X: IconName = IconName("bluetooth-x")
    BLUR: IconName = IconName("blur")
    BLUR_OFF: IconName = IconName("blur-off")
    BMP: IconName = IconName("bmp")
    BOLD: IconName = IconName("bold")
    BOLD_OFF: IconName = IconName("bold-off")
    BOLT: IconName = IconName("bolt")
    BOLT_OFF: IconName = IconName("bolt-off")
    BOMB: IconName = IconName("bomb")
    BOMB_FILLED: IconName = IconName("bomb-filled")
    BONE: IconName = IconName("bone")
    BONE_OFF: IconName = IconName("bone-off")
    BONG: IconName = IconName("bong")
    BONG_OFF: IconName = IconName("bong-off")
    BOOK: IconName = IconName("book")
    BOOK_2: IconName = IconName("book-2")
    BOOK_DOWNLOAD: IconName = IconName("book-download")
    BOOK_FILLED: IconName = IconName("book-filled")
    BOOK_OFF: IconName = IconName("book-off")
    BOOK_UPLOAD: IconName = IconName("book-upload")
    BOOKMARK: IconName = IconName("bookmark")
    BOOKMARK_EDIT: IconName = IconName("bookmark-edit")
    BOOKMARK_FILLED: IconName = IconName("bookmark-filled")
    BOOKMARK_MINUS: IconName = IconName("bookmark-minus")
    BOOKMARK_OFF: IconName = IconName("bookmark-off")
    BOOKMARK_PLUS: IconName = IconName("bookmark-plus")
    BOOKMARK_QUESTION: IconName = IconName("bookmark-question")
    BOOKMARKS: IconName = IconName("bookmarks")
    BOOKMARKS_OFF: IconName = IconName("bookmarks-off")
    BOOKS: IconName = IconName("books")
    BOOKS_OFF: IconName = IconName("books-off")
    BORDER_ALL: IconName = IconName("border-all")
    BORDER_BOTTOM: IconName = IconName("border-bottom")
    BORDER_CORNERS: IconName = IconName("border-corners")
    BORDER_HORIZONTAL: IconName = IconName("border-horizontal")
    BORDER_INNER: IconName = IconName("border-inner")
    BORDER_LEFT: IconName = IconName("border-left")
    BORDER_NONE: IconName = IconName("border-none")
    BORDER_OUTER: IconName = IconName("border-outer")
    BORDER_RADIUS: IconName = IconName("border-radius")
    BORDER_RIGHT: IconName = IconName("border-right")
    BORDER_SIDES: IconName = IconName("border-sides")
    BORDER_STYLE: IconName = IconName("border-style")
    BORDER_STYLE_2: IconName = IconName("border-style-2")
    BORDER_TOP: IconName = IconName("border-top")
    BORDER_VERTICAL: IconName = IconName("border-vertical")
    BOTTLE: IconName = IconName("bottle")
    BOTTLE_FILLED: IconName = IconName("bottle-filled")
    BOTTLE_OFF: IconName = IconName("bottle-off")
    BOUNCE_LEFT: IconName = IconName("bounce-left")
    BOUNCE_RIGHT: IconName = IconName("bounce-right")
    BOW: IconName = IconName("bow")
    BOWL: IconName = IconName("bowl")
    BOX: IconName = IconName("box")
    BOX_ALIGN_BOTTOM: IconName = IconName("box-align-bottom")
    BOX_ALIGN_BOTTOM_FILLED: IconName = IconName("box-align-bottom-filled")
    BOX_ALIGN_BOTTOM_LEFT: IconName = IconName("box-align-bottom-left")
    BOX_ALIGN_BOTTOM_LEFT_FILLED: IconName = IconName("box-align-bottom-left-filled")
    BOX_ALIGN_BOTTOM_RIGHT: IconName = IconName("box-align-bottom-right")
    BOX_ALIGN_BOTTOM_RIGHT_FILLED: IconName = IconName("box-align-bottom-right-filled")
    BOX_ALIGN_LEFT: IconName = IconName("box-align-left")
    BOX_ALIGN_LEFT_FILLED: IconName = IconName("box-align-left-filled")
    BOX_ALIGN_RIGHT: IconName = IconName("box-align-right")
    BOX_ALIGN_RIGHT_FILLED: IconName = IconName("box-align-right-filled")
    BOX_ALIGN_TOP: IconName = IconName("box-align-top")
    BOX_ALIGN_TOP_FILLED: IconName = IconName("box-align-top-filled")
    BOX_ALIGN_TOP_LEFT: IconName = IconName("box-align-top-left")
    BOX_ALIGN_TOP_LEFT_FILLED: IconName = IconName("box-align-top-left-filled")
    BOX_ALIGN_TOP_RIGHT: IconName = IconName("box-align-top-right")
    BOX_ALIGN_TOP_RIGHT_FILLED: IconName = IconName("box-align-top-right-filled")
    BOX_MARGIN: IconName = IconName("box-margin")
    BOX_MODEL: IconName = IconName("box-model")
    BOX_MODEL_2: IconName = IconName("box-model-2")
    BOX_MODEL_2_OFF: IconName = IconName("box-model-2-off")
    BOX_MODEL_OFF: IconName = IconName("box-model-off")
    BOX_MULTIPLE: IconName = IconName("box-multiple")
    BOX_MULTIPLE_0: IconName = IconName("box-multiple-0")
    BOX_MULTIPLE_1: IconName = IconName("box-multiple-1")
    BOX_MULTIPLE_2: IconName = IconName("box-multiple-2")
    BOX_MULTIPLE_3: IconName = IconName("box-multiple-3")
    BOX_MULTIPLE_4: IconName = IconName("box-multiple-4")
    BOX_MULTIPLE_5: IconName = IconName("box-multiple-5")
    BOX_MULTIPLE_6: IconName = IconName("box-multiple-6")
    BOX_MULTIPLE_7: IconName = IconName("box-multiple-7")
    BOX_MULTIPLE_8: IconName = IconName("box-multiple-8")
    BOX_MULTIPLE_9: IconName = IconName("box-multiple-9")
    BOX_OFF: IconName = IconName("box-off")
    BOX_PADDING: IconName = IconName("box-padding")
    BOX_SEAM: IconName = IconName("box-seam")
    BRACES: IconName = IconName("braces")
    BRACES_OFF: IconName = IconName("braces-off")
    BRACKETS: IconName = IconName("brackets")
    BRACKETS_CONTAIN: IconName = IconName("brackets-contain")
    BRACKETS_CONTAIN_END: IconName = IconName("brackets-contain-end")
    BRACKETS_CONTAIN_START: IconName = IconName("brackets-contain-start")
    BRACKETS_OFF: IconName = IconName("brackets-off")
    BRAILLE: IconName = IconName("braille")
    BRAIN: IconName = IconName("brain")
    BRAND_4CHAN: IconName = IconName("brand-4chan")
    BRAND_ABSTRACT: IconName = IconName("brand-abstract")
    BRAND_ADOBE: IconName = IconName("brand-adobe")
    BRAND_ADONIS_JS: IconName = IconName("brand-adonis-js")
    BRAND_AIRBNB: IconName = IconName("brand-airbnb")
    BRAND_AIRTABLE: IconName = IconName("brand-airtable")
    BRAND_ALGOLIA: IconName = IconName("brand-algolia")
    BRAND_ALIPAY: IconName = IconName("brand-alipay")
    BRAND_ALPINE_JS: IconName = IconName("brand-alpine-js")
    BRAND_AMAZON: IconName = IconName("brand-amazon")
    BRAND_AMD: IconName = IconName("brand-amd")
    BRAND_AMIGO: IconName = IconName("brand-amigo")
    BRAND_AMONG_US: IconName = IconName("brand-among-us")
    BRAND_ANDROID: IconName = IconName("brand-android")
    BRAND_ANGULAR: IconName = IconName("brand-angular")
    BRAND_ANSIBLE: IconName = IconName("brand-ansible")
    BRAND_AO3: IconName = IconName("brand-ao3")
    BRAND_APPGALLERY: IconName = IconName("brand-appgallery")
    BRAND_APPLE: IconName = IconName("brand-apple")
    BRAND_APPLE_ARCADE: IconName = IconName("brand-apple-arcade")
    BRAND_APPLE_PODCAST: IconName = IconName("brand-apple-podcast")
    BRAND_APPSTORE: IconName = IconName("brand-appstore")
    BRAND_ASANA: IconName = IconName("brand-asana")
    BRAND_AWS: IconName = IconName("brand-aws")
    BRAND_AZURE: IconName = IconName("brand-azure")
    BRAND_BACKBONE: IconName = IconName("brand-backbone")
    BRAND_BADOO: IconName = IconName("brand-badoo")
    BRAND_BAIDU: IconName = IconName("brand-baidu")
    BRAND_BANDCAMP: IconName = IconName("brand-bandcamp")
    BRAND_BANDLAB: IconName = IconName("brand-bandlab")
    BRAND_BEATS: IconName = IconName("brand-beats")
    BRAND_BEHANCE: IconName = IconName("brand-behance")
    BRAND_BILIBILI: IconName = IconName("brand-bilibili")
    BRAND_BINANCE: IconName = IconName("brand-binance")
    BRAND_BING: IconName = IconName("brand-bing")
    BRAND_BITBUCKET: IconName = IconName("brand-bitbucket")
    BRAND_BLACKBERRY: IconName = IconName("brand-blackberry")
    BRAND_BLENDER: IconName = IconName("brand-blender")
    BRAND_BLOGGER: IconName = IconName("brand-blogger")
    BRAND_BOOKING: IconName = IconName("brand-booking")
    BRAND_BOOTSTRAP: IconName = IconName("brand-bootstrap")
    BRAND_BULMA: IconName = IconName("brand-bulma")
    BRAND_BUMBLE: IconName = IconName("brand-bumble")
    BRAND_BUNPO: IconName = IconName("brand-bunpo")
    BRAND_C_SHARP: IconName = IconName("brand-c-sharp")
    BRAND_CAKE: IconName = IconName("brand-cake")
    BRAND_CAKEPHP: IconName = IconName("brand-cakephp")
    BRAND_CAMPAIGNMONITOR: IconName = IconName("brand-campaignmonitor")
    BRAND_CARBON: IconName = IconName("brand-carbon")
    BRAND_CASHAPP: IconName = IconName("brand-cashapp")
    BRAND_CHROME: IconName = IconName("brand-chrome")
    BRAND_CINEMA_4D: IconName = IconName("brand-cinema-4d")
    BRAND_CITYMAPPER: IconName = IconName("brand-citymapper")
    BRAND_CLOUDFLARE: IconName = IconName("brand-cloudflare")
    BRAND_CODECOV: IconName = IconName("brand-codecov")
    BRAND_CODEPEN: IconName = IconName("brand-codepen")
    BRAND_CODESANDBOX: IconName = IconName("brand-codesandbox")
    BRAND_COHOST: IconName = IconName("brand-cohost")
    BRAND_COINBASE: IconName = IconName("brand-coinbase")
    BRAND_COMEDY_CENTRAL: IconName = IconName("brand-comedy-central")
    BRAND_COREOS: IconName = IconName("brand-coreos")
    BRAND_COUCHDB: IconName = IconName("brand-couchdb")
    BRAND_COUCHSURFING: IconName = IconName("brand-couchsurfing")
    BRAND_CPP: IconName = IconName("brand-cpp")
    BRAND_CRAFT: IconName = IconName("brand-craft")
    BRAND_CRUNCHBASE: IconName = IconName("brand-crunchbase")
    BRAND_CSS3: IconName = IconName("brand-css3")
    BRAND_CTEMPLAR: IconName = IconName("brand-ctemplar")
    BRAND_CUCUMBER: IconName = IconName("brand-cucumber")
    BRAND_CUPRA: IconName = IconName("brand-cupra")
    BRAND_CYPRESS: IconName = IconName("brand-cypress")
    BRAND_D3: IconName = IconName("brand-d3")
    BRAND_DAYS_COUNTER: IconName = IconName("brand-days-counter")
    BRAND_DCOS: IconName = IconName("brand-dcos")
    BRAND_DEBIAN: IconName = IconName("brand-debian")
    BRAND_DEEZER: IconName = IconName("brand-deezer")
    BRAND_DELIVEROO: IconName = IconName("brand-deliveroo")
    BRAND_DENO: IconName = IconName("brand-deno")
    BRAND_DENODO: IconName = IconName("brand-denodo")
    BRAND_DEVIANTART: IconName = IconName("brand-deviantart")
    BRAND_DIGG: IconName = IconName("brand-digg")
    BRAND_DINGTALK: IconName = IconName("brand-dingtalk")
    BRAND_DISCORD: IconName = IconName("brand-discord")
    BRAND_DISCORD_FILLED: IconName = IconName("brand-discord-filled")
    BRAND_DISNEY: IconName = IconName("brand-disney")
    BRAND_DISQUS: IconName = IconName("brand-disqus")
    BRAND_DJANGO: IconName = IconName("brand-django")
    BRAND_DOCKER: IconName = IconName("brand-docker")
    BRAND_DOCTRINE: IconName = IconName("brand-doctrine")
    BRAND_DOLBY_DIGITAL: IconName = IconName("brand-dolby-digital")
    BRAND_DOUBAN: IconName = IconName("brand-douban")
    BRAND_DRIBBBLE: IconName = IconName("brand-dribbble")
    BRAND_DRIBBBLE_FILLED: IconName = IconName("brand-dribbble-filled")
    BRAND_DROPS: IconName = IconName("brand-drops")
    BRAND_DRUPAL: IconName = IconName("brand-drupal")
    BRAND_EDGE: IconName = IconName("brand-edge")
    BRAND_ELASTIC: IconName = IconName("brand-elastic")
    BRAND_ELECTRONIC_ARTS: IconName = IconName("brand-electronic-arts")
    BRAND_EMBER: IconName = IconName("brand-ember")
    BRAND_ENVATO: IconName = IconName("brand-envato")
    BRAND_ETSY: IconName = IconName("brand-etsy")
    BRAND_EVERNOTE: IconName = IconName("brand-evernote")
    BRAND_FACEBOOK: IconName = IconName("brand-facebook")
    BRAND_FACEBOOK_FILLED: IconName = IconName("brand-facebook-filled")
    BRAND_FEEDLY: IconName = IconName("brand-feedly")
    BRAND_FIGMA: IconName = IconName("brand-figma")
    BRAND_FILEZILLA: IconName = IconName("brand-filezilla")
    BRAND_FINDER: IconName = IconName("brand-finder")
    BRAND_FIREBASE: IconName = IconName("brand-firebase")
    BRAND_FIREFOX: IconName = IconName("brand-firefox")
    BRAND_FIVERR: IconName = IconName("brand-fiverr")
    BRAND_FLICKR: IconName = IconName("brand-flickr")
    BRAND_FLIGHTRADAR24: IconName = IconName("brand-flightradar24")
    BRAND_FLIPBOARD: IconName = IconName("brand-flipboard")
    BRAND_FLUTTER: IconName = IconName("brand-flutter")
    BRAND_FORTNITE: IconName = IconName("brand-fortnite")
    BRAND_FOURSQUARE: IconName = IconName("brand-foursquare")
    BRAND_FRAMER: IconName = IconName("brand-framer")
    BRAND_FRAMER_MOTION: IconName = IconName("brand-framer-motion")
    BRAND_FUNIMATION: IconName = IconName("brand-funimation")
    BRAND_GATSBY: IconName = IconName("brand-gatsby")
    BRAND_GIT: IconName = IconName("brand-git")
    BRAND_GITHUB: IconName = IconName("brand-github")
    BRAND_GITHUB_COPILOT: IconName = IconName("brand-github-copilot")
    BRAND_GITHUB_FILLED: IconName = IconName("brand-github-filled")
    BRAND_GITLAB: IconName = IconName("brand-gitlab")
    BRAND_GMAIL: IconName = IconName("brand-gmail")
    BRAND_GOLANG: IconName = IconName("brand-golang")
    BRAND_GOOGLE: IconName = IconName("brand-google")
    BRAND_GOOGLE_ANALYTICS: IconName = IconName("brand-google-analytics")
    BRAND_GOOGLE_BIG_QUERY: IconName = IconName("brand-google-big-query")
    BRAND_GOOGLE_DRIVE: IconName = IconName("brand-google-drive")
    BRAND_GOOGLE_FIT: IconName = IconName("brand-google-fit")
    BRAND_GOOGLE_HOME: IconName = IconName("brand-google-home")
    BRAND_GOOGLE_MAPS: IconName = IconName("brand-google-maps")
    BRAND_GOOGLE_ONE: IconName = IconName("brand-google-one")
    BRAND_GOOGLE_PHOTOS: IconName = IconName("brand-google-photos")
    BRAND_GOOGLE_PLAY: IconName = IconName("brand-google-play")
    BRAND_GOOGLE_PODCASTS: IconName = IconName("brand-google-podcasts")
    BRAND_GRAMMARLY: IconName = IconName("brand-grammarly")
    BRAND_GRAPHQL: IconName = IconName("brand-graphql")
    BRAND_GRAVATAR: IconName = IconName("brand-gravatar")
    BRAND_GRINDR: IconName = IconName("brand-grindr")
    BRAND_GUARDIAN: IconName = IconName("brand-guardian")
    BRAND_GUMROAD: IconName = IconName("brand-gumroad")
    BRAND_HBO: IconName = IconName("brand-hbo")
    BRAND_HEADLESSUI: IconName = IconName("brand-headlessui")
    BRAND_HEXO: IconName = IconName("brand-hexo")
    BRAND_HIPCHAT: IconName = IconName("brand-hipchat")
    BRAND_HTML5: IconName = IconName("brand-html5")
    BRAND_INERTIA: IconName = IconName("brand-inertia")
    BRAND_INSTAGRAM: IconName = IconName("brand-instagram")
    BRAND_INTERCOM: IconName = IconName("brand-intercom")
    BRAND_ITCH: IconName = IconName("brand-itch")
    BRAND_JAVASCRIPT: IconName = IconName("brand-javascript")
    BRAND_JUEJIN: IconName = IconName("brand-juejin")
    BRAND_KBIN: IconName = IconName("brand-kbin")
    BRAND_KICK: IconName = IconName("brand-kick")
    BRAND_KICKSTARTER: IconName = IconName("brand-kickstarter")
    BRAND_KOTLIN: IconName = IconName("brand-kotlin")
    BRAND_LARAVEL: IconName = IconName("brand-laravel")
    BRAND_LASTFM: IconName = IconName("brand-lastfm")
    BRAND_LEETCODE: IconName = IconName("brand-leetcode")
    BRAND_LETTERBOXD: IconName = IconName("brand-letterboxd")
    BRAND_LINE: IconName = IconName("brand-line")
    BRAND_LINKEDIN: IconName = IconName("brand-linkedin")
    BRAND_LINKTREE: IconName = IconName("brand-linktree")
    BRAND_LINQPAD: IconName = IconName("brand-linqpad")
    BRAND_LOOM: IconName = IconName("brand-loom")
    BRAND_MAILGUN: IconName = IconName("brand-mailgun")
    BRAND_MANTINE: IconName = IconName("brand-mantine")
    BRAND_MASTERCARD: IconName = IconName("brand-mastercard")
    BRAND_MASTODON: IconName = IconName("brand-mastodon")
    BRAND_MATRIX: IconName = IconName("brand-matrix")
    BRAND_MCDONALDS: IconName = IconName("brand-mcdonalds")
    BRAND_MEDIUM: IconName = IconName("brand-medium")
    BRAND_MERCEDES: IconName = IconName("brand-mercedes")
    BRAND_MESSENGER: IconName = IconName("brand-messenger")
    BRAND_META: IconName = IconName("brand-meta")
    BRAND_MICROSOFT_TEAMS: IconName = IconName("brand-microsoft-teams")
    BRAND_MINECRAFT: IconName = IconName("brand-minecraft")
    BRAND_MINIPROGRAM: IconName = IconName("brand-miniprogram")
    BRAND_MIXPANEL: IconName = IconName("brand-mixpanel")
    BRAND_MONDAY: IconName = IconName("brand-monday")
    BRAND_MONGODB: IconName = IconName("brand-mongodb")
    BRAND_MY_OPPO: IconName = IconName("brand-my-oppo")
    BRAND_MYSQL: IconName = IconName("brand-mysql")
    BRAND_NATIONAL_GEOGRAPHIC: IconName = IconName("brand-national-geographic")
    BRAND_NEM: IconName = IconName("brand-nem")
    BRAND_NETBEANS: IconName = IconName("brand-netbeans")
    BRAND_NETEASE_MUSIC: IconName = IconName("brand-netease-music")
    BRAND_NETFLIX: IconName = IconName("brand-netflix")
    BRAND_NEXO: IconName = IconName("brand-nexo")
    BRAND_NEXTCLOUD: IconName = IconName("brand-nextcloud")
    BRAND_NEXTJS: IconName = IconName("brand-nextjs")
    BRAND_NODEJS: IconName = IconName("brand-nodejs")
    BRAND_NORD_VPN: IconName = IconName("brand-nord-vpn")
    BRAND_NOTION: IconName = IconName("brand-notion")
    BRAND_NPM: IconName = IconName("brand-npm")
    BRAND_NUXT: IconName = IconName("brand-nuxt")
    BRAND_NYTIMES: IconName = IconName("brand-nytimes")
    BRAND_OAUTH: IconName = IconName("brand-oauth")
    BRAND_OFFICE: IconName = IconName("brand-office")
    BRAND_OK_RU: IconName = IconName("brand-ok-ru")
    BRAND_ONEDRIVE: IconName = IconName("brand-onedrive")
    BRAND_ONLYFANS: IconName = IconName("brand-onlyfans")
    BRAND_OPEN_SOURCE: IconName = IconName("brand-open-source")
    BRAND_OPENAI: IconName = IconName("brand-openai")
    BRAND_OPENVPN: IconName = IconName("brand-openvpn")
    BRAND_OPERA: IconName = IconName("brand-opera")
    BRAND_PAGEKIT: IconName = IconName("brand-pagekit")
    BRAND_PATREON: IconName = IconName("brand-patreon")
    BRAND_PAYPAL: IconName = IconName("brand-paypal")
    BRAND_PAYPAL_FILLED: IconName = IconName("brand-paypal-filled")
    BRAND_PAYPAY: IconName = IconName("brand-paypay")
    BRAND_PEANUT: IconName = IconName("brand-peanut")
    BRAND_PEPSI: IconName = IconName("brand-pepsi")
    BRAND_PHP: IconName = IconName("brand-php")
    BRAND_PICSART: IconName = IconName("brand-picsart")
    BRAND_PINTEREST: IconName = IconName("brand-pinterest")
    BRAND_PLANETSCALE: IconName = IconName("brand-planetscale")
    BRAND_POCKET: IconName = IconName("brand-pocket")
    BRAND_POLYMER: IconName = IconName("brand-polymer")
    BRAND_POWERSHELL: IconName = IconName("brand-powershell")
    BRAND_PRISMA: IconName = IconName("brand-prisma")
    BRAND_PRODUCTHUNT: IconName = IconName("brand-producthunt")
    BRAND_PUSHBULLET: IconName = IconName("brand-pushbullet")
    BRAND_PUSHOVER: IconName = IconName("brand-pushover")
    BRAND_PYTHON: IconName = IconName("brand-python")
    BRAND_QQ: IconName = IconName("brand-qq")
    BRAND_RADIX_UI: IconName = IconName("brand-radix-ui")
    BRAND_REACT: IconName = IconName("brand-react")
    BRAND_REACT_NATIVE: IconName = IconName("brand-react-native")
    BRAND_REASON: IconName = IconName("brand-reason")
    BRAND_REDDIT: IconName = IconName("brand-reddit")
    BRAND_REDHAT: IconName = IconName("brand-redhat")
    BRAND_REDUX: IconName = IconName("brand-redux")
    BRAND_REVOLUT: IconName = IconName("brand-revolut")
    BRAND_RUMBLE: IconName = IconName("brand-rumble")
    BRAND_RUST: IconName = IconName("brand-rust")
    BRAND_SAFARI: IconName = IconName("brand-safari")
    BRAND_SAMSUNGPASS: IconName = IconName("brand-samsungpass")
    BRAND_SASS: IconName = IconName("brand-sass")
    BRAND_SENTRY: IconName = IconName("brand-sentry")
    BRAND_SHARIK: IconName = IconName("brand-sharik")
    BRAND_SHAZAM: IconName = IconName("brand-shazam")
    BRAND_SHOPEE: IconName = IconName("brand-shopee")
    BRAND_SKETCH: IconName = IconName("brand-sketch")
    BRAND_SKYPE: IconName = IconName("brand-skype")
    BRAND_SLACK: IconName = IconName("brand-slack")
    BRAND_SNAPCHAT: IconName = IconName("brand-snapchat")
    BRAND_SNAPSEED: IconName = IconName("brand-snapseed")
    BRAND_SNOWFLAKE: IconName = IconName("brand-snowflake")
    BRAND_SOCKET_IO: IconName = IconName("brand-socket-io")
    BRAND_SOLIDJS: IconName = IconName("brand-solidjs")
    BRAND_SOUNDCLOUD: IconName = IconName("brand-soundcloud")
    BRAND_SPACEHEY: IconName = IconName("brand-spacehey")
    BRAND_SPEEDTEST: IconName = IconName("brand-speedtest")
    BRAND_SPOTIFY: IconName = IconName("brand-spotify")
    BRAND_STACKOVERFLOW: IconName = IconName("brand-stackoverflow")
    BRAND_STACKSHARE: IconName = IconName("brand-stackshare")
    BRAND_STEAM: IconName = IconName("brand-steam")
    BRAND_STORJ: IconName = IconName("brand-storj")
    BRAND_STORYBOOK: IconName = IconName("brand-storybook")
    BRAND_STORYTEL: IconName = IconName("brand-storytel")
    BRAND_STRAVA: IconName = IconName("brand-strava")
    BRAND_STRIPE: IconName = IconName("brand-stripe")
    BRAND_SUBLIME_TEXT: IconName = IconName("brand-sublime-text")
    BRAND_SUGARIZER: IconName = IconName("brand-sugarizer")
    BRAND_SUPABASE: IconName = IconName("brand-supabase")
    BRAND_SUPERHUMAN: IconName = IconName("brand-superhuman")
    BRAND_SUPERNOVA: IconName = IconName("brand-supernova")
    BRAND_SURFSHARK: IconName = IconName("brand-surfshark")
    BRAND_SVELTE: IconName = IconName("brand-svelte")
    BRAND_SWIFT: IconName = IconName("brand-swift")
    BRAND_SYMFONY: IconName = IconName("brand-symfony")
    BRAND_TABLER: IconName = IconName("brand-tabler")
    BRAND_TAILWIND: IconName = IconName("brand-tailwind")
    BRAND_TAOBAO: IconName = IconName("brand-taobao")
    BRAND_TED: IconName = IconName("brand-ted")
    BRAND_TELEGRAM: IconName = IconName("brand-telegram")
    BRAND_TERRAFORM: IconName = IconName("brand-terraform")
    BRAND_TETHER: IconName = IconName("brand-tether")
    BRAND_THREEJS: IconName = IconName("brand-threejs")
    BRAND_TIDAL: IconName = IconName("brand-tidal")
    BRAND_TIKTO_FILLED: IconName = IconName("brand-tikto-filled")
    BRAND_TIKTOK: IconName = IconName("brand-tiktok")
    BRAND_TINDER: IconName = IconName("brand-tinder")
    BRAND_TOPBUZZ: IconName = IconName("brand-topbuzz")
    BRAND_TORCHAIN: IconName = IconName("brand-torchain")
    BRAND_TOYOTA: IconName = IconName("brand-toyota")
    BRAND_TRELLO: IconName = IconName("brand-trello")
    BRAND_TRIPADVISOR: IconName = IconName("brand-tripadvisor")
    BRAND_TUMBLR: IconName = IconName("brand-tumblr")
    BRAND_TWILIO: IconName = IconName("brand-twilio")
    BRAND_TWITCH: IconName = IconName("brand-twitch")
    BRAND_TWITTER: IconName = IconName("brand-twitter")
    BRAND_TWITTER_FILLED: IconName = IconName("brand-twitter-filled")
    BRAND_TYPESCRIPT: IconName = IconName("brand-typescript")
    BRAND_UBER: IconName = IconName("brand-uber")
    BRAND_UBUNTU: IconName = IconName("brand-ubuntu")
    BRAND_UNITY: IconName = IconName("brand-unity")
    BRAND_UNSPLASH: IconName = IconName("brand-unsplash")
    BRAND_UPWORK: IconName = IconName("brand-upwork")
    BRAND_VALORANT: IconName = IconName("brand-valorant")
    BRAND_VERCEL: IconName = IconName("brand-vercel")
    BRAND_VIMEO: IconName = IconName("brand-vimeo")
    BRAND_VINTED: IconName = IconName("brand-vinted")
    BRAND_VISA: IconName = IconName("brand-visa")
    BRAND_VISUAL_STUDIO: IconName = IconName("brand-visual-studio")
    BRAND_VITE: IconName = IconName("brand-vite")
    BRAND_VIVALDI: IconName = IconName("brand-vivaldi")
    BRAND_VK: IconName = IconName("brand-vk")
    BRAND_VLC: IconName = IconName("brand-vlc")
    BRAND_VOLKSWAGEN: IconName = IconName("brand-volkswagen")
    BRAND_VSCO: IconName = IconName("brand-vsco")
    BRAND_VSCODE: IconName = IconName("brand-vscode")
    BRAND_VUE: IconName = IconName("brand-vue")
    BRAND_WALMART: IconName = IconName("brand-walmart")
    BRAND_WAZE: IconName = IconName("brand-waze")
    BRAND_WEBFLOW: IconName = IconName("brand-webflow")
    BRAND_WECHAT: IconName = IconName("brand-wechat")
    BRAND_WEIBO: IconName = IconName("brand-weibo")
    BRAND_WHATSAPP: IconName = IconName("brand-whatsapp")
    BRAND_WIKIPEDIA: IconName = IconName("brand-wikipedia")
    BRAND_WINDOWS: IconName = IconName("brand-windows")
    BRAND_WINDY: IconName = IconName("brand-windy")
    BRAND_WISH: IconName = IconName("brand-wish")
    BRAND_WIX: IconName = IconName("brand-wix")
    BRAND_WORDPRESS: IconName = IconName("brand-wordpress")
    BRAND_XAMARIN: IconName = IconName("brand-xamarin")
    BRAND_XBOX: IconName = IconName("brand-xbox")
    BRAND_XING: IconName = IconName("brand-xing")
    BRAND_YAHOO: IconName = IconName("brand-yahoo")
    BRAND_YANDEX: IconName = IconName("brand-yandex")
    BRAND_YATSE: IconName = IconName("brand-yatse")
    BRAND_YCOMBINATOR: IconName = IconName("brand-ycombinator")
    BRAND_YOUTUBE: IconName = IconName("brand-youtube")
    BRAND_YOUTUBE_KIDS: IconName = IconName("brand-youtube-kids")
    BRAND_ZALANDO: IconName = IconName("brand-zalando")
    BRAND_ZAPIER: IconName = IconName("brand-zapier")
    BRAND_ZEIT: IconName = IconName("brand-zeit")
    BRAND_ZHIHU: IconName = IconName("brand-zhihu")
    BRAND_ZOOM: IconName = IconName("brand-zoom")
    BRAND_ZULIP: IconName = IconName("brand-zulip")
    BRAND_ZWIFT: IconName = IconName("brand-zwift")
    BREAD: IconName = IconName("bread")
    BREAD_OFF: IconName = IconName("bread-off")
    BRIEFCASE: IconName = IconName("briefcase")
    BRIEFCASE_OFF: IconName = IconName("briefcase-off")
    BRIGHTNESS: IconName = IconName("brightness")
    BRIGHTNESS_2: IconName = IconName("brightness-2")
    BRIGHTNESS_DOWN: IconName = IconName("brightness-down")
    BRIGHTNESS_HALF: IconName = IconName("brightness-half")
    BRIGHTNESS_OFF: IconName = IconName("brightness-off")
    BRIGHTNESS_UP: IconName = IconName("brightness-up")
    BROADCAST: IconName = IconName("broadcast")
    BROADCAST_OFF: IconName = IconName("broadcast-off")
    BROWSER: IconName = IconName("browser")
    BROWSER_CHECK: IconName = IconName("browser-check")
    BROWSER_OFF: IconName = IconName("browser-off")
    BROWSER_PLUS: IconName = IconName("browser-plus")
    BROWSER_X: IconName = IconName("browser-x")
    BRUSH: IconName = IconName("brush")
    BRUSH_OFF: IconName = IconName("brush-off")
    BUCKET: IconName = IconName("bucket")
    BUCKET_DROPLET: IconName = IconName("bucket-droplet")
    BUCKET_OFF: IconName = IconName("bucket-off")
    BUG: IconName = IconName("bug")
    BUG_OFF: IconName = IconName("bug-off")
    BUILDING: IconName = IconName("building")
    BUILDING_ARCH: IconName = IconName("building-arch")
    BUILDING_BANK: IconName = IconName("building-bank")
    BUILDING_BRIDGE: IconName = IconName("building-bridge")
    BUILDING_BRIDGE_2: IconName = IconName("building-bridge-2")
    BUILDING_BROADCAST_TOWER: IconName = IconName("building-broadcast-tower")
    BUILDING_CAROUSEL: IconName = IconName("building-carousel")
    BUILDING_CASTLE: IconName = IconName("building-castle")
    BUILDING_CHURCH: IconName = IconName("building-church")
    BUILDING_CIRCUS: IconName = IconName("building-circus")
    BUILDING_COMMUNITY: IconName = IconName("building-community")
    BUILDING_COTTAGE: IconName = IconName("building-cottage")
    BUILDING_ESTATE: IconName = IconName("building-estate")
    BUILDING_FACTORY: IconName = IconName("building-factory")
    BUILDING_FACTORY_2: IconName = IconName("building-factory-2")
    BUILDING_FORTRESS: IconName = IconName("building-fortress")
    BUILDING_HOSPITAL: IconName = IconName("building-hospital")
    BUILDING_LIGHTHOUSE: IconName = IconName("building-lighthouse")
    BUILDING_MONUMENT: IconName = IconName("building-monument")
    BUILDING_MOSQUE: IconName = IconName("building-mosque")
    BUILDING_PAVILION: IconName = IconName("building-pavilion")
    BUILDING_SKYSCRAPER: IconName = IconName("building-skyscraper")
    BUILDING_STADIUM: IconName = IconName("building-stadium")
    BUILDING_STORE: IconName = IconName("building-store")
    BUILDING_TUNNEL: IconName = IconName("building-tunnel")
    BUILDING_WAREHOUSE: IconName = IconName("building-warehouse")
    BUILDING_WIND_TURBINE: IconName = IconName("building-wind-turbine")
    BULB: IconName = IconName("bulb")
    BULB_FILLED: IconName = IconName("bulb-filled")
    BULB_OFF: IconName = IconName("bulb-off")
    BULLDOZER: IconName = IconName("bulldozer")
    BUS: IconName = IconName("bus")
    BUS_OFF: IconName = IconName("bus-off")
    BUS_STOP: IconName = IconName("bus-stop")
    BUSINESSPLAN: IconName = IconName("businessplan")
    BUTTERFLY: IconName = IconName("butterfly")
    CACTUS: IconName = IconName("cactus")
    CACTUS_OFF: IconName = IconName("cactus-off")
    CAKE: IconName = IconName("cake")
    CAKE_OFF: IconName = IconName("cake-off")
    CALCULATOR: IconName = IconName("calculator")
    CALCULATOR_OFF: IconName = IconName("calculator-off")
    CALENDAR: IconName = IconName("calendar")
    CALENDAR_BOLT: IconName = IconName("calendar-bolt")
    CALENDAR_CANCEL: IconName = IconName("calendar-cancel")
    CALENDAR_CHECK: IconName = IconName("calendar-check")
    CALENDAR_CODE: IconName = IconName("calendar-code")
    CALENDAR_COG: IconName = IconName("calendar-cog")
    CALENDAR_DOLLAR: IconName = IconName("calendar-dollar")
    CALENDAR_DOWN: IconName = IconName("calendar-down")
    CALENDAR_DUE: IconName = IconName("calendar-due")
    CALENDAR_EVENT: IconName = IconName("calendar-event")
    CALENDAR_EXCLAMATION: IconName = IconName("calendar-exclamation")
    CALENDAR_HEART: IconName = IconName("calendar-heart")
    CALENDAR_MINUS: IconName = IconName("calendar-minus")
    CALENDAR_OFF: IconName = IconName("calendar-off")
    CALENDAR_PAUSE: IconName = IconName("calendar-pause")
    CALENDAR_PIN: IconName = IconName("calendar-pin")
    CALENDAR_PLUS: IconName = IconName("calendar-plus")
    CALENDAR_QUESTION: IconName = IconName("calendar-question")
    CALENDAR_REPEAT: IconName = IconName("calendar-repeat")
    CALENDAR_SEARCH: IconName = IconName("calendar-search")
    CALENDAR_SHARE: IconName = IconName("calendar-share")
    CALENDAR_STAR: IconName = IconName("calendar-star")
    CALENDAR_STATS: IconName = IconName("calendar-stats")
    CALENDAR_TIME: IconName = IconName("calendar-time")
    CALENDAR_UP: IconName = IconName("calendar-up")
    CALENDAR_X: IconName = IconName("calendar-x")
    CAMERA: IconName = IconName("camera")
    CAMERA_BOLT: IconName = IconName("camera-bolt")
    CAMERA_CANCEL: IconName = IconName("camera-cancel")
    CAMERA_CHECK: IconName = IconName("camera-check")
    CAMERA_CODE: IconName = IconName("camera-code")
    CAMERA_COG: IconName = IconName("camera-cog")
    CAMERA_DOLLAR: IconName = IconName("camera-dollar")
    CAMERA_DOWN: IconName = IconName("camera-down")
    CAMERA_EXCLAMATION: IconName = IconName("camera-exclamation")
    CAMERA_FILLED: IconName = IconName("camera-filled")
    CAMERA_HEART: IconName = IconName("camera-heart")
    CAMERA_MINUS: IconName = IconName("camera-minus")
    CAMERA_OFF: IconName = IconName("camera-off")
    CAMERA_PAUSE: IconName = IconName("camera-pause")
    CAMERA_PIN: IconName = IconName("camera-pin")
    CAMERA_PLUS: IconName = IconName("camera-plus")
    CAMERA_QUESTION: IconName = IconName("camera-question")
    CAMERA_ROTATE: IconName = IconName("camera-rotate")
    CAMERA_SEARCH: IconName = IconName("camera-search")
    CAMERA_SELFIE: IconName = IconName("camera-selfie")
    CAMERA_SHARE: IconName = IconName("camera-share")
    CAMERA_STAR: IconName = IconName("camera-star")
    CAMERA_UP: IconName = IconName("camera-up")
    CAMERA_X: IconName = IconName("camera-x")
    CAMPER: IconName = IconName("camper")
    CAMPFIRE: IconName = IconName("campfire")
    CANDLE: IconName = IconName("candle")
    CANDY: IconName = IconName("candy")
    CANDY_OFF: IconName = IconName("candy-off")
    CANE: IconName = IconName("cane")
    CANNABIS: IconName = IconName("cannabis")
    CAPSULE: IconName = IconName("capsule")
    CAPSULE_HORIZONTAL: IconName = IconName("capsule-horizontal")
    CAPTURE: IconName = IconName("capture")
    CAPTURE_OFF: IconName = IconName("capture-off")
    CAR: IconName = IconName("car")
    CAR_CRANE: IconName = IconName("car-crane")
    CAR_CRASH: IconName = IconName("car-crash")
    CAR_OFF: IconName = IconName("car-off")
    CAR_TURBINE: IconName = IconName("car-turbine")
    CARAVAN: IconName = IconName("caravan")
    CARDBOARDS: IconName = IconName("cardboards")
    CARDBOARDS_OFF: IconName = IconName("cardboards-off")
    CARDS: IconName = IconName("cards")
    CARET_DOWN: IconName = IconName("caret-down")
    CARET_LEFT: IconName = IconName("caret-left")
    CARET_RIGHT: IconName = IconName("caret-right")
    CARET_UP: IconName = IconName("caret-up")
    CAROUSEL_HORIZONTAL: IconName = IconName("carousel-horizontal")
    CAROUSEL_HORIZONTAL_FILLED: IconName = IconName("carousel-horizontal-filled")
    CAROUSEL_VERTICAL: IconName = IconName("carousel-vertical")
    CAROUSEL_VERTICAL_FILLED: IconName = IconName("carousel-vertical-filled")
    CARROT: IconName = IconName("carrot")
    CARROT_OFF: IconName = IconName("carrot-off")
    CASH: IconName = IconName("cash")
    CASH_BANKNOTE: IconName = IconName("cash-banknote")
    CASH_BANKNOTE_OFF: IconName = IconName("cash-banknote-off")
    CASH_OFF: IconName = IconName("cash-off")
    CAST: IconName = IconName("cast")
    CAST_OFF: IconName = IconName("cast-off")
    CAT: IconName = IconName("cat")
    CATEGORY: IconName = IconName("category")
    CATEGORY_2: IconName = IconName("category-2")
    CE: IconName = IconName("ce")
    CE_OFF: IconName = IconName("ce-off")
    CELL: IconName = IconName("cell")
    CELL_SIGNAL_1: IconName = IconName("cell-signal-1")
    CELL_SIGNAL_2: IconName = IconName("cell-signal-2")
    CELL_SIGNAL_3: IconName = IconName("cell-signal-3")
    CELL_SIGNAL_4: IconName = IconName("cell-signal-4")
    CELL_SIGNAL_5: IconName = IconName("cell-signal-5")
    CELL_SIGNAL_OFF: IconName = IconName("cell-signal-off")
    CERTIFICATE: IconName = IconName("certificate")
    CERTIFICATE_2: IconName = IconName("certificate-2")
    CERTIFICATE_2_OFF: IconName = IconName("certificate-2-off")
    CERTIFICATE_OFF: IconName = IconName("certificate-off")
    CHAIR_DIRECTOR: IconName = IconName("chair-director")
    CHALKBOARD: IconName = IconName("chalkboard")
    CHALKBOARD_OFF: IconName = IconName("chalkboard-off")
    CHARGING_PILE: IconName = IconName("charging-pile")
    CHART_ARCS: IconName = IconName("chart-arcs")
    CHART_ARCS_3: IconName = IconName("chart-arcs-3")
    CHART_AREA: IconName = IconName("chart-area")
    CHART_AREA_FILLED: IconName = IconName("chart-area-filled")
    CHART_AREA_LINE: IconName = IconName("chart-area-line")
    CHART_AREA_LINE_FILLED: IconName = IconName("chart-area-line-filled")
    CHART_ARROWS: IconName = IconName("chart-arrows")
    CHART_ARROWS_VERTICAL: IconName = IconName("chart-arrows-vertical")
    CHART_BAR: IconName = IconName("chart-bar")
    CHART_BAR_OFF: IconName = IconName("chart-bar-off")
    CHART_BUBBLE: IconName = IconName("chart-bubble")
    CHART_BUBBLE_FILLED: IconName = IconName("chart-bubble-filled")
    CHART_CANDLE: IconName = IconName("chart-candle")
    CHART_CANDLE_FILLED: IconName = IconName("chart-candle-filled")
    CHART_CIRCLES: IconName = IconName("chart-circles")
    CHART_DONUT: IconName = IconName("chart-donut")
    CHART_DONUT_2: IconName = IconName("chart-donut-2")
    CHART_DONUT_3: IconName = IconName("chart-donut-3")
    CHART_DONUT_4: IconName = IconName("chart-donut-4")
    CHART_DONUT_FILLED: IconName = IconName("chart-donut-filled")
    CHART_DOTS: IconName = IconName("chart-dots")
    CHART_DOTS_2: IconName = IconName("chart-dots-2")
    CHART_DOTS_3: IconName = IconName("chart-dots-3")
    CHART_GRID_DOTS: IconName = IconName("chart-grid-dots")
    CHART_HISTOGRAM: IconName = IconName("chart-histogram")
    CHART_INFOGRAPHIC: IconName = IconName("chart-infographic")
    CHART_LINE: IconName = IconName("chart-line")
    CHART_PIE: IconName = IconName("chart-pie")
    CHART_PIE_2: IconName = IconName("chart-pie-2")
    CHART_PIE_3: IconName = IconName("chart-pie-3")
    CHART_PIE_4: IconName = IconName("chart-pie-4")
    CHART_PIE_FILLED: IconName = IconName("chart-pie-filled")
    CHART_PIE_OFF: IconName = IconName("chart-pie-off")
    CHART_PPF: IconName = IconName("chart-ppf")
    CHART_RADAR: IconName = IconName("chart-radar")
    CHART_SANKEY: IconName = IconName("chart-sankey")
    CHART_TREEMAP: IconName = IconName("chart-treemap")
    CHECK: IconName = IconName("check")
    CHECKBOX: IconName = IconName("checkbox")
    CHECKLIST: IconName = IconName("checklist")
    CHECKS: IconName = IconName("checks")
    CHECKUP_LIST: IconName = IconName("checkup-list")
    CHEESE: IconName = IconName("cheese")
    CHEF_HAT: IconName = IconName("chef-hat")
    CHEF_HAT_OFF: IconName = IconName("chef-hat-off")
    CHERRY: IconName = IconName("cherry")
    CHERRY_FILLED: IconName = IconName("cherry-filled")
    CHESS: IconName = IconName("chess")
    CHESS_BISHOP: IconName = IconName("chess-bishop")
    CHESS_BISHOP_FILLED: IconName = IconName("chess-bishop-filled")
    CHESS_FILLED: IconName = IconName("chess-filled")
    CHESS_KING: IconName = IconName("chess-king")
    CHESS_KING_FILLED: IconName = IconName("chess-king-filled")
    CHESS_KNIGHT: IconName = IconName("chess-knight")
    CHESS_KNIGHT_FILLED: IconName = IconName("chess-knight-filled")
    CHESS_QUEEN: IconName = IconName("chess-queen")
    CHESS_QUEEN_FILLED: IconName = IconName("chess-queen-filled")
    CHESS_ROOK: IconName = IconName("chess-rook")
    CHESS_ROOK_FILLED: IconName = IconName("chess-rook-filled")
    CHEVRON_COMPACT_DOWN: IconName = IconName("chevron-compact-down")
    CHEVRON_COMPACT_LEFT: IconName = IconName("chevron-compact-left")
    CHEVRON_COMPACT_RIGHT: IconName = IconName("chevron-compact-right")
    CHEVRON_COMPACT_UP: IconName = IconName("chevron-compact-up")
    CHEVRON_DOWN: IconName = IconName("chevron-down")
    CHEVRON_DOWN_LEFT: IconName = IconName("chevron-down-left")
    CHEVRON_DOWN_RIGHT: IconName = IconName("chevron-down-right")
    CHEVRON_LEFT: IconName = IconName("chevron-left")
    CHEVRON_LEFT_PIPE: IconName = IconName("chevron-left-pipe")
    CHEVRON_RIGHT: IconName = IconName("chevron-right")
    CHEVRON_RIGHT_PIPE: IconName = IconName("chevron-right-pipe")
    CHEVRON_UP: IconName = IconName("chevron-up")
    CHEVRON_UP_LEFT: IconName = IconName("chevron-up-left")
    CHEVRON_UP_RIGHT: IconName = IconName("chevron-up-right")
    CHEVRONS_DOWN: IconName = IconName("chevrons-down")
    CHEVRONS_DOWN_LEFT: IconName = IconName("chevrons-down-left")
    CHEVRONS_DOWN_RIGHT: IconName = IconName("chevrons-down-right")
    CHEVRONS_LEFT: IconName = IconName("chevrons-left")
    CHEVRONS_RIGHT: IconName = IconName("chevrons-right")
    CHEVRONS_UP: IconName = IconName("chevrons-up")
    CHEVRONS_UP_LEFT: IconName = IconName("chevrons-up-left")
    CHEVRONS_UP_RIGHT: IconName = IconName("chevrons-up-right")
    CHISEL: IconName = IconName("chisel")
    CHRISTMAS_TREE: IconName = IconName("christmas-tree")
    CHRISTMAS_TREE_OFF: IconName = IconName("christmas-tree-off")
    CIRCLE: IconName = IconName("circle")
    CIRCLE_0_FILLED: IconName = IconName("circle-0-filled")
    CIRCLE_1_FILLED: IconName = IconName("circle-1-filled")
    CIRCLE_2_FILLED: IconName = IconName("circle-2-filled")
    CIRCLE_3_FILLED: IconName = IconName("circle-3-filled")
    CIRCLE_4_FILLED: IconName = IconName("circle-4-filled")
    CIRCLE_5_FILLED: IconName = IconName("circle-5-filled")
    CIRCLE_6_FILLED: IconName = IconName("circle-6-filled")
    CIRCLE_7_FILLED: IconName = IconName("circle-7-filled")
    CIRCLE_8_FILLED: IconName = IconName("circle-8-filled")
    CIRCLE_9_FILLED: IconName = IconName("circle-9-filled")
    CIRCLE_ARROW_DOWN: IconName = IconName("circle-arrow-down")
    CIRCLE_ARROW_DOWN_FILLED: IconName = IconName("circle-arrow-down-filled")
    CIRCLE_ARROW_DOWN_LEFT: IconName = IconName("circle-arrow-down-left")
    CIRCLE_ARROW_DOWN_LEFT_FILLED: IconName = IconName("circle-arrow-down-left-filled")
    CIRCLE_ARROW_DOWN_RIGHT: IconName = IconName("circle-arrow-down-right")
    CIRCLE_ARROW_DOWN_RIGHT_FILLED: IconName = IconName(
        "circle-arrow-down-right-filled"
    )
    CIRCLE_ARROW_LEFT: IconName = IconName("circle-arrow-left")
    CIRCLE_ARROW_LEFT_FILLED: IconName = IconName("circle-arrow-left-filled")
    CIRCLE_ARROW_RIGHT: IconName = IconName("circle-arrow-right")
    CIRCLE_ARROW_RIGHT_FILLED: IconName = IconName("circle-arrow-right-filled")
    CIRCLE_ARROW_UP: IconName = IconName("circle-arrow-up")
    CIRCLE_ARROW_UP_FILLED: IconName = IconName("circle-arrow-up-filled")
    CIRCLE_ARROW_UP_LEFT: IconName = IconName("circle-arrow-up-left")
    CIRCLE_ARROW_UP_LEFT_FILLED: IconName = IconName("circle-arrow-up-left-filled")
    CIRCLE_ARROW_UP_RIGHT: IconName = IconName("circle-arrow-up-right")
    CIRCLE_ARROW_UP_RIGHT_FILLED: IconName = IconName("circle-arrow-up-right-filled")
    CIRCLE_CARET_DOWN: IconName = IconName("circle-caret-down")
    CIRCLE_CARET_LEFT: IconName = IconName("circle-caret-left")
    CIRCLE_CARET_RIGHT: IconName = IconName("circle-caret-right")
    CIRCLE_CARET_UP: IconName = IconName("circle-caret-up")
    CIRCLE_CHECK: IconName = IconName("circle-check")
    CIRCLE_CHECK_FILLED: IconName = IconName("circle-check-filled")
    CIRCLE_CHEVRON_DOWN: IconName = IconName("circle-chevron-down")
    CIRCLE_CHEVRON_LEFT: IconName = IconName("circle-chevron-left")
    CIRCLE_CHEVRON_RIGHT: IconName = IconName("circle-chevron-right")
    CIRCLE_CHEVRON_UP: IconName = IconName("circle-chevron-up")
    CIRCLE_CHEVRONS_DOWN: IconName = IconName("circle-chevrons-down")
    CIRCLE_CHEVRONS_LEFT: IconName = IconName("circle-chevrons-left")
    CIRCLE_CHEVRONS_RIGHT: IconName = IconName("circle-chevrons-right")
    CIRCLE_CHEVRONS_UP: IconName = IconName("circle-chevrons-up")
    CIRCLE_DASHED: IconName = IconName("circle-dashed")
    CIRCLE_DOT: IconName = IconName("circle-dot")
    CIRCLE_DOT_FILLED: IconName = IconName("circle-dot-filled")
    CIRCLE_DOTTED: IconName = IconName("circle-dotted")
    CIRCLE_FILLED: IconName = IconName("circle-filled")
    CIRCLE_HALF: IconName = IconName("circle-half")
    CIRCLE_HALF_2: IconName = IconName("circle-half-2")
    CIRCLE_HALF_VERTICAL: IconName = IconName("circle-half-vertical")
    CIRCLE_KEY: IconName = IconName("circle-key")
    CIRCLE_KEY_FILLED: IconName = IconName("circle-key-filled")
    CIRCLE_LETTER_A: IconName = IconName("circle-letter-a")
    CIRCLE_LETTER_B: IconName = IconName("circle-letter-b")
    CIRCLE_LETTER_C: IconName = IconName("circle-letter-c")
    CIRCLE_LETTER_D: IconName = IconName("circle-letter-d")
    CIRCLE_LETTER_E: IconName = IconName("circle-letter-e")
    CIRCLE_LETTER_F: IconName = IconName("circle-letter-f")
    CIRCLE_LETTER_G: IconName = IconName("circle-letter-g")
    CIRCLE_LETTER_H: IconName = IconName("circle-letter-h")
    CIRCLE_LETTER_I: IconName = IconName("circle-letter-i")
    CIRCLE_LETTER_J: IconName = IconName("circle-letter-j")
    CIRCLE_LETTER_K: IconName = IconName("circle-letter-k")
    CIRCLE_LETTER_L: IconName = IconName("circle-letter-l")
    CIRCLE_LETTER_M: IconName = IconName("circle-letter-m")
    CIRCLE_LETTER_N: IconName = IconName("circle-letter-n")
    CIRCLE_LETTER_O: IconName = IconName("circle-letter-o")
    CIRCLE_LETTER_P: IconName = IconName("circle-letter-p")
    CIRCLE_LETTER_Q: IconName = IconName("circle-letter-q")
    CIRCLE_LETTER_R: IconName = IconName("circle-letter-r")
    CIRCLE_LETTER_S: IconName = IconName("circle-letter-s")
    CIRCLE_LETTER_T: IconName = IconName("circle-letter-t")
    CIRCLE_LETTER_U: IconName = IconName("circle-letter-u")
    CIRCLE_LETTER_V: IconName = IconName("circle-letter-v")
    CIRCLE_LETTER_W: IconName = IconName("circle-letter-w")
    CIRCLE_LETTER_X: IconName = IconName("circle-letter-x")
    CIRCLE_LETTER_Y: IconName = IconName("circle-letter-y")
    CIRCLE_LETTER_Z: IconName = IconName("circle-letter-z")
    CIRCLE_MINUS: IconName = IconName("circle-minus")
    CIRCLE_NUMBER_0: IconName = IconName("circle-number-0")
    CIRCLE_NUMBER_1: IconName = IconName("circle-number-1")
    CIRCLE_NUMBER_2: IconName = IconName("circle-number-2")
    CIRCLE_NUMBER_3: IconName = IconName("circle-number-3")
    CIRCLE_NUMBER_4: IconName = IconName("circle-number-4")
    CIRCLE_NUMBER_5: IconName = IconName("circle-number-5")
    CIRCLE_NUMBER_6: IconName = IconName("circle-number-6")
    CIRCLE_NUMBER_7: IconName = IconName("circle-number-7")
    CIRCLE_NUMBER_8: IconName = IconName("circle-number-8")
    CIRCLE_NUMBER_9: IconName = IconName("circle-number-9")
    CIRCLE_OFF: IconName = IconName("circle-off")
    CIRCLE_PLUS: IconName = IconName("circle-plus")
    CIRCLE_RECTANGLE: IconName = IconName("circle-rectangle")
    CIRCLE_RECTANGLE_OFF: IconName = IconName("circle-rectangle-off")
    CIRCLE_SQUARE: IconName = IconName("circle-square")
    CIRCLE_TRIANGLE: IconName = IconName("circle-triangle")
    CIRCLE_X: IconName = IconName("circle-x")
    CIRCLE_X_FILLED: IconName = IconName("circle-x-filled")
    CIRCLES: IconName = IconName("circles")
    CIRCLES_FILLED: IconName = IconName("circles-filled")
    CIRCLES_RELATION: IconName = IconName("circles-relation")
    CIRCUIT_AMMETER: IconName = IconName("circuit-ammeter")
    CIRCUIT_BATTERY: IconName = IconName("circuit-battery")
    CIRCUIT_BULB: IconName = IconName("circuit-bulb")
    CIRCUIT_CAPACITOR: IconName = IconName("circuit-capacitor")
    CIRCUIT_CAPACITOR_POLARIZED: IconName = IconName("circuit-capacitor-polarized")
    CIRCUIT_CELL: IconName = IconName("circuit-cell")
    CIRCUIT_CELL_PLUS: IconName = IconName("circuit-cell-plus")
    CIRCUIT_CHANGEOVER: IconName = IconName("circuit-changeover")
    CIRCUIT_DIODE: IconName = IconName("circuit-diode")
    CIRCUIT_DIODE_ZENER: IconName = IconName("circuit-diode-zener")
    CIRCUIT_GROUND: IconName = IconName("circuit-ground")
    CIRCUIT_GROUND_DIGITAL: IconName = IconName("circuit-ground-digital")
    CIRCUIT_INDUCTOR: IconName = IconName("circuit-inductor")
    CIRCUIT_MOTOR: IconName = IconName("circuit-motor")
    CIRCUIT_PUSHBUTTON: IconName = IconName("circuit-pushbutton")
    CIRCUIT_RESISTOR: IconName = IconName("circuit-resistor")
    CIRCUIT_SWITCH_CLOSED: IconName = IconName("circuit-switch-closed")
    CIRCUIT_SWITCH_OPEN: IconName = IconName("circuit-switch-open")
    CIRCUIT_VOLTMETER: IconName = IconName("circuit-voltmeter")
    CLEAR_ALL: IconName = IconName("clear-all")
    CLEAR_FORMATTING: IconName = IconName("clear-formatting")
    CLICK: IconName = IconName("click")
    CLIPBOARD: IconName = IconName("clipboard")
    CLIPBOARD_CHECK: IconName = IconName("clipboard-check")
    CLIPBOARD_COPY: IconName = IconName("clipboard-copy")
    CLIPBOARD_DATA: IconName = IconName("clipboard-data")
    CLIPBOARD_HEART: IconName = IconName("clipboard-heart")
    CLIPBOARD_LIST: IconName = IconName("clipboard-list")
    CLIPBOARD_OFF: IconName = IconName("clipboard-off")
    CLIPBOARD_PLUS: IconName = IconName("clipboard-plus")
    CLIPBOARD_TEXT: IconName = IconName("clipboard-text")
    CLIPBOARD_TYPOGRAPHY: IconName = IconName("clipboard-typography")
    CLIPBOARD_X: IconName = IconName("clipboard-x")
    CLOCK: IconName = IconName("clock")
    CLOCK_2: IconName = IconName("clock-2")
    CLOCK_BOLT: IconName = IconName("clock-bolt")
    CLOCK_CANCEL: IconName = IconName("clock-cancel")
    CLOCK_CHECK: IconName = IconName("clock-check")
    CLOCK_CODE: IconName = IconName("clock-code")
    CLOCK_COG: IconName = IconName("clock-cog")
    CLOCK_DOLLAR: IconName = IconName("clock-dollar")
    CLOCK_DOWN: IconName = IconName("clock-down")
    CLOCK_EDIT: IconName = IconName("clock-edit")
    CLOCK_EXCLAMATION: IconName = IconName("clock-exclamation")
    CLOCK_FILLED: IconName = IconName("clock-filled")
    CLOCK_HEART: IconName = IconName("clock-heart")
    CLOCK_HOUR_1: IconName = IconName("clock-hour-1")
    CLOCK_HOUR_10: IconName = IconName("clock-hour-10")
    CLOCK_HOUR_11: IconName = IconName("clock-hour-11")
    CLOCK_HOUR_12: IconName = IconName("clock-hour-12")
    CLOCK_HOUR_2: IconName = IconName("clock-hour-2")
    CLOCK_HOUR_3: IconName = IconName("clock-hour-3")
    CLOCK_HOUR_4: IconName = IconName("clock-hour-4")
    CLOCK_HOUR_5: IconName = IconName("clock-hour-5")
    CLOCK_HOUR_6: IconName = IconName("clock-hour-6")
    CLOCK_HOUR_7: IconName = IconName("clock-hour-7")
    CLOCK_HOUR_8: IconName = IconName("clock-hour-8")
    CLOCK_HOUR_9: IconName = IconName("clock-hour-9")
    CLOCK_MINUS: IconName = IconName("clock-minus")
    CLOCK_OFF: IconName = IconName("clock-off")
    CLOCK_PAUSE: IconName = IconName("clock-pause")
    CLOCK_PIN: IconName = IconName("clock-pin")
    CLOCK_PLAY: IconName = IconName("clock-play")
    CLOCK_PLUS: IconName = IconName("clock-plus")
    CLOCK_QUESTION: IconName = IconName("clock-question")
    CLOCK_RECORD: IconName = IconName("clock-record")
    CLOCK_SEARCH: IconName = IconName("clock-search")
    CLOCK_SHARE: IconName = IconName("clock-share")
    CLOCK_SHIELD: IconName = IconName("clock-shield")
    CLOCK_STAR: IconName = IconName("clock-star")
    CLOCK_STOP: IconName = IconName("clock-stop")
    CLOCK_UP: IconName = IconName("clock-up")
    CLOCK_X: IconName = IconName("clock-x")
    CLOTHES_RACK: IconName = IconName("clothes-rack")
    CLOTHES_RACK_OFF: IconName = IconName("clothes-rack-off")
    CLOUD: IconName = IconName("cloud")
    CLOUD_BOLT: IconName = IconName("cloud-bolt")
    CLOUD_CANCEL: IconName = IconName("cloud-cancel")
    CLOUD_CHECK: IconName = IconName("cloud-check")
    CLOUD_CODE: IconName = IconName("cloud-code")
    CLOUD_COG: IconName = IconName("cloud-cog")
    CLOUD_COMPUTING: IconName = IconName("cloud-computing")
    CLOUD_DATA_CONNECTION: IconName = IconName("cloud-data-connection")
    CLOUD_DOLLAR: IconName = IconName("cloud-dollar")
    CLOUD_DOWN: IconName = IconName("cloud-down")
    CLOUD_DOWNLOAD: IconName = IconName("cloud-download")
    CLOUD_EXCLAMATION: IconName = IconName("cloud-exclamation")
    CLOUD_FILLED: IconName = IconName("cloud-filled")
    CLOUD_FOG: IconName = IconName("cloud-fog")
    CLOUD_HEART: IconName = IconName("cloud-heart")
    CLOUD_LOCK: IconName = IconName("cloud-lock")
    CLOUD_LOCK_OPEN: IconName = IconName("cloud-lock-open")
    CLOUD_MINUS: IconName = IconName("cloud-minus")
    CLOUD_OFF: IconName = IconName("cloud-off")
    CLOUD_PAUSE: IconName = IconName("cloud-pause")
    CLOUD_PIN: IconName = IconName("cloud-pin")
    CLOUD_PLUS: IconName = IconName("cloud-plus")
    CLOUD_QUESTION: IconName = IconName("cloud-question")
    CLOUD_RAIN: IconName = IconName("cloud-rain")
    CLOUD_SEARCH: IconName = IconName("cloud-search")
    CLOUD_SHARE: IconName = IconName("cloud-share")
    CLOUD_SNOW: IconName = IconName("cloud-snow")
    CLOUD_STAR: IconName = IconName("cloud-star")
    CLOUD_STORM: IconName = IconName("cloud-storm")
    CLOUD_UP: IconName = IconName("cloud-up")
    CLOUD_UPLOAD: IconName = IconName("cloud-upload")
    CLOUD_X: IconName = IconName("cloud-x")
    CLOVER: IconName = IconName("clover")
    CLOVER_2: IconName = IconName("clover-2")
    CLUBS: IconName = IconName("clubs")
    CLUBS_FILLED: IconName = IconName("clubs-filled")
    CODE: IconName = IconName("code")
    CODE_ASTERIX: IconName = IconName("code-asterix")
    CODE_CIRCLE: IconName = IconName("code-circle")
    CODE_CIRCLE_2: IconName = IconName("code-circle-2")
    CODE_DOTS: IconName = IconName("code-dots")
    CODE_MINUS: IconName = IconName("code-minus")
    CODE_OFF: IconName = IconName("code-off")
    CODE_PLUS: IconName = IconName("code-plus")
    COFFEE: IconName = IconName("coffee")
    COFFEE_OFF: IconName = IconName("coffee-off")
    COFFIN: IconName = IconName("coffin")
    COIN: IconName = IconName("coin")
    COIN_BITCOIN: IconName = IconName("coin-bitcoin")
    COIN_EURO: IconName = IconName("coin-euro")
    COIN_MONERO: IconName = IconName("coin-monero")
    COIN_OFF: IconName = IconName("coin-off")
    COIN_POUND: IconName = IconName("coin-pound")
    COIN_RUPEE: IconName = IconName("coin-rupee")
    COIN_YEN: IconName = IconName("coin-yen")
    COIN_YUAN: IconName = IconName("coin-yuan")
    COINS: IconName = IconName("coins")
    COLOR_FILTER: IconName = IconName("color-filter")
    COLOR_PICKER: IconName = IconName("color-picker")
    COLOR_PICKER_OFF: IconName = IconName("color-picker-off")
    COLOR_SWATCH: IconName = IconName("color-swatch")
    COLOR_SWATCH_OFF: IconName = IconName("color-swatch-off")
    COLUMN_INSERT_LEFT: IconName = IconName("column-insert-left")
    COLUMN_INSERT_RIGHT: IconName = IconName("column-insert-right")
    COLUMN_REMOVE: IconName = IconName("column-remove")
    COLUMNS: IconName = IconName("columns")
    COLUMNS_1: IconName = IconName("columns-1")
    COLUMNS_2: IconName = IconName("columns-2")
    COLUMNS_3: IconName = IconName("columns-3")
    COLUMNS_OFF: IconName = IconName("columns-off")
    COMET: IconName = IconName("comet")
    COMMAND: IconName = IconName("command")
    COMMAND_OFF: IconName = IconName("command-off")
    COMPASS: IconName = IconName("compass")
    COMPASS_OFF: IconName = IconName("compass-off")
    COMPONENTS: IconName = IconName("components")
    COMPONENTS_OFF: IconName = IconName("components-off")
    CONE: IconName = IconName("cone")
    CONE_2: IconName = IconName("cone-2")
    CONE_OFF: IconName = IconName("cone-off")
    CONE_PLUS: IconName = IconName("cone-plus")
    CONFETTI: IconName = IconName("confetti")
    CONFETTI_OFF: IconName = IconName("confetti-off")
    CONFUCIUS: IconName = IconName("confucius")
    CONTAINER: IconName = IconName("container")
    CONTAINER_OFF: IconName = IconName("container-off")
    CONTRAST: IconName = IconName("contrast")
    CONTRAST_2: IconName = IconName("contrast-2")
    CONTRAST_2_OFF: IconName = IconName("contrast-2-off")
    CONTRAST_OFF: IconName = IconName("contrast-off")
    COOKER: IconName = IconName("cooker")
    COOKIE: IconName = IconName("cookie")
    COOKIE_MAN: IconName = IconName("cookie-man")
    COOKIE_OFF: IconName = IconName("cookie-off")
    COPY: IconName = IconName("copy")
    COPY_OFF: IconName = IconName("copy-off")
    COPYLEFT: IconName = IconName("copyleft")
    COPYLEFT_FILLED: IconName = IconName("copyleft-filled")
    COPYLEFT_OFF: IconName = IconName("copyleft-off")
    COPYRIGHT: IconName = IconName("copyright")
    COPYRIGHT_FILLED: IconName = IconName("copyright-filled")
    COPYRIGHT_OFF: IconName = IconName("copyright-off")
    CORNER_DOWN_LEFT: IconName = IconName("corner-down-left")
    CORNER_DOWN_LEFT_DOUBLE: IconName = IconName("corner-down-left-double")
    CORNER_DOWN_RIGHT: IconName = IconName("corner-down-right")
    CORNER_DOWN_RIGHT_DOUBLE: IconName = IconName("corner-down-right-double")
    CORNER_LEFT_DOWN: IconName = IconName("corner-left-down")
    CORNER_LEFT_DOWN_DOUBLE: IconName = IconName("corner-left-down-double")
    CORNER_LEFT_UP: IconName = IconName("corner-left-up")
    CORNER_LEFT_UP_DOUBLE: IconName = IconName("corner-left-up-double")
    CORNER_RIGHT_DOWN: IconName = IconName("corner-right-down")
    CORNER_RIGHT_DOWN_DOUBLE: IconName = IconName("corner-right-down-double")
    CORNER_RIGHT_UP: IconName = IconName("corner-right-up")
    CORNER_RIGHT_UP_DOUBLE: IconName = IconName("corner-right-up-double")
    CORNER_UP_LEFT: IconName = IconName("corner-up-left")
    CORNER_UP_LEFT_DOUBLE: IconName = IconName("corner-up-left-double")
    CORNER_UP_RIGHT: IconName = IconName("corner-up-right")
    CORNER_UP_RIGHT_DOUBLE: IconName = IconName("corner-up-right-double")
    CPU: IconName = IconName("cpu")
    CPU_2: IconName = IconName("cpu-2")
    CPU_OFF: IconName = IconName("cpu-off")
    CRANE: IconName = IconName("crane")
    CRANE_OFF: IconName = IconName("crane-off")
    CREATIVE_COMMONS: IconName = IconName("creative-commons")
    CREATIVE_COMMONS_BY: IconName = IconName("creative-commons-by")
    CREATIVE_COMMONS_NC: IconName = IconName("creative-commons-nc")
    CREATIVE_COMMONS_ND: IconName = IconName("creative-commons-nd")
    CREATIVE_COMMONS_OFF: IconName = IconName("creative-commons-off")
    CREATIVE_COMMONS_SA: IconName = IconName("creative-commons-sa")
    CREATIVE_COMMONS_ZERO: IconName = IconName("creative-commons-zero")
    CREDIT_CARD: IconName = IconName("credit-card")
    CREDIT_CARD_OFF: IconName = IconName("credit-card-off")
    CRICKET: IconName = IconName("cricket")
    CROP: IconName = IconName("crop")
    CROSS: IconName = IconName("cross")
    CROSS_FILLED: IconName = IconName("cross-filled")
    CROSS_OFF: IconName = IconName("cross-off")
    CROSSHAIR: IconName = IconName("crosshair")
    CROWN: IconName = IconName("crown")
    CROWN_OFF: IconName = IconName("crown-off")
    CRUTCHES: IconName = IconName("crutches")
    CRUTCHES_OFF: IconName = IconName("crutches-off")
    CRYSTAL_BALL: IconName = IconName("crystal-ball")
    CSV: IconName = IconName("csv")
    CUBE: IconName = IconName("cube")
    CUBE_OFF: IconName = IconName("cube-off")
    CUBE_PLUS: IconName = IconName("cube-plus")
    CUBE_SEND: IconName = IconName("cube-send")
    CUBE_UNFOLDED: IconName = IconName("cube-unfolded")
    CUP: IconName = IconName("cup")
    CUP_OFF: IconName = IconName("cup-off")
    CURLING: IconName = IconName("curling")
    CURLY_LOOP: IconName = IconName("curly-loop")
    CURRENCY: IconName = IconName("currency")
    CURRENCY_AFGHANI: IconName = IconName("currency-afghani")
    CURRENCY_BAHRAINI: IconName = IconName("currency-bahraini")
    CURRENCY_BAHT: IconName = IconName("currency-baht")
    CURRENCY_BITCOIN: IconName = IconName("currency-bitcoin")
    CURRENCY_CENT: IconName = IconName("currency-cent")
    CURRENCY_DINAR: IconName = IconName("currency-dinar")
    CURRENCY_DIRHAM: IconName = IconName("currency-dirham")
    CURRENCY_DOGECOIN: IconName = IconName("currency-dogecoin")
    CURRENCY_DOLLAR: IconName = IconName("currency-dollar")
    CURRENCY_DOLLAR_AUSTRALIAN: IconName = IconName("currency-dollar-australian")
    CURRENCY_DOLLAR_BRUNEI: IconName = IconName("currency-dollar-brunei")
    CURRENCY_DOLLAR_CANADIAN: IconName = IconName("currency-dollar-canadian")
    CURRENCY_DOLLAR_GUYANESE: IconName = IconName("currency-dollar-guyanese")
    CURRENCY_DOLLAR_OFF: IconName = IconName("currency-dollar-off")
    CURRENCY_DOLLAR_SINGAPORE: IconName = IconName("currency-dollar-singapore")
    CURRENCY_DOLLAR_ZIMBABWEAN: IconName = IconName("currency-dollar-zimbabwean")
    CURRENCY_DONG: IconName = IconName("currency-dong")
    CURRENCY_DRAM: IconName = IconName("currency-dram")
    CURRENCY_ETHEREUM: IconName = IconName("currency-ethereum")
    CURRENCY_EURO: IconName = IconName("currency-euro")
    CURRENCY_EURO_OFF: IconName = IconName("currency-euro-off")
    CURRENCY_FLORIN: IconName = IconName("currency-florin")
    CURRENCY_FORINT: IconName = IconName("currency-forint")
    CURRENCY_FRANK: IconName = IconName("currency-frank")
    CURRENCY_GUARANI: IconName = IconName("currency-guarani")
    CURRENCY_HRYVNIA: IconName = IconName("currency-hryvnia")
    CURRENCY_IRANIAN_RIAL: IconName = IconName("currency-iranian-rial")
    CURRENCY_KIP: IconName = IconName("currency-kip")
    CURRENCY_KRONE_CZECH: IconName = IconName("currency-krone-czech")
    CURRENCY_KRONE_DANISH: IconName = IconName("currency-krone-danish")
    CURRENCY_KRONE_SWEDISH: IconName = IconName("currency-krone-swedish")
    CURRENCY_LARI: IconName = IconName("currency-lari")
    CURRENCY_LEU: IconName = IconName("currency-leu")
    CURRENCY_LIRA: IconName = IconName("currency-lira")
    CURRENCY_LITECOIN: IconName = IconName("currency-litecoin")
    CURRENCY_LYD: IconName = IconName("currency-lyd")
    CURRENCY_MANAT: IconName = IconName("currency-manat")
    CURRENCY_MONERO: IconName = IconName("currency-monero")
    CURRENCY_NAIRA: IconName = IconName("currency-naira")
    CURRENCY_NANO: IconName = IconName("currency-nano")
    CURRENCY_OFF: IconName = IconName("currency-off")
    CURRENCY_PAANGA: IconName = IconName("currency-paanga")
    CURRENCY_PESO: IconName = IconName("currency-peso")
    CURRENCY_POUND: IconName = IconName("currency-pound")
    CURRENCY_POUND_OFF: IconName = IconName("currency-pound-off")
    CURRENCY_QUETZAL: IconName = IconName("currency-quetzal")
    CURRENCY_REAL: IconName = IconName("currency-real")
    CURRENCY_RENMINBI: IconName = IconName("currency-renminbi")
    CURRENCY_RIPPLE: IconName = IconName("currency-ripple")
    CURRENCY_RIYAL: IconName = IconName("currency-riyal")
    CURRENCY_RUBEL: IconName = IconName("currency-rubel")
    CURRENCY_RUFIYAA: IconName = IconName("currency-rufiyaa")
    CURRENCY_RUPEE: IconName = IconName("currency-rupee")
    CURRENCY_RUPEE_NEPALESE: IconName = IconName("currency-rupee-nepalese")
    CURRENCY_SHEKEL: IconName = IconName("currency-shekel")
    CURRENCY_SOLANA: IconName = IconName("currency-solana")
    CURRENCY_SOM: IconName = IconName("currency-som")
    CURRENCY_TAKA: IconName = IconName("currency-taka")
    CURRENCY_TENGE: IconName = IconName("currency-tenge")
    CURRENCY_TUGRIK: IconName = IconName("currency-tugrik")
    CURRENCY_WON: IconName = IconName("currency-won")
    CURRENCY_YEN: IconName = IconName("currency-yen")
    CURRENCY_YEN_OFF: IconName = IconName("currency-yen-off")
    CURRENCY_YUAN: IconName = IconName("currency-yuan")
    CURRENCY_ZLOTY: IconName = IconName("currency-zloty")
    CURRENT_LOCATION: IconName = IconName("current-location")
    CURRENT_LOCATION_OFF: IconName = IconName("current-location-off")
    CURSOR_OFF: IconName = IconName("cursor-off")
    CURSOR_TEXT: IconName = IconName("cursor-text")
    CUT: IconName = IconName("cut")
    CYLINDER: IconName = IconName("cylinder")
    CYLINDER_OFF: IconName = IconName("cylinder-off")
    CYLINDER_PLUS: IconName = IconName("cylinder-plus")
    DASHBOARD: IconName = IconName("dashboard")
    DASHBOARD_OFF: IconName = IconName("dashboard-off")
    DATABASE: IconName = IconName("database")
    DATABASE_COG: IconName = IconName("database-cog")
    DATABASE_DOLLAR: IconName = IconName("database-dollar")
    DATABASE_EDIT: IconName = IconName("database-edit")
    DATABASE_EXCLAMATION: IconName = IconName("database-exclamation")
    DATABASE_EXPORT: IconName = IconName("database-export")
    DATABASE_HEART: IconName = IconName("database-heart")
    DATABASE_IMPORT: IconName = IconName("database-import")
    DATABASE_LEAK: IconName = IconName("database-leak")
    DATABASE_MINUS: IconName = IconName("database-minus")
    DATABASE_OFF: IconName = IconName("database-off")
    DATABASE_PLUS: IconName = IconName("database-plus")
    DATABASE_SEARCH: IconName = IconName("database-search")
    DATABASE_SHARE: IconName = IconName("database-share")
    DATABASE_STAR: IconName = IconName("database-star")
    DATABASE_X: IconName = IconName("database-x")
    DECIMAL: IconName = IconName("decimal")
    DEER: IconName = IconName("deer")
    DELTA: IconName = IconName("delta")
    DENTAL: IconName = IconName("dental")
    DENTAL_BROKEN: IconName = IconName("dental-broken")
    DENTAL_OFF: IconName = IconName("dental-off")
    DESELECT: IconName = IconName("deselect")
    DETAILS: IconName = IconName("details")
    DETAILS_OFF: IconName = IconName("details-off")
    DEVICE_AIRPODS: IconName = IconName("device-airpods")
    DEVICE_AIRPODS_CASE: IconName = IconName("device-airpods-case")
    DEVICE_AIRTAG: IconName = IconName("device-airtag")
    DEVICE_ANALYTICS: IconName = IconName("device-analytics")
    DEVICE_AUDIO_TAPE: IconName = IconName("device-audio-tape")
    DEVICE_CAMERA_PHONE: IconName = IconName("device-camera-phone")
    DEVICE_CCTV: IconName = IconName("device-cctv")
    DEVICE_CCTV_OFF: IconName = IconName("device-cctv-off")
    DEVICE_COMPUTER_CAMERA: IconName = IconName("device-computer-camera")
    DEVICE_COMPUTER_CAMERA_OFF: IconName = IconName("device-computer-camera-off")
    DEVICE_DESKTOP: IconName = IconName("device-desktop")
    DEVICE_DESKTOP_ANALYTICS: IconName = IconName("device-desktop-analytics")
    DEVICE_DESKTOP_BOLT: IconName = IconName("device-desktop-bolt")
    DEVICE_DESKTOP_CANCEL: IconName = IconName("device-desktop-cancel")
    DEVICE_DESKTOP_CHECK: IconName = IconName("device-desktop-check")
    DEVICE_DESKTOP_CODE: IconName = IconName("device-desktop-code")
    DEVICE_DESKTOP_COG: IconName = IconName("device-desktop-cog")
    DEVICE_DESKTOP_DOLLAR: IconName = IconName("device-desktop-dollar")
    DEVICE_DESKTOP_DOWN: IconName = IconName("device-desktop-down")
    DEVICE_DESKTOP_EXCLAMATION: IconName = IconName("device-desktop-exclamation")
    DEVICE_DESKTOP_HEART: IconName = IconName("device-desktop-heart")
    DEVICE_DESKTOP_MINUS: IconName = IconName("device-desktop-minus")
    DEVICE_DESKTOP_OFF: IconName = IconName("device-desktop-off")
    DEVICE_DESKTOP_PAUSE: IconName = IconName("device-desktop-pause")
    DEVICE_DESKTOP_PIN: IconName = IconName("device-desktop-pin")
    DEVICE_DESKTOP_PLUS: IconName = IconName("device-desktop-plus")
    DEVICE_DESKTOP_QUESTION: IconName = IconName("device-desktop-question")
    DEVICE_DESKTOP_SEARCH: IconName = IconName("device-desktop-search")
    DEVICE_DESKTOP_SHARE: IconName = IconName("device-desktop-share")
    DEVICE_DESKTOP_STAR: IconName = IconName("device-desktop-star")
    DEVICE_DESKTOP_UP: IconName = IconName("device-desktop-up")
    DEVICE_DESKTOP_X: IconName = IconName("device-desktop-x")
    DEVICE_FLOPPY: IconName = IconName("device-floppy")
    DEVICE_GAMEPAD: IconName = IconName("device-gamepad")
    DEVICE_GAMEPAD_2: IconName = IconName("device-gamepad-2")
    DEVICE_HEART_MONITOR: IconName = IconName("device-heart-monitor")
    DEVICE_HEART_MONITOR_FILLED: IconName = IconName("device-heart-monitor-filled")
    DEVICE_IMAC: IconName = IconName("device-imac")
    DEVICE_IMAC_BOLT: IconName = IconName("device-imac-bolt")
    DEVICE_IMAC_CANCEL: IconName = IconName("device-imac-cancel")
    DEVICE_IMAC_CHECK: IconName = IconName("device-imac-check")
    DEVICE_IMAC_CODE: IconName = IconName("device-imac-code")
    DEVICE_IMAC_COG: IconName = IconName("device-imac-cog")
    DEVICE_IMAC_DOLLAR: IconName = IconName("device-imac-dollar")
    DEVICE_IMAC_DOWN: IconName = IconName("device-imac-down")
    DEVICE_IMAC_EXCLAMATION: IconName = IconName("device-imac-exclamation")
    DEVICE_IMAC_HEART: IconName = IconName("device-imac-heart")
    DEVICE_IMAC_MINUS: IconName = IconName("device-imac-minus")
    DEVICE_IMAC_OFF: IconName = IconName("device-imac-off")
    DEVICE_IMAC_PAUSE: IconName = IconName("device-imac-pause")
    DEVICE_IMAC_PIN: IconName = IconName("device-imac-pin")
    DEVICE_IMAC_PLUS: IconName = IconName("device-imac-plus")
    DEVICE_IMAC_QUESTION: IconName = IconName("device-imac-question")
    DEVICE_IMAC_SEARCH: IconName = IconName("device-imac-search")
    DEVICE_IMAC_SHARE: IconName = IconName("device-imac-share")
    DEVICE_IMAC_STAR: IconName = IconName("device-imac-star")
    DEVICE_IMAC_UP: IconName = IconName("device-imac-up")
    DEVICE_IMAC_X: IconName = IconName("device-imac-x")
    DEVICE_IPAD: IconName = IconName("device-ipad")
    DEVICE_IPAD_BOLT: IconName = IconName("device-ipad-bolt")
    DEVICE_IPAD_CANCEL: IconName = IconName("device-ipad-cancel")
    DEVICE_IPAD_CHECK: IconName = IconName("device-ipad-check")
    DEVICE_IPAD_CODE: IconName = IconName("device-ipad-code")
    DEVICE_IPAD_COG: IconName = IconName("device-ipad-cog")
    DEVICE_IPAD_DOLLAR: IconName = IconName("device-ipad-dollar")
    DEVICE_IPAD_DOWN: IconName = IconName("device-ipad-down")
    DEVICE_IPAD_EXCLAMATION: IconName = IconName("device-ipad-exclamation")
    DEVICE_IPAD_HEART: IconName = IconName("device-ipad-heart")
    DEVICE_IPAD_HORIZONTAL: IconName = IconName("device-ipad-horizontal")
    DEVICE_IPAD_HORIZONTAL_BOLT: IconName = IconName("device-ipad-horizontal-bolt")
    DEVICE_IPAD_HORIZONTAL_CANCEL: IconName = IconName("device-ipad-horizontal-cancel")
    DEVICE_IPAD_HORIZONTAL_CHECK: IconName = IconName("device-ipad-horizontal-check")
    DEVICE_IPAD_HORIZONTAL_CODE: IconName = IconName("device-ipad-horizontal-code")
    DEVICE_IPAD_HORIZONTAL_COG: IconName = IconName("device-ipad-horizontal-cog")
    DEVICE_IPAD_HORIZONTAL_DOLLAR: IconName = IconName("device-ipad-horizontal-dollar")
    DEVICE_IPAD_HORIZONTAL_DOWN: IconName = IconName("device-ipad-horizontal-down")
    DEVICE_IPAD_HORIZONTAL_EXCLAMATION: IconName = IconName(
        "device-ipad-horizontal-exclamation"
    )
    DEVICE_IPAD_HORIZONTAL_HEART: IconName = IconName("device-ipad-horizontal-heart")
    DEVICE_IPAD_HORIZONTAL_MINUS: IconName = IconName("device-ipad-horizontal-minus")
    DEVICE_IPAD_HORIZONTAL_OFF: IconName = IconName("device-ipad-horizontal-off")
    DEVICE_IPAD_HORIZONTAL_PAUSE: IconName = IconName("device-ipad-horizontal-pause")
    DEVICE_IPAD_HORIZONTAL_PIN: IconName = IconName("device-ipad-horizontal-pin")
    DEVICE_IPAD_HORIZONTAL_PLUS: IconName = IconName("device-ipad-horizontal-plus")
    DEVICE_IPAD_HORIZONTAL_QUESTION: IconName = IconName(
        "device-ipad-horizontal-question"
    )
    DEVICE_IPAD_HORIZONTAL_SEARCH: IconName = IconName("device-ipad-horizontal-search")
    DEVICE_IPAD_HORIZONTAL_SHARE: IconName = IconName("device-ipad-horizontal-share")
    DEVICE_IPAD_HORIZONTAL_STAR: IconName = IconName("device-ipad-horizontal-star")
    DEVICE_IPAD_HORIZONTAL_UP: IconName = IconName("device-ipad-horizontal-up")
    DEVICE_IPAD_HORIZONTAL_X: IconName = IconName("device-ipad-horizontal-x")
    DEVICE_IPAD_MINUS: IconName = IconName("device-ipad-minus")
    DEVICE_IPAD_OFF: IconName = IconName("device-ipad-off")
    DEVICE_IPAD_PAUSE: IconName = IconName("device-ipad-pause")
    DEVICE_IPAD_PIN: IconName = IconName("device-ipad-pin")
    DEVICE_IPAD_PLUS: IconName = IconName("device-ipad-plus")
    DEVICE_IPAD_QUESTION: IconName = IconName("device-ipad-question")
    DEVICE_IPAD_SEARCH: IconName = IconName("device-ipad-search")
    DEVICE_IPAD_SHARE: IconName = IconName("device-ipad-share")
    DEVICE_IPAD_STAR: IconName = IconName("device-ipad-star")
    DEVICE_IPAD_UP: IconName = IconName("device-ipad-up")
    DEVICE_IPAD_X: IconName = IconName("device-ipad-x")
    DEVICE_LANDLINE_PHONE: IconName = IconName("device-landline-phone")
    DEVICE_LAPTOP: IconName = IconName("device-laptop")
    DEVICE_LAPTOP_OFF: IconName = IconName("device-laptop-off")
    DEVICE_MOBILE: IconName = IconName("device-mobile")
    DEVICE_MOBILE_BOLT: IconName = IconName("device-mobile-bolt")
    DEVICE_MOBILE_CANCEL: IconName = IconName("device-mobile-cancel")
    DEVICE_MOBILE_CHARGING: IconName = IconName("device-mobile-charging")
    DEVICE_MOBILE_CHECK: IconName = IconName("device-mobile-check")
    DEVICE_MOBILE_CODE: IconName = IconName("device-mobile-code")
    DEVICE_MOBILE_COG: IconName = IconName("device-mobile-cog")
    DEVICE_MOBILE_DOLLAR: IconName = IconName("device-mobile-dollar")
    DEVICE_MOBILE_DOWN: IconName = IconName("device-mobile-down")
    DEVICE_MOBILE_EXCLAMATION: IconName = IconName("device-mobile-exclamation")
    DEVICE_MOBILE_FILLED: IconName = IconName("device-mobile-filled")
    DEVICE_MOBILE_HEART: IconName = IconName("device-mobile-heart")
    DEVICE_MOBILE_MESSAGE: IconName = IconName("device-mobile-message")
    DEVICE_MOBILE_MINUS: IconName = IconName("device-mobile-minus")
    DEVICE_MOBILE_OFF: IconName = IconName("device-mobile-off")
    DEVICE_MOBILE_PAUSE: IconName = IconName("device-mobile-pause")
    DEVICE_MOBILE_PIN: IconName = IconName("device-mobile-pin")
    DEVICE_MOBILE_PLUS: IconName = IconName("device-mobile-plus")
    DEVICE_MOBILE_QUESTION: IconName = IconName("device-mobile-question")
    DEVICE_MOBILE_ROTATED: IconName = IconName("device-mobile-rotated")
    DEVICE_MOBILE_SEARCH: IconName = IconName("device-mobile-search")
    DEVICE_MOBILE_SHARE: IconName = IconName("device-mobile-share")
    DEVICE_MOBILE_STAR: IconName = IconName("device-mobile-star")
    DEVICE_MOBILE_UP: IconName = IconName("device-mobile-up")
    DEVICE_MOBILE_VIBRATION: IconName = IconName("device-mobile-vibration")
    DEVICE_MOBILE_X: IconName = IconName("device-mobile-x")
    DEVICE_NINTENDO: IconName = IconName("device-nintendo")
    DEVICE_NINTENDO_OFF: IconName = IconName("device-nintendo-off")
    DEVICE_REMOTE: IconName = IconName("device-remote")
    DEVICE_SD_CARD: IconName = IconName("device-sd-card")
    DEVICE_SIM: IconName = IconName("device-sim")
    DEVICE_SIM_1: IconName = IconName("device-sim-1")
    DEVICE_SIM_2: IconName = IconName("device-sim-2")
    DEVICE_SIM_3: IconName = IconName("device-sim-3")
    DEVICE_SPEAKER: IconName = IconName("device-speaker")
    DEVICE_SPEAKER_OFF: IconName = IconName("device-speaker-off")
    DEVICE_TABLET: IconName = IconName("device-tablet")
    DEVICE_TABLET_BOLT: IconName = IconName("device-tablet-bolt")
    DEVICE_TABLET_CANCEL: IconName = IconName("device-tablet-cancel")
    DEVICE_TABLET_CHECK: IconName = IconName("device-tablet-check")
    DEVICE_TABLET_CODE: IconName = IconName("device-tablet-code")
    DEVICE_TABLET_COG: IconName = IconName("device-tablet-cog")
    DEVICE_TABLET_DOLLAR: IconName = IconName("device-tablet-dollar")
    DEVICE_TABLET_DOWN: IconName = IconName("device-tablet-down")
    DEVICE_TABLET_EXCLAMATION: IconName = IconName("device-tablet-exclamation")
    DEVICE_TABLET_FILLED: IconName = IconName("device-tablet-filled")
    DEVICE_TABLET_HEART: IconName = IconName("device-tablet-heart")
    DEVICE_TABLET_MINUS: IconName = IconName("device-tablet-minus")
    DEVICE_TABLET_OFF: IconName = IconName("device-tablet-off")
    DEVICE_TABLET_PAUSE: IconName = IconName("device-tablet-pause")
    DEVICE_TABLET_PIN: IconName = IconName("device-tablet-pin")
    DEVICE_TABLET_PLUS: IconName = IconName("device-tablet-plus")
    DEVICE_TABLET_QUESTION: IconName = IconName("device-tablet-question")
    DEVICE_TABLET_SEARCH: IconName = IconName("device-tablet-search")
    DEVICE_TABLET_SHARE: IconName = IconName("device-tablet-share")
    DEVICE_TABLET_STAR: IconName = IconName("device-tablet-star")
    DEVICE_TABLET_UP: IconName = IconName("device-tablet-up")
    DEVICE_TABLET_X: IconName = IconName("device-tablet-x")
    DEVICE_TV: IconName = IconName("device-tv")
    DEVICE_TV_OFF: IconName = IconName("device-tv-off")
    DEVICE_TV_OLD: IconName = IconName("device-tv-old")
    DEVICE_VISION_PRO: IconName = IconName("device-vision-pro")
    DEVICE_WATCH: IconName = IconName("device-watch")
    DEVICE_WATCH_BOLT: IconName = IconName("device-watch-bolt")
    DEVICE_WATCH_CANCEL: IconName = IconName("device-watch-cancel")
    DEVICE_WATCH_CHECK: IconName = IconName("device-watch-check")
    DEVICE_WATCH_CODE: IconName = IconName("device-watch-code")
    DEVICE_WATCH_COG: IconName = IconName("device-watch-cog")
    DEVICE_WATCH_DOLLAR: IconName = IconName("device-watch-dollar")
    DEVICE_WATCH_DOWN: IconName = IconName("device-watch-down")
    DEVICE_WATCH_EXCLAMATION: IconName = IconName("device-watch-exclamation")
    DEVICE_WATCH_HEART: IconName = IconName("device-watch-heart")
    DEVICE_WATCH_MINUS: IconName = IconName("device-watch-minus")
    DEVICE_WATCH_OFF: IconName = IconName("device-watch-off")
    DEVICE_WATCH_PAUSE: IconName = IconName("device-watch-pause")
    DEVICE_WATCH_PIN: IconName = IconName("device-watch-pin")
    DEVICE_WATCH_PLUS: IconName = IconName("device-watch-plus")
    DEVICE_WATCH_QUESTION: IconName = IconName("device-watch-question")
    DEVICE_WATCH_SEARCH: IconName = IconName("device-watch-search")
    DEVICE_WATCH_SHARE: IconName = IconName("device-watch-share")
    DEVICE_WATCH_STAR: IconName = IconName("device-watch-star")
    DEVICE_WATCH_STATS: IconName = IconName("device-watch-stats")
    DEVICE_WATCH_STATS_2: IconName = IconName("device-watch-stats-2")
    DEVICE_WATCH_UP: IconName = IconName("device-watch-up")
    DEVICE_WATCH_X: IconName = IconName("device-watch-x")
    DEVICES: IconName = IconName("devices")
    DEVICES_2: IconName = IconName("devices-2")
    DEVICES_BOLT: IconName = IconName("devices-bolt")
    DEVICES_CANCEL: IconName = IconName("devices-cancel")
    DEVICES_CHECK: IconName = IconName("devices-check")
    DEVICES_CODE: IconName = IconName("devices-code")
    DEVICES_COG: IconName = IconName("devices-cog")
    DEVICES_DOLLAR: IconName = IconName("devices-dollar")
    DEVICES_DOWN: IconName = IconName("devices-down")
    DEVICES_EXCLAMATION: IconName = IconName("devices-exclamation")
    DEVICES_HEART: IconName = IconName("devices-heart")
    DEVICES_MINUS: IconName = IconName("devices-minus")
    DEVICES_OFF: IconName = IconName("devices-off")
    DEVICES_PAUSE: IconName = IconName("devices-pause")
    DEVICES_PC: IconName = IconName("devices-pc")
    DEVICES_PC_OFF: IconName = IconName("devices-pc-off")
    DEVICES_PIN: IconName = IconName("devices-pin")
    DEVICES_PLUS: IconName = IconName("devices-plus")
    DEVICES_QUESTION: IconName = IconName("devices-question")
    DEVICES_SEARCH: IconName = IconName("devices-search")
    DEVICES_SHARE: IconName = IconName("devices-share")
    DEVICES_STAR: IconName = IconName("devices-star")
    DEVICES_UP: IconName = IconName("devices-up")
    DEVICES_X: IconName = IconName("devices-x")
    DIABOLO: IconName = IconName("diabolo")
    DIABOLO_OFF: IconName = IconName("diabolo-off")
    DIABOLO_PLUS: IconName = IconName("diabolo-plus")
    DIALPAD: IconName = IconName("dialpad")
    DIALPAD_FILLED: IconName = IconName("dialpad-filled")
    DIALPAD_OFF: IconName = IconName("dialpad-off")
    DIAMOND: IconName = IconName("diamond")
    DIAMOND_FILLED: IconName = IconName("diamond-filled")
    DIAMOND_OFF: IconName = IconName("diamond-off")
    DIAMONDS: IconName = IconName("diamonds")
    DIAMONDS_FILLED: IconName = IconName("diamonds-filled")
    DICE: IconName = IconName("dice")
    DICE_1: IconName = IconName("dice-1")
    DICE_1_FILLED: IconName = IconName("dice-1-filled")
    DICE_2: IconName = IconName("dice-2")
    DICE_2_FILLED: IconName = IconName("dice-2-filled")
    DICE_3: IconName = IconName("dice-3")
    DICE_3_FILLED: IconName = IconName("dice-3-filled")
    DICE_4: IconName = IconName("dice-4")
    DICE_4_FILLED: IconName = IconName("dice-4-filled")
    DICE_5: IconName = IconName("dice-5")
    DICE_5_FILLED: IconName = IconName("dice-5-filled")
    DICE_6: IconName = IconName("dice-6")
    DICE_6_FILLED: IconName = IconName("dice-6-filled")
    DICE_FILLED: IconName = IconName("dice-filled")
    DIMENSIONS: IconName = IconName("dimensions")
    DIRECTION: IconName = IconName("direction")
    DIRECTION_HORIZONTAL: IconName = IconName("direction-horizontal")
    DIRECTION_SIGN: IconName = IconName("direction-sign")
    DIRECTION_SIGN_FILLED: IconName = IconName("direction-sign-filled")
    DIRECTION_SIGN_OFF: IconName = IconName("direction-sign-off")
    DIRECTIONS: IconName = IconName("directions")
    DIRECTIONS_OFF: IconName = IconName("directions-off")
    DISABLED: IconName = IconName("disabled")
    DISABLED_2: IconName = IconName("disabled-2")
    DISABLED_OFF: IconName = IconName("disabled-off")
    DISC: IconName = IconName("disc")
    DISC_GOLF: IconName = IconName("disc-golf")
    DISC_OFF: IconName = IconName("disc-off")
    DISCOUNT: IconName = IconName("discount")
    DISCOUNT_2: IconName = IconName("discount-2")
    DISCOUNT_2_OFF: IconName = IconName("discount-2-off")
    DISCOUNT_CHECK: IconName = IconName("discount-check")
    DISCOUNT_CHECK_FILLED: IconName = IconName("discount-check-filled")
    DISCOUNT_OFF: IconName = IconName("discount-off")
    DIVIDE: IconName = IconName("divide")
    DNA: IconName = IconName("dna")
    DNA_2: IconName = IconName("dna-2")
    DNA_2_OFF: IconName = IconName("dna-2-off")
    DNA_OFF: IconName = IconName("dna-off")
    DOG: IconName = IconName("dog")
    DOG_BOWL: IconName = IconName("dog-bowl")
    DOOR: IconName = IconName("door")
    DOOR_ENTER: IconName = IconName("door-enter")
    DOOR_EXIT: IconName = IconName("door-exit")
    DOOR_OFF: IconName = IconName("door-off")
    DOTS: IconName = IconName("dots")
    DOTS_CIRCLE_HORIZONTAL: IconName = IconName("dots-circle-horizontal")
    DOTS_DIAGONAL: IconName = IconName("dots-diagonal")
    DOTS_DIAGONAL_2: IconName = IconName("dots-diagonal-2")
    DOTS_VERTICAL: IconName = IconName("dots-vertical")
    DOWNLOAD: IconName = IconName("download")
    DOWNLOAD_OFF: IconName = IconName("download-off")
    DRAG_DROP: IconName = IconName("drag-drop")
    DRAG_DROP_2: IconName = IconName("drag-drop-2")
    DRONE: IconName = IconName("drone")
    DRONE_OFF: IconName = IconName("drone-off")
    DROP_CIRCLE: IconName = IconName("drop-circle")
    DROPLET: IconName = IconName("droplet")
    DROPLET_BOLT: IconName = IconName("droplet-bolt")
    DROPLET_CANCEL: IconName = IconName("droplet-cancel")
    DROPLET_CHECK: IconName = IconName("droplet-check")
    DROPLET_CODE: IconName = IconName("droplet-code")
    DROPLET_COG: IconName = IconName("droplet-cog")
    DROPLET_DOLLAR: IconName = IconName("droplet-dollar")
    DROPLET_DOWN: IconName = IconName("droplet-down")
    DROPLET_EXCLAMATION: IconName = IconName("droplet-exclamation")
    DROPLET_FILLED: IconName = IconName("droplet-filled")
    DROPLET_FILLED_2: IconName = IconName("droplet-filled-2")
    DROPLET_HALF: IconName = IconName("droplet-half")
    DROPLET_HALF_2: IconName = IconName("droplet-half-2")
    DROPLET_HALF_FILLED: IconName = IconName("droplet-half-filled")
    DROPLET_HEART: IconName = IconName("droplet-heart")
    DROPLET_MINUS: IconName = IconName("droplet-minus")
    DROPLET_OFF: IconName = IconName("droplet-off")
    DROPLET_PAUSE: IconName = IconName("droplet-pause")
    DROPLET_PIN: IconName = IconName("droplet-pin")
    DROPLET_PLUS: IconName = IconName("droplet-plus")
    DROPLET_QUESTION: IconName = IconName("droplet-question")
    DROPLET_SEARCH: IconName = IconName("droplet-search")
    DROPLET_SHARE: IconName = IconName("droplet-share")
    DROPLET_STAR: IconName = IconName("droplet-star")
    DROPLET_UP: IconName = IconName("droplet-up")
    DROPLET_X: IconName = IconName("droplet-x")
    DUAL_SCREEN: IconName = IconName("dual-screen")
    E_PASSPORT: IconName = IconName("e-passport")
    EAR: IconName = IconName("ear")
    EAR_OFF: IconName = IconName("ear-off")
    EASE_IN: IconName = IconName("ease-in")
    EASE_IN_CONTROL_POINT: IconName = IconName("ease-in-control-point")
    EASE_IN_OUT: IconName = IconName("ease-in-out")
    EASE_IN_OUT_CONTROL_POINTS: IconName = IconName("ease-in-out-control-points")
    EASE_OUT: IconName = IconName("ease-out")
    EASE_OUT_CONTROL_POINT: IconName = IconName("ease-out-control-point")
    EDIT: IconName = IconName("edit")
    EDIT_CIRCLE: IconName = IconName("edit-circle")
    EDIT_CIRCLE_OFF: IconName = IconName("edit-circle-off")
    EDIT_OFF: IconName = IconName("edit-off")
    EGG: IconName = IconName("egg")
    EGG_CRACKED: IconName = IconName("egg-cracked")
    EGG_FILLED: IconName = IconName("egg-filled")
    EGG_FRIED: IconName = IconName("egg-fried")
    EGG_OFF: IconName = IconName("egg-off")
    EGGS: IconName = IconName("eggs")
    ELEVATOR: IconName = IconName("elevator")
    ELEVATOR_OFF: IconName = IconName("elevator-off")
    EMERGENCY_BED: IconName = IconName("emergency-bed")
    EMPATHIZE: IconName = IconName("empathize")
    EMPATHIZE_OFF: IconName = IconName("empathize-off")
    EMPHASIS: IconName = IconName("emphasis")
    ENGINE: IconName = IconName("engine")
    ENGINE_OFF: IconName = IconName("engine-off")
    EQUAL: IconName = IconName("equal")
    EQUAL_DOUBLE: IconName = IconName("equal-double")
    EQUAL_NOT: IconName = IconName("equal-not")
    ERASER: IconName = IconName("eraser")
    ERASER_OFF: IconName = IconName("eraser-off")
    ERROR_404: IconName = IconName("error-404")
    ERROR_404_OFF: IconName = IconName("error-404-off")
    EXCHANGE: IconName = IconName("exchange")
    EXCHANGE_OFF: IconName = IconName("exchange-off")
    EXCLAMATION_CIRCLE: IconName = IconName("exclamation-circle")
    EXCLAMATION_MARK: IconName = IconName("exclamation-mark")
    EXCLAMATION_MARK_OFF: IconName = IconName("exclamation-mark-off")
    EXPLICIT: IconName = IconName("explicit")
    EXPLICIT_OFF: IconName = IconName("explicit-off")
    EXPOSURE: IconName = IconName("exposure")
    EXPOSURE_0: IconName = IconName("exposure-0")
    EXPOSURE_MINUS_1: IconName = IconName("exposure-minus-1")
    EXPOSURE_MINUS_2: IconName = IconName("exposure-minus-2")
    EXPOSURE_OFF: IconName = IconName("exposure-off")
    EXPOSURE_PLUS_1: IconName = IconName("exposure-plus-1")
    EXPOSURE_PLUS_2: IconName = IconName("exposure-plus-2")
    EXTERNAL_LINK: IconName = IconName("external-link")
    EXTERNAL_LINK_OFF: IconName = IconName("external-link-off")
    EYE: IconName = IconName("eye")
    EYE_CHECK: IconName = IconName("eye-check")
    EYE_CLOSED: IconName = IconName("eye-closed")
    EYE_COG: IconName = IconName("eye-cog")
    EYE_EDIT: IconName = IconName("eye-edit")
    EYE_EXCLAMATION: IconName = IconName("eye-exclamation")
    EYE_FILLED: IconName = IconName("eye-filled")
    EYE_HEART: IconName = IconName("eye-heart")
    EYE_OFF: IconName = IconName("eye-off")
    EYE_TABLE: IconName = IconName("eye-table")
    EYE_X: IconName = IconName("eye-x")
    EYEGLASS: IconName = IconName("eyeglass")
    EYEGLASS_2: IconName = IconName("eyeglass-2")
    EYEGLASS_OFF: IconName = IconName("eyeglass-off")
    FACE_ID: IconName = IconName("face-id")
    FACE_ID_ERROR: IconName = IconName("face-id-error")
    FACE_MASK: IconName = IconName("face-mask")
    FACE_MASK_OFF: IconName = IconName("face-mask-off")
    FALL: IconName = IconName("fall")
    FEATHER: IconName = IconName("feather")
    FEATHER_OFF: IconName = IconName("feather-off")
    FENCE: IconName = IconName("fence")
    FENCE_OFF: IconName = IconName("fence-off")
    FIDGET_SPINNER: IconName = IconName("fidget-spinner")
    FILE: IconName = IconName("file")
    FILE_3D: IconName = IconName("file-3d")
    FILE_ALERT: IconName = IconName("file-alert")
    FILE_ANALYTICS: IconName = IconName("file-analytics")
    FILE_ARROW_LEFT: IconName = IconName("file-arrow-left")
    FILE_ARROW_RIGHT: IconName = IconName("file-arrow-right")
    FILE_BARCODE: IconName = IconName("file-barcode")
    FILE_BROKEN: IconName = IconName("file-broken")
    FILE_CERTIFICATE: IconName = IconName("file-certificate")
    FILE_CHART: IconName = IconName("file-chart")
    FILE_CHECK: IconName = IconName("file-check")
    FILE_CODE: IconName = IconName("file-code")
    FILE_CODE_2: IconName = IconName("file-code-2")
    FILE_CV: IconName = IconName("file-cv")
    FILE_DATABASE: IconName = IconName("file-database")
    FILE_DELTA: IconName = IconName("file-delta")
    FILE_DESCRIPTION: IconName = IconName("file-description")
    FILE_DIFF: IconName = IconName("file-diff")
    FILE_DIGIT: IconName = IconName("file-digit")
    FILE_DISLIKE: IconName = IconName("file-dislike")
    FILE_DOLLAR: IconName = IconName("file-dollar")
    FILE_DOTS: IconName = IconName("file-dots")
    FILE_DOWNLOAD: IconName = IconName("file-download")
    FILE_EURO: IconName = IconName("file-euro")
    FILE_EXPORT: IconName = IconName("file-export")
    FILE_FILLED: IconName = IconName("file-filled")
    FILE_FUNCTION: IconName = IconName("file-function")
    FILE_HORIZONTAL: IconName = IconName("file-horizontal")
    FILE_IMPORT: IconName = IconName("file-import")
    FILE_INFINITY: IconName = IconName("file-infinity")
    FILE_INFO: IconName = IconName("file-info")
    FILE_INVOICE: IconName = IconName("file-invoice")
    FILE_LAMBDA: IconName = IconName("file-lambda")
    FILE_LIKE: IconName = IconName("file-like")
    FILE_MINUS: IconName = IconName("file-minus")
    FILE_MUSIC: IconName = IconName("file-music")
    FILE_OFF: IconName = IconName("file-off")
    FILE_ORIENTATION: IconName = IconName("file-orientation")
    FILE_PENCIL: IconName = IconName("file-pencil")
    FILE_PERCENT: IconName = IconName("file-percent")
    FILE_PHONE: IconName = IconName("file-phone")
    FILE_PLUS: IconName = IconName("file-plus")
    FILE_POWER: IconName = IconName("file-power")
    FILE_REPORT: IconName = IconName("file-report")
    FILE_RSS: IconName = IconName("file-rss")
    FILE_SCISSORS: IconName = IconName("file-scissors")
    FILE_SEARCH: IconName = IconName("file-search")
    FILE_SETTINGS: IconName = IconName("file-settings")
    FILE_SHREDDER: IconName = IconName("file-shredder")
    FILE_SIGNAL: IconName = IconName("file-signal")
    FILE_SPREADSHEET: IconName = IconName("file-spreadsheet")
    FILE_STACK: IconName = IconName("file-stack")
    FILE_STAR: IconName = IconName("file-star")
    FILE_SYMLINK: IconName = IconName("file-symlink")
    FILE_TEXT: IconName = IconName("file-text")
    FILE_TEXT_AI: IconName = IconName("file-text-ai")
    FILE_TIME: IconName = IconName("file-time")
    FILE_TYPOGRAPHY: IconName = IconName("file-typography")
    FILE_UNKNOWN: IconName = IconName("file-unknown")
    FILE_UPLOAD: IconName = IconName("file-upload")
    FILE_VECTOR: IconName = IconName("file-vector")
    FILE_X: IconName = IconName("file-x")
    FILE_X_FILLED: IconName = IconName("file-x-filled")
    FILE_ZIP: IconName = IconName("file-zip")
    FILES: IconName = IconName("files")
    FILES_OFF: IconName = IconName("files-off")
    FILTER: IconName = IconName("filter")
    FILTER_COG: IconName = IconName("filter-cog")
    FILTER_DOLLAR: IconName = IconName("filter-dollar")
    FILTER_EDIT: IconName = IconName("filter-edit")
    FILTER_MINUS: IconName = IconName("filter-minus")
    FILTER_OFF: IconName = IconName("filter-off")
    FILTER_PLUS: IconName = IconName("filter-plus")
    FILTER_STAR: IconName = IconName("filter-star")
    FILTER_X: IconName = IconName("filter-x")
    FILTERS: IconName = IconName("filters")
    FINGERPRINT: IconName = IconName("fingerprint")
    FINGERPRINT_OFF: IconName = IconName("fingerprint-off")
    FIRE_EXTINGUISHER: IconName = IconName("fire-extinguisher")
    FIRE_HYDRANT: IconName = IconName("fire-hydrant")
    FIRE_HYDRANT_OFF: IconName = IconName("fire-hydrant-off")
    FIRETRUCK: IconName = IconName("firetruck")
    FIRST_AID_KIT: IconName = IconName("first-aid-kit")
    FIRST_AID_KIT_OFF: IconName = IconName("first-aid-kit-off")
    FISH: IconName = IconName("fish")
    FISH_BONE: IconName = IconName("fish-bone")
    FISH_CHRISTIANITY: IconName = IconName("fish-christianity")
    FISH_HOOK: IconName = IconName("fish-hook")
    FISH_HOOK_OFF: IconName = IconName("fish-hook-off")
    FISH_OFF: IconName = IconName("fish-off")
    FLAG: IconName = IconName("flag")
    FLAG_2: IconName = IconName("flag-2")
    FLAG_2_FILLED: IconName = IconName("flag-2-filled")
    FLAG_2_OFF: IconName = IconName("flag-2-off")
    FLAG_3: IconName = IconName("flag-3")
    FLAG_3_FILLED: IconName = IconName("flag-3-filled")
    FLAG_FILLED: IconName = IconName("flag-filled")
    FLAG_OFF: IconName = IconName("flag-off")
    FLAME: IconName = IconName("flame")
    FLAME_OFF: IconName = IconName("flame-off")
    FLARE: IconName = IconName("flare")
    FLASK: IconName = IconName("flask")
    FLASK_2: IconName = IconName("flask-2")
    FLASK_2_OFF: IconName = IconName("flask-2-off")
    FLASK_OFF: IconName = IconName("flask-off")
    FLIP_FLOPS: IconName = IconName("flip-flops")
    FLIP_HORIZONTAL: IconName = IconName("flip-horizontal")
    FLIP_VERTICAL: IconName = IconName("flip-vertical")
    FLOAT_CENTER: IconName = IconName("float-center")
    FLOAT_LEFT: IconName = IconName("float-left")
    FLOAT_NONE: IconName = IconName("float-none")
    FLOAT_RIGHT: IconName = IconName("float-right")
    FLOWER: IconName = IconName("flower")
    FLOWER_OFF: IconName = IconName("flower-off")
    FOCUS: IconName = IconName("focus")
    FOCUS_2: IconName = IconName("focus-2")
    FOCUS_AUTO: IconName = IconName("focus-auto")
    FOCUS_CENTERED: IconName = IconName("focus-centered")
    FOLD: IconName = IconName("fold")
    FOLD_DOWN: IconName = IconName("fold-down")
    FOLD_UP: IconName = IconName("fold-up")
    FOLDER: IconName = IconName("folder")
    FOLDER_BOLT: IconName = IconName("folder-bolt")
    FOLDER_CANCEL: IconName = IconName("folder-cancel")
    FOLDER_CHECK: IconName = IconName("folder-check")
    FOLDER_CODE: IconName = IconName("folder-code")
    FOLDER_COG: IconName = IconName("folder-cog")
    FOLDER_DOLLAR: IconName = IconName("folder-dollar")
    FOLDER_DOWN: IconName = IconName("folder-down")
    FOLDER_EXCLAMATION: IconName = IconName("folder-exclamation")
    FOLDER_FILLED: IconName = IconName("folder-filled")
    FOLDER_HEART: IconName = IconName("folder-heart")
    FOLDER_MINUS: IconName = IconName("folder-minus")
    FOLDER_OFF: IconName = IconName("folder-off")
    FOLDER_OPEN: IconName = IconName("folder-open")
    FOLDER_PAUSE: IconName = IconName("folder-pause")
    FOLDER_PIN: IconName = IconName("folder-pin")
    FOLDER_PLUS: IconName = IconName("folder-plus")
    FOLDER_QUESTION: IconName = IconName("folder-question")
    FOLDER_SEARCH: IconName = IconName("folder-search")
    FOLDER_SHARE: IconName = IconName("folder-share")
    FOLDER_STAR: IconName = IconName("folder-star")
    FOLDER_SYMLINK: IconName = IconName("folder-symlink")
    FOLDER_UP: IconName = IconName("folder-up")
    FOLDER_X: IconName = IconName("folder-x")
    FOLDERS: IconName = IconName("folders")
    FOLDERS_OFF: IconName = IconName("folders-off")
    FORBID: IconName = IconName("forbid")
    FORBID_2: IconName = IconName("forbid-2")
    FORKLIFT: IconName = IconName("forklift")
    FORMS: IconName = IconName("forms")
    FOUNTAIN: IconName = IconName("fountain")
    FOUNTAIN_OFF: IconName = IconName("fountain-off")
    FRAME: IconName = IconName("frame")
    FRAME_OFF: IconName = IconName("frame-off")
    FREE_RIGHTS: IconName = IconName("free-rights")
    FREEZE_COLUMN: IconName = IconName("freeze-column")
    FREEZE_ROW: IconName = IconName("freeze-row")
    FREEZE_ROW_COLUMN: IconName = IconName("freeze-row-column")
    FRIDGE: IconName = IconName("fridge")
    FRIDGE_OFF: IconName = IconName("fridge-off")
    FRIENDS: IconName = IconName("friends")
    FRIENDS_OFF: IconName = IconName("friends-off")
    FRUSTUM: IconName = IconName("frustum")
    FRUSTUM_OFF: IconName = IconName("frustum-off")
    FRUSTUM_PLUS: IconName = IconName("frustum-plus")
    FUNCTION: IconName = IconName("function")
    FUNCTION_OFF: IconName = IconName("function-off")
    GARDEN_CART: IconName = IconName("garden-cart")
    GARDEN_CART_OFF: IconName = IconName("garden-cart-off")
    GAS_STATION: IconName = IconName("gas-station")
    GAS_STATION_OFF: IconName = IconName("gas-station-off")
    GAUGE: IconName = IconName("gauge")
    GAUGE_OFF: IconName = IconName("gauge-off")
    GAVEL: IconName = IconName("gavel")
    GENDER_AGENDER: IconName = IconName("gender-agender")
    GENDER_ANDROGYNE: IconName = IconName("gender-androgyne")
    GENDER_BIGENDER: IconName = IconName("gender-bigender")
    GENDER_DEMIBOY: IconName = IconName("gender-demiboy")
    GENDER_DEMIGIRL: IconName = IconName("gender-demigirl")
    GENDER_EPICENE: IconName = IconName("gender-epicene")
    GENDER_FEMALE: IconName = IconName("gender-female")
    GENDER_FEMME: IconName = IconName("gender-femme")
    GENDER_GENDERFLUID: IconName = IconName("gender-genderfluid")
    GENDER_GENDERLESS: IconName = IconName("gender-genderless")
    GENDER_GENDERQUEER: IconName = IconName("gender-genderqueer")
    GENDER_HERMAPHRODITE: IconName = IconName("gender-hermaphrodite")
    GENDER_INTERGENDER: IconName = IconName("gender-intergender")
    GENDER_MALE: IconName = IconName("gender-male")
    GENDER_NEUTROIS: IconName = IconName("gender-neutrois")
    GENDER_THIRD: IconName = IconName("gender-third")
    GENDER_TRANSGENDER: IconName = IconName("gender-transgender")
    GENDER_TRASVESTI: IconName = IconName("gender-trasvesti")
    GEOMETRY: IconName = IconName("geometry")
    GHOST: IconName = IconName("ghost")
    GHOST_2: IconName = IconName("ghost-2")
    GHOST_2_FILLED: IconName = IconName("ghost-2-filled")
    GHOST_FILLED: IconName = IconName("ghost-filled")
    GHOST_OFF: IconName = IconName("ghost-off")
    GIF: IconName = IconName("gif")
    GIFT: IconName = IconName("gift")
    GIFT_CARD: IconName = IconName("gift-card")
    GIFT_OFF: IconName = IconName("gift-off")
    GIT_BRANCH: IconName = IconName("git-branch")
    GIT_BRANCH_DELETED: IconName = IconName("git-branch-deleted")
    GIT_CHERRY_PICK: IconName = IconName("git-cherry-pick")
    GIT_COMMIT: IconName = IconName("git-commit")
    GIT_COMPARE: IconName = IconName("git-compare")
    GIT_FORK: IconName = IconName("git-fork")
    GIT_MERGE: IconName = IconName("git-merge")
    GIT_PULL_REQUEST: IconName = IconName("git-pull-request")
    GIT_PULL_REQUEST_CLOSED: IconName = IconName("git-pull-request-closed")
    GIT_PULL_REQUEST_DRAFT: IconName = IconName("git-pull-request-draft")
    GIZMO: IconName = IconName("gizmo")
    GLASS: IconName = IconName("glass")
    GLASS_FULL: IconName = IconName("glass-full")
    GLASS_OFF: IconName = IconName("glass-off")
    GLOBE: IconName = IconName("globe")
    GLOBE_OFF: IconName = IconName("globe-off")
    GO_GAME: IconName = IconName("go-game")
    GOLF: IconName = IconName("golf")
    GOLF_OFF: IconName = IconName("golf-off")
    GPS: IconName = IconName("gps")
    GRADIENTER: IconName = IconName("gradienter")
    GRAIN: IconName = IconName("grain")
    GRAPH: IconName = IconName("graph")
    GRAPH_OFF: IconName = IconName("graph-off")
    GRAVE: IconName = IconName("grave")
    GRAVE_2: IconName = IconName("grave-2")
    GRID_DOTS: IconName = IconName("grid-dots")
    GRID_PATTERN: IconName = IconName("grid-pattern")
    GRILL: IconName = IconName("grill")
    GRILL_FORK: IconName = IconName("grill-fork")
    GRILL_OFF: IconName = IconName("grill-off")
    GRILL_SPATULA: IconName = IconName("grill-spatula")
    GRIP_HORIZONTAL: IconName = IconName("grip-horizontal")
    GRIP_VERTICAL: IconName = IconName("grip-vertical")
    GROWTH: IconName = IconName("growth")
    GUITAR_PICK: IconName = IconName("guitar-pick")
    GUITAR_PICK_FILLED: IconName = IconName("guitar-pick-filled")
    H_1: IconName = IconName("h-1")
    H_2: IconName = IconName("h-2")
    H_3: IconName = IconName("h-3")
    H_4: IconName = IconName("h-4")
    H_5: IconName = IconName("h-5")
    H_6: IconName = IconName("h-6")
    HAMMER: IconName = IconName("hammer")
    HAMMER_OFF: IconName = IconName("hammer-off")
    HAND_CLICK: IconName = IconName("hand-click")
    HAND_FINGER: IconName = IconName("hand-finger")
    HAND_FINGER_OFF: IconName = IconName("hand-finger-off")
    HAND_GRAB: IconName = IconName("hand-grab")
    HAND_LITTLE_FINGER: IconName = IconName("hand-little-finger")
    HAND_MIDDLE_FINGER: IconName = IconName("hand-middle-finger")
    HAND_MOVE: IconName = IconName("hand-move")
    HAND_OFF: IconName = IconName("hand-off")
    HAND_RING_FINGER: IconName = IconName("hand-ring-finger")
    HAND_ROCK: IconName = IconName("hand-rock")
    HAND_SANITIZER: IconName = IconName("hand-sanitizer")
    HAND_STOP: IconName = IconName("hand-stop")
    HAND_THREE_FINGERS: IconName = IconName("hand-three-fingers")
    HAND_TWO_FINGERS: IconName = IconName("hand-two-fingers")
    HANGER: IconName = IconName("hanger")
    HANGER_2: IconName = IconName("hanger-2")
    HANGER_OFF: IconName = IconName("hanger-off")
    HASH: IconName = IconName("hash")
    HAZE: IconName = IconName("haze")
    HAZE_MOON: IconName = IconName("haze-moon")
    HDR: IconName = IconName("hdr")
    HEADING: IconName = IconName("heading")
    HEADING_OFF: IconName = IconName("heading-off")
    HEADPHONES: IconName = IconName("headphones")
    HEADPHONES_FILLED: IconName = IconName("headphones-filled")
    HEADPHONES_OFF: IconName = IconName("headphones-off")
    HEADSET: IconName = IconName("headset")
    HEADSET_OFF: IconName = IconName("headset-off")
    HEALTH_RECOGNITION: IconName = IconName("health-recognition")
    HEART: IconName = IconName("heart")
    HEART_BROKEN: IconName = IconName("heart-broken")
    HEART_FILLED: IconName = IconName("heart-filled")
    HEART_HANDSHAKE: IconName = IconName("heart-handshake")
    HEART_MINUS: IconName = IconName("heart-minus")
    HEART_OFF: IconName = IconName("heart-off")
    HEART_PLUS: IconName = IconName("heart-plus")
    HEART_RATE_MONITOR: IconName = IconName("heart-rate-monitor")
    HEARTBEAT: IconName = IconName("heartbeat")
    HEARTS: IconName = IconName("hearts")
    HEARTS_OFF: IconName = IconName("hearts-off")
    HELICOPTER: IconName = IconName("helicopter")
    HELICOPTER_LANDING: IconName = IconName("helicopter-landing")
    HELMET: IconName = IconName("helmet")
    HELMET_OFF: IconName = IconName("helmet-off")
    HELP: IconName = IconName("help")
    HELP_CIRCLE: IconName = IconName("help-circle")
    HELP_CIRCLE_FILLED: IconName = IconName("help-circle-filled")
    HELP_HEXAGON: IconName = IconName("help-hexagon")
    HELP_HEXAGON_FILLED: IconName = IconName("help-hexagon-filled")
    HELP_OCTAGON: IconName = IconName("help-octagon")
    HELP_OCTAGON_FILLED: IconName = IconName("help-octagon-filled")
    HELP_OFF: IconName = IconName("help-off")
    HELP_SMALL: IconName = IconName("help-small")
    HELP_SQUARE: IconName = IconName("help-square")
    HELP_SQUARE_FILLED: IconName = IconName("help-square-filled")
    HELP_SQUARE_ROUNDED: IconName = IconName("help-square-rounded")
    HELP_SQUARE_ROUNDED_FILLED: IconName = IconName("help-square-rounded-filled")
    HELP_TRIANGLE: IconName = IconName("help-triangle")
    HELP_TRIANGLE_FILLED: IconName = IconName("help-triangle-filled")
    HEMISPHERE: IconName = IconName("hemisphere")
    HEMISPHERE_OFF: IconName = IconName("hemisphere-off")
    HEMISPHERE_PLUS: IconName = IconName("hemisphere-plus")
    HEXAGON: IconName = IconName("hexagon")
    HEXAGON_0_FILLED: IconName = IconName("hexagon-0-filled")
    HEXAGON_1_FILLED: IconName = IconName("hexagon-1-filled")
    HEXAGON_2_FILLED: IconName = IconName("hexagon-2-filled")
    HEXAGON_3_FILLED: IconName = IconName("hexagon-3-filled")
    HEXAGON_3D: IconName = IconName("hexagon-3d")
    HEXAGON_4_FILLED: IconName = IconName("hexagon-4-filled")
    HEXAGON_5_FILLED: IconName = IconName("hexagon-5-filled")
    HEXAGON_6_FILLED: IconName = IconName("hexagon-6-filled")
    HEXAGON_7_FILLED: IconName = IconName("hexagon-7-filled")
    HEXAGON_8_FILLED: IconName = IconName("hexagon-8-filled")
    HEXAGON_9_FILLED: IconName = IconName("hexagon-9-filled")
    HEXAGON_FILLED: IconName = IconName("hexagon-filled")
    HEXAGON_LETTER_A: IconName = IconName("hexagon-letter-a")
    HEXAGON_LETTER_B: IconName = IconName("hexagon-letter-b")
    HEXAGON_LETTER_C: IconName = IconName("hexagon-letter-c")
    HEXAGON_LETTER_D: IconName = IconName("hexagon-letter-d")
    HEXAGON_LETTER_E: IconName = IconName("hexagon-letter-e")
    HEXAGON_LETTER_F: IconName = IconName("hexagon-letter-f")
    HEXAGON_LETTER_G: IconName = IconName("hexagon-letter-g")
    HEXAGON_LETTER_H: IconName = IconName("hexagon-letter-h")
    HEXAGON_LETTER_I: IconName = IconName("hexagon-letter-i")
    HEXAGON_LETTER_J: IconName = IconName("hexagon-letter-j")
    HEXAGON_LETTER_K: IconName = IconName("hexagon-letter-k")
    HEXAGON_LETTER_L: IconName = IconName("hexagon-letter-l")
    HEXAGON_LETTER_M: IconName = IconName("hexagon-letter-m")
    HEXAGON_LETTER_N: IconName = IconName("hexagon-letter-n")
    HEXAGON_LETTER_O: IconName = IconName("hexagon-letter-o")
    HEXAGON_LETTER_P: IconName = IconName("hexagon-letter-p")
    HEXAGON_LETTER_Q: IconName = IconName("hexagon-letter-q")
    HEXAGON_LETTER_R: IconName = IconName("hexagon-letter-r")
    HEXAGON_LETTER_S: IconName = IconName("hexagon-letter-s")
    HEXAGON_LETTER_T: IconName = IconName("hexagon-letter-t")
    HEXAGON_LETTER_U: IconName = IconName("hexagon-letter-u")
    HEXAGON_LETTER_V: IconName = IconName("hexagon-letter-v")
    HEXAGON_LETTER_W: IconName = IconName("hexagon-letter-w")
    HEXAGON_LETTER_X: IconName = IconName("hexagon-letter-x")
    HEXAGON_LETTER_Y: IconName = IconName("hexagon-letter-y")
    HEXAGON_LETTER_Z: IconName = IconName("hexagon-letter-z")
    HEXAGON_NUMBER_0: IconName = IconName("hexagon-number-0")
    HEXAGON_NUMBER_1: IconName = IconName("hexagon-number-1")
    HEXAGON_NUMBER_2: IconName = IconName("hexagon-number-2")
    HEXAGON_NUMBER_3: IconName = IconName("hexagon-number-3")
    HEXAGON_NUMBER_4: IconName = IconName("hexagon-number-4")
    HEXAGON_NUMBER_5: IconName = IconName("hexagon-number-5")
    HEXAGON_NUMBER_6: IconName = IconName("hexagon-number-6")
    HEXAGON_NUMBER_7: IconName = IconName("hexagon-number-7")
    HEXAGON_NUMBER_8: IconName = IconName("hexagon-number-8")
    HEXAGON_NUMBER_9: IconName = IconName("hexagon-number-9")
    HEXAGON_OFF: IconName = IconName("hexagon-off")
    HEXAGONAL_PRISM: IconName = IconName("hexagonal-prism")
    HEXAGONAL_PRISM_OFF: IconName = IconName("hexagonal-prism-off")
    HEXAGONAL_PRISM_PLUS: IconName = IconName("hexagonal-prism-plus")
    HEXAGONAL_PYRAMID: IconName = IconName("hexagonal-pyramid")
    HEXAGONAL_PYRAMID_OFF: IconName = IconName("hexagonal-pyramid-off")
    HEXAGONAL_PYRAMID_PLUS: IconName = IconName("hexagonal-pyramid-plus")
    HEXAGONS: IconName = IconName("hexagons")
    HEXAGONS_OFF: IconName = IconName("hexagons-off")
    HIERARCHY: IconName = IconName("hierarchy")
    HIERARCHY_2: IconName = IconName("hierarchy-2")
    HIERARCHY_3: IconName = IconName("hierarchy-3")
    HIERARCHY_OFF: IconName = IconName("hierarchy-off")
    HIGHLIGHT: IconName = IconName("highlight")
    HIGHLIGHT_OFF: IconName = IconName("highlight-off")
    HISTORY: IconName = IconName("history")
    HISTORY_OFF: IconName = IconName("history-off")
    HISTORY_TOGGLE: IconName = IconName("history-toggle")
    HOME: IconName = IconName("home")
    HOME_2: IconName = IconName("home-2")
    HOME_BOLT: IconName = IconName("home-bolt")
    HOME_CANCEL: IconName = IconName("home-cancel")
    HOME_CHECK: IconName = IconName("home-check")
    HOME_COG: IconName = IconName("home-cog")
    HOME_DOLLAR: IconName = IconName("home-dollar")
    HOME_DOT: IconName = IconName("home-dot")
    HOME_DOWN: IconName = IconName("home-down")
    HOME_ECO: IconName = IconName("home-eco")
    HOME_EDIT: IconName = IconName("home-edit")
    HOME_EXCLAMATION: IconName = IconName("home-exclamation")
    HOME_HAND: IconName = IconName("home-hand")
    HOME_HEART: IconName = IconName("home-heart")
    HOME_INFINITY: IconName = IconName("home-infinity")
    HOME_LINK: IconName = IconName("home-link")
    HOME_MINUS: IconName = IconName("home-minus")
    HOME_MOVE: IconName = IconName("home-move")
    HOME_OFF: IconName = IconName("home-off")
    HOME_PLUS: IconName = IconName("home-plus")
    HOME_QUESTION: IconName = IconName("home-question")
    HOME_RIBBON: IconName = IconName("home-ribbon")
    HOME_SEARCH: IconName = IconName("home-search")
    HOME_SHARE: IconName = IconName("home-share")
    HOME_SHIELD: IconName = IconName("home-shield")
    HOME_SIGNAL: IconName = IconName("home-signal")
    HOME_STAR: IconName = IconName("home-star")
    HOME_STATS: IconName = IconName("home-stats")
    HOME_UP: IconName = IconName("home-up")
    HOME_X: IconName = IconName("home-x")
    HORSE_TOY: IconName = IconName("horse-toy")
    HOTEL_SERVICE: IconName = IconName("hotel-service")
    HOURGLASS: IconName = IconName("hourglass")
    HOURGLASS_EMPTY: IconName = IconName("hourglass-empty")
    HOURGLASS_FILLED: IconName = IconName("hourglass-filled")
    HOURGLASS_HIGH: IconName = IconName("hourglass-high")
    HOURGLASS_LOW: IconName = IconName("hourglass-low")
    HOURGLASS_OFF: IconName = IconName("hourglass-off")
    HTML: IconName = IconName("html")
    HTTP_CONNECT: IconName = IconName("http-connect")
    HTTP_DELETE: IconName = IconName("http-delete")
    HTTP_GET: IconName = IconName("http-get")
    HTTP_HEAD: IconName = IconName("http-head")
    HTTP_OPTIONS: IconName = IconName("http-options")
    HTTP_PATCH: IconName = IconName("http-patch")
    HTTP_POST: IconName = IconName("http-post")
    HTTP_PUT: IconName = IconName("http-put")
    HTTP_QUE: IconName = IconName("http-que")
    HTTP_TRACE: IconName = IconName("http-trace")
    ICE_CREAM: IconName = IconName("ice-cream")
    ICE_CREAM_2: IconName = IconName("ice-cream-2")
    ICE_CREAM_OFF: IconName = IconName("ice-cream-off")
    ICE_SKATING: IconName = IconName("ice-skating")
    ICONS: IconName = IconName("icons")
    ICONS_OFF: IconName = IconName("icons-off")
    ID: IconName = IconName("id")
    ID_BADGE: IconName = IconName("id-badge")
    ID_BADGE_2: IconName = IconName("id-badge-2")
    ID_BADGE_OFF: IconName = IconName("id-badge-off")
    ID_OFF: IconName = IconName("id-off")
    INBOX: IconName = IconName("inbox")
    INBOX_OFF: IconName = IconName("inbox-off")
    INDENT_DECREASE: IconName = IconName("indent-decrease")
    INDENT_INCREASE: IconName = IconName("indent-increase")
    INFINITY: IconName = IconName("infinity")
    INFINITY_OFF: IconName = IconName("infinity-off")
    INFO_CIRCLE: IconName = IconName("info-circle")
    INFO_CIRCLE_FILLED: IconName = IconName("info-circle-filled")
    INFO_HEXAGON: IconName = IconName("info-hexagon")
    INFO_HEXAGON_FILLED: IconName = IconName("info-hexagon-filled")
    INFO_OCTAGON: IconName = IconName("info-octagon")
    INFO_OCTAGON_FILLED: IconName = IconName("info-octagon-filled")
    INFO_SMALL: IconName = IconName("info-small")
    INFO_SQUARE: IconName = IconName("info-square")
    INFO_SQUARE_FILLED: IconName = IconName("info-square-filled")
    INFO_SQUARE_ROUNDED: IconName = IconName("info-square-rounded")
    INFO_SQUARE_ROUNDED_FILLED: IconName = IconName("info-square-rounded-filled")
    INFO_TRIANGLE: IconName = IconName("info-triangle")
    INFO_TRIANGLE_FILLED: IconName = IconName("info-triangle-filled")
    INNER_SHADOW_BOTTOM: IconName = IconName("inner-shadow-bottom")
    INNER_SHADOW_BOTTOM_FILLED: IconName = IconName("inner-shadow-bottom-filled")
    INNER_SHADOW_BOTTOM_LEFT: IconName = IconName("inner-shadow-bottom-left")
    INNER_SHADOW_BOTTOM_LEFT_FILLED: IconName = IconName(
        "inner-shadow-bottom-left-filled"
    )
    INNER_SHADOW_BOTTOM_RIGHT: IconName = IconName("inner-shadow-bottom-right")
    INNER_SHADOW_BOTTOM_RIGHT_FILLED: IconName = IconName(
        "inner-shadow-bottom-right-filled"
    )
    INNER_SHADOW_LEFT: IconName = IconName("inner-shadow-left")
    INNER_SHADOW_LEFT_FILLED: IconName = IconName("inner-shadow-left-filled")
    INNER_SHADOW_RIGHT: IconName = IconName("inner-shadow-right")
    INNER_SHADOW_RIGHT_FILLED: IconName = IconName("inner-shadow-right-filled")
    INNER_SHADOW_TOP: IconName = IconName("inner-shadow-top")
    INNER_SHADOW_TOP_FILLED: IconName = IconName("inner-shadow-top-filled")
    INNER_SHADOW_TOP_LEFT: IconName = IconName("inner-shadow-top-left")
    INNER_SHADOW_TOP_LEFT_FILLED: IconName = IconName("inner-shadow-top-left-filled")
    INNER_SHADOW_TOP_RIGHT: IconName = IconName("inner-shadow-top-right")
    INNER_SHADOW_TOP_RIGHT_FILLED: IconName = IconName("inner-shadow-top-right-filled")
    INPUT_SEARCH: IconName = IconName("input-search")
    IRONING: IconName = IconName("ironing")
    IRONING_1: IconName = IconName("ironing-1")
    IRONING_2: IconName = IconName("ironing-2")
    IRONING_3: IconName = IconName("ironing-3")
    IRONING_OFF: IconName = IconName("ironing-off")
    IRONING_STEAM: IconName = IconName("ironing-steam")
    IRONING_STEAM_OFF: IconName = IconName("ironing-steam-off")
    IRREGULAR_POLYHEDRON: IconName = IconName("irregular-polyhedron")
    IRREGULAR_POLYHEDRON_OFF: IconName = IconName("irregular-polyhedron-off")
    IRREGULAR_POLYHEDRON_PLUS: IconName = IconName("irregular-polyhedron-plus")
    ITALIC: IconName = IconName("italic")
    JACKET: IconName = IconName("jacket")
    JETPACK: IconName = IconName("jetpack")
    JEWISH_STAR: IconName = IconName("jewish-star")
    JEWISH_STAR_FILLED: IconName = IconName("jewish-star-filled")
    JPG: IconName = IconName("jpg")
    JSON: IconName = IconName("json")
    JUMP_ROPE: IconName = IconName("jump-rope")
    KARATE: IconName = IconName("karate")
    KAYAK: IconName = IconName("kayak")
    KERING: IconName = IconName("kering")
    KEY: IconName = IconName("key")
    KEY_OFF: IconName = IconName("key-off")
    KEYBOARD: IconName = IconName("keyboard")
    KEYBOARD_HIDE: IconName = IconName("keyboard-hide")
    KEYBOARD_OFF: IconName = IconName("keyboard-off")
    KEYBOARD_SHOW: IconName = IconName("keyboard-show")
    KEYFRAME: IconName = IconName("keyframe")
    KEYFRAME_ALIGN_CENTER: IconName = IconName("keyframe-align-center")
    KEYFRAME_ALIGN_HORIZONTAL: IconName = IconName("keyframe-align-horizontal")
    KEYFRAME_ALIGN_VERTICAL: IconName = IconName("keyframe-align-vertical")
    KEYFRAMES: IconName = IconName("keyframes")
    LADDER: IconName = IconName("ladder")
    LADDER_OFF: IconName = IconName("ladder-off")
    LAMBDA: IconName = IconName("lambda")
    LAMP: IconName = IconName("lamp")
    LAMP_2: IconName = IconName("lamp-2")
    LAMP_OFF: IconName = IconName("lamp-off")
    LANE: IconName = IconName("lane")
    LANGUAGE: IconName = IconName("language")
    LANGUAGE_HIRAGANA: IconName = IconName("language-hiragana")
    LANGUAGE_KATAKANA: IconName = IconName("language-katakana")
    LANGUAGE_OFF: IconName = IconName("language-off")
    LASSO: IconName = IconName("lasso")
    LASSO_OFF: IconName = IconName("lasso-off")
    LASSO_POLYGON: IconName = IconName("lasso-polygon")
    LAYERS_DIFFERENCE: IconName = IconName("layers-difference")
    LAYERS_INTERSECT: IconName = IconName("layers-intersect")
    LAYERS_INTERSECT_2: IconName = IconName("layers-intersect-2")
    LAYERS_LINKED: IconName = IconName("layers-linked")
    LAYERS_OFF: IconName = IconName("layers-off")
    LAYERS_SUBTRACT: IconName = IconName("layers-subtract")
    LAYERS_UNION: IconName = IconName("layers-union")
    LAYOUT: IconName = IconName("layout")
    LAYOUT_2: IconName = IconName("layout-2")
    LAYOUT_ALIGN_BOTTOM: IconName = IconName("layout-align-bottom")
    LAYOUT_ALIGN_CENTER: IconName = IconName("layout-align-center")
    LAYOUT_ALIGN_LEFT: IconName = IconName("layout-align-left")
    LAYOUT_ALIGN_MIDDLE: IconName = IconName("layout-align-middle")
    LAYOUT_ALIGN_RIGHT: IconName = IconName("layout-align-right")
    LAYOUT_ALIGN_TOP: IconName = IconName("layout-align-top")
    LAYOUT_BOARD: IconName = IconName("layout-board")
    LAYOUT_BOARD_SPLIT: IconName = IconName("layout-board-split")
    LAYOUT_BOTTOMBAR: IconName = IconName("layout-bottombar")
    LAYOUT_BOTTOMBAR_COLLAPSE: IconName = IconName("layout-bottombar-collapse")
    LAYOUT_BOTTOMBAR_EXPAND: IconName = IconName("layout-bottombar-expand")
    LAYOUT_CARDS: IconName = IconName("layout-cards")
    LAYOUT_COLLAGE: IconName = IconName("layout-collage")
    LAYOUT_COLUMNS: IconName = IconName("layout-columns")
    LAYOUT_DASHBOARD: IconName = IconName("layout-dashboard")
    LAYOUT_DISTRIBUTE_HORIZONTAL: IconName = IconName("layout-distribute-horizontal")
    LAYOUT_DISTRIBUTE_VERTICAL: IconName = IconName("layout-distribute-vertical")
    LAYOUT_GRID: IconName = IconName("layout-grid")
    LAYOUT_GRID_ADD: IconName = IconName("layout-grid-add")
    LAYOUT_GRID_REMOVE: IconName = IconName("layout-grid-remove")
    LAYOUT_KANBAN: IconName = IconName("layout-kanban")
    LAYOUT_LIST: IconName = IconName("layout-list")
    LAYOUT_NAVBAR: IconName = IconName("layout-navbar")
    LAYOUT_NAVBAR_COLLAPSE: IconName = IconName("layout-navbar-collapse")
    LAYOUT_NAVBAR_EXPAND: IconName = IconName("layout-navbar-expand")
    LAYOUT_OFF: IconName = IconName("layout-off")
    LAYOUT_ROWS: IconName = IconName("layout-rows")
    LAYOUT_SIDEBAR: IconName = IconName("layout-sidebar")
    LAYOUT_SIDEBAR_LEFT_COLLAPSE: IconName = IconName("layout-sidebar-left-collapse")
    LAYOUT_SIDEBAR_LEFT_EXPAND: IconName = IconName("layout-sidebar-left-expand")
    LAYOUT_SIDEBAR_RIGHT: IconName = IconName("layout-sidebar-right")
    LAYOUT_SIDEBAR_RIGHT_COLLAPSE: IconName = IconName("layout-sidebar-right-collapse")
    LAYOUT_SIDEBAR_RIGHT_EXPAND: IconName = IconName("layout-sidebar-right-expand")
    LEAF: IconName = IconName("leaf")
    LEAF_OFF: IconName = IconName("leaf-off")
    LEGO: IconName = IconName("lego")
    LEGO_OFF: IconName = IconName("lego-off")
    LEMON: IconName = IconName("lemon")
    LEMON_2: IconName = IconName("lemon-2")
    LETTER_A: IconName = IconName("letter-a")
    LETTER_B: IconName = IconName("letter-b")
    LETTER_C: IconName = IconName("letter-c")
    LETTER_CASE: IconName = IconName("letter-case")
    LETTER_CASE_LOWER: IconName = IconName("letter-case-lower")
    LETTER_CASE_TOGGLE: IconName = IconName("letter-case-toggle")
    LETTER_CASE_UPPER: IconName = IconName("letter-case-upper")
    LETTER_D: IconName = IconName("letter-d")
    LETTER_E: IconName = IconName("letter-e")
    LETTER_F: IconName = IconName("letter-f")
    LETTER_G: IconName = IconName("letter-g")
    LETTER_H: IconName = IconName("letter-h")
    LETTER_I: IconName = IconName("letter-i")
    LETTER_J: IconName = IconName("letter-j")
    LETTER_K: IconName = IconName("letter-k")
    LETTER_L: IconName = IconName("letter-l")
    LETTER_M: IconName = IconName("letter-m")
    LETTER_N: IconName = IconName("letter-n")
    LETTER_O: IconName = IconName("letter-o")
    LETTER_P: IconName = IconName("letter-p")
    LETTER_Q: IconName = IconName("letter-q")
    LETTER_R: IconName = IconName("letter-r")
    LETTER_S: IconName = IconName("letter-s")
    LETTER_SPACING: IconName = IconName("letter-spacing")
    LETTER_T: IconName = IconName("letter-t")
    LETTER_U: IconName = IconName("letter-u")
    LETTER_V: IconName = IconName("letter-v")
    LETTER_W: IconName = IconName("letter-w")
    LETTER_X: IconName = IconName("letter-x")
    LETTER_Y: IconName = IconName("letter-y")
    LETTER_Z: IconName = IconName("letter-z")
    LICENSE: IconName = IconName("license")
    LICENSE_OFF: IconName = IconName("license-off")
    LIFEBUOY: IconName = IconName("lifebuoy")
    LIFEBUOY_OFF: IconName = IconName("lifebuoy-off")
    LIGHTER: IconName = IconName("lighter")
    LINE: IconName = IconName("line")
    LINE_DASHED: IconName = IconName("line-dashed")
    LINE_DOTTED: IconName = IconName("line-dotted")
    LINE_HEIGHT: IconName = IconName("line-height")
    LINK: IconName = IconName("link")
    LINK_OFF: IconName = IconName("link-off")
    LIST: IconName = IconName("list")
    LIST_CHECK: IconName = IconName("list-check")
    LIST_DETAILS: IconName = IconName("list-details")
    LIST_NUMBERS: IconName = IconName("list-numbers")
    LIST_SEARCH: IconName = IconName("list-search")
    LIST_TREE: IconName = IconName("list-tree")
    LIVE_PHOTO: IconName = IconName("live-photo")
    LIVE_PHOTO_OFF: IconName = IconName("live-photo-off")
    LIVE_VIEW: IconName = IconName("live-view")
    LOAD_BALANCER: IconName = IconName("load-balancer")
    LOADER: IconName = IconName("loader")
    LOADER_2: IconName = IconName("loader-2")
    LOADER_3: IconName = IconName("loader-3")
    LOADER_QUARTER: IconName = IconName("loader-quarter")
    LOCATION: IconName = IconName("location")
    LOCATION_BROKEN: IconName = IconName("location-broken")
    LOCATION_FILLED: IconName = IconName("location-filled")
    LOCATION_OFF: IconName = IconName("location-off")
    LOCK: IconName = IconName("lock")
    LOCK_ACCESS: IconName = IconName("lock-access")
    LOCK_ACCESS_OFF: IconName = IconName("lock-access-off")
    LOCK_BOLT: IconName = IconName("lock-bolt")
    LOCK_CANCEL: IconName = IconName("lock-cancel")
    LOCK_CHECK: IconName = IconName("lock-check")
    LOCK_CODE: IconName = IconName("lock-code")
    LOCK_COG: IconName = IconName("lock-cog")
    LOCK_DOLLAR: IconName = IconName("lock-dollar")
    LOCK_DOWN: IconName = IconName("lock-down")
    LOCK_EXCLAMATION: IconName = IconName("lock-exclamation")
    LOCK_HEART: IconName = IconName("lock-heart")
    LOCK_MINUS: IconName = IconName("lock-minus")
    LOCK_OFF: IconName = IconName("lock-off")
    LOCK_OPEN: IconName = IconName("lock-open")
    LOCK_OPEN_OFF: IconName = IconName("lock-open-off")
    LOCK_PAUSE: IconName = IconName("lock-pause")
    LOCK_PIN: IconName = IconName("lock-pin")
    LOCK_PLUS: IconName = IconName("lock-plus")
    LOCK_QUESTION: IconName = IconName("lock-question")
    LOCK_SEARCH: IconName = IconName("lock-search")
    LOCK_SHARE: IconName = IconName("lock-share")
    LOCK_SQUARE: IconName = IconName("lock-square")
    LOCK_SQUARE_ROUNDED: IconName = IconName("lock-square-rounded")
    LOCK_SQUARE_ROUNDED_FILLED: IconName = IconName("lock-square-rounded-filled")
    LOCK_STAR: IconName = IconName("lock-star")
    LOCK_UP: IconName = IconName("lock-up")
    LOCK_X: IconName = IconName("lock-x")
    LOGIC_AND: IconName = IconName("logic-and")
    LOGIC_BUFFER: IconName = IconName("logic-buffer")
    LOGIC_NAND: IconName = IconName("logic-nand")
    LOGIC_NOR: IconName = IconName("logic-nor")
    LOGIC_NOT: IconName = IconName("logic-not")
    LOGIC_OR: IconName = IconName("logic-or")
    LOGIC_XNOR: IconName = IconName("logic-xnor")
    LOGIC_XOR: IconName = IconName("logic-xor")
    LOGIN: IconName = IconName("login")
    LOGOUT: IconName = IconName("logout")
    LOGOUT_2: IconName = IconName("logout-2")
    LOLLIPOP: IconName = IconName("lollipop")
    LOLLIPOP_OFF: IconName = IconName("lollipop-off")
    LUGGAGE: IconName = IconName("luggage")
    LUGGAGE_OFF: IconName = IconName("luggage-off")
    LUNGS: IconName = IconName("lungs")
    LUNGS_OFF: IconName = IconName("lungs-off")
    MACRO: IconName = IconName("macro")
    MACRO_OFF: IconName = IconName("macro-off")
    MAGNET: IconName = IconName("magnet")
    MAGNET_OFF: IconName = IconName("magnet-off")
    MAIL: IconName = IconName("mail")
    MAIL_AI: IconName = IconName("mail-ai")
    MAIL_BOLT: IconName = IconName("mail-bolt")
    MAIL_CANCEL: IconName = IconName("mail-cancel")
    MAIL_CHECK: IconName = IconName("mail-check")
    MAIL_CODE: IconName = IconName("mail-code")
    MAIL_COG: IconName = IconName("mail-cog")
    MAIL_DOLLAR: IconName = IconName("mail-dollar")
    MAIL_DOWN: IconName = IconName("mail-down")
    MAIL_EXCLAMATION: IconName = IconName("mail-exclamation")
    MAIL_FAST: IconName = IconName("mail-fast")
    MAIL_FILLED: IconName = IconName("mail-filled")
    MAIL_FORWARD: IconName = IconName("mail-forward")
    MAIL_HEART: IconName = IconName("mail-heart")
    MAIL_MINUS: IconName = IconName("mail-minus")
    MAIL_OFF: IconName = IconName("mail-off")
    MAIL_OPENED: IconName = IconName("mail-opened")
    MAIL_OPENED_FILLED: IconName = IconName("mail-opened-filled")
    MAIL_PAUSE: IconName = IconName("mail-pause")
    MAIL_PIN: IconName = IconName("mail-pin")
    MAIL_PLUS: IconName = IconName("mail-plus")
    MAIL_QUESTION: IconName = IconName("mail-question")
    MAIL_SEARCH: IconName = IconName("mail-search")
    MAIL_SHARE: IconName = IconName("mail-share")
    MAIL_STAR: IconName = IconName("mail-star")
    MAIL_UP: IconName = IconName("mail-up")
    MAIL_X: IconName = IconName("mail-x")
    MAILBOX: IconName = IconName("mailbox")
    MAILBOX_OFF: IconName = IconName("mailbox-off")
    MAN: IconName = IconName("man")
    MANUAL_GEARBOX: IconName = IconName("manual-gearbox")
    MAP: IconName = IconName("map")
    MAP_2: IconName = IconName("map-2")
    MAP_OFF: IconName = IconName("map-off")
    MAP_PIN: IconName = IconName("map-pin")
    MAP_PIN_BOLT: IconName = IconName("map-pin-bolt")
    MAP_PIN_CANCEL: IconName = IconName("map-pin-cancel")
    MAP_PIN_CHECK: IconName = IconName("map-pin-check")
    MAP_PIN_CODE: IconName = IconName("map-pin-code")
    MAP_PIN_COG: IconName = IconName("map-pin-cog")
    MAP_PIN_DOLLAR: IconName = IconName("map-pin-dollar")
    MAP_PIN_DOWN: IconName = IconName("map-pin-down")
    MAP_PIN_EXCLAMATION: IconName = IconName("map-pin-exclamation")
    MAP_PIN_FILLED: IconName = IconName("map-pin-filled")
    MAP_PIN_HEART: IconName = IconName("map-pin-heart")
    MAP_PIN_MINUS: IconName = IconName("map-pin-minus")
    MAP_PIN_OFF: IconName = IconName("map-pin-off")
    MAP_PIN_PAUSE: IconName = IconName("map-pin-pause")
    MAP_PIN_PIN: IconName = IconName("map-pin-pin")
    MAP_PIN_PLUS: IconName = IconName("map-pin-plus")
    MAP_PIN_QUESTION: IconName = IconName("map-pin-question")
    MAP_PIN_SEARCH: IconName = IconName("map-pin-search")
    MAP_PIN_SHARE: IconName = IconName("map-pin-share")
    MAP_PIN_STAR: IconName = IconName("map-pin-star")
    MAP_PIN_UP: IconName = IconName("map-pin-up")
    MAP_PIN_X: IconName = IconName("map-pin-x")
    MAP_PINS: IconName = IconName("map-pins")
    MAP_SEARCH: IconName = IconName("map-search")
    MARKDOWN: IconName = IconName("markdown")
    MARKDOWN_OFF: IconName = IconName("markdown-off")
    MARQUEE: IconName = IconName("marquee")
    MARQUEE_2: IconName = IconName("marquee-2")
    MARQUEE_OFF: IconName = IconName("marquee-off")
    MARS: IconName = IconName("mars")
    MASK: IconName = IconName("mask")
    MASK_OFF: IconName = IconName("mask-off")
    MASKS_THEATER: IconName = IconName("masks-theater")
    MASKS_THEATER_OFF: IconName = IconName("masks-theater-off")
    MASSAGE: IconName = IconName("massage")
    MATCHSTICK: IconName = IconName("matchstick")
    MATH: IconName = IconName("math")
    MATH_1_DIVIDE_2: IconName = IconName("math-1-divide-2")
    MATH_1_DIVIDE_3: IconName = IconName("math-1-divide-3")
    MATH_AVG: IconName = IconName("math-avg")
    MATH_EQUAL_GREATER: IconName = IconName("math-equal-greater")
    MATH_EQUAL_LOWER: IconName = IconName("math-equal-lower")
    MATH_FUNCTION: IconName = IconName("math-function")
    MATH_FUNCTION_OFF: IconName = IconName("math-function-off")
    MATH_FUNCTION_Y: IconName = IconName("math-function-y")
    MATH_GREATER: IconName = IconName("math-greater")
    MATH_INTEGRAL: IconName = IconName("math-integral")
    MATH_INTEGRAL_X: IconName = IconName("math-integral-x")
    MATH_INTEGRALS: IconName = IconName("math-integrals")
    MATH_LOWER: IconName = IconName("math-lower")
    MATH_MAX: IconName = IconName("math-max")
    MATH_MIN: IconName = IconName("math-min")
    MATH_NOT: IconName = IconName("math-not")
    MATH_OFF: IconName = IconName("math-off")
    MATH_PI: IconName = IconName("math-pi")
    MATH_PI_DIVIDE_2: IconName = IconName("math-pi-divide-2")
    MATH_SYMBOLS: IconName = IconName("math-symbols")
    MATH_X_DIVIDE_2: IconName = IconName("math-x-divide-2")
    MATH_X_DIVIDE_Y: IconName = IconName("math-x-divide-y")
    MATH_X_DIVIDE_Y_2: IconName = IconName("math-x-divide-y-2")
    MATH_X_MINUS_X: IconName = IconName("math-x-minus-x")
    MATH_X_MINUS_Y: IconName = IconName("math-x-minus-y")
    MATH_X_PLUS_X: IconName = IconName("math-x-plus-x")
    MATH_X_PLUS_Y: IconName = IconName("math-x-plus-y")
    MATH_XY: IconName = IconName("math-xy")
    MATH_Y_MINUS_Y: IconName = IconName("math-y-minus-y")
    MATH_Y_PLUS_Y: IconName = IconName("math-y-plus-y")
    MAXIMIZE: IconName = IconName("maximize")
    MAXIMIZE_OFF: IconName = IconName("maximize-off")
    MEAT: IconName = IconName("meat")
    MEAT_OFF: IconName = IconName("meat-off")
    MEDAL: IconName = IconName("medal")
    MEDAL_2: IconName = IconName("medal-2")
    MEDICAL_CROSS: IconName = IconName("medical-cross")
    MEDICAL_CROSS_CIRCLE: IconName = IconName("medical-cross-circle")
    MEDICAL_CROSS_FILLED: IconName = IconName("medical-cross-filled")
    MEDICAL_CROSS_OFF: IconName = IconName("medical-cross-off")
    MEDICINE_SYRUP: IconName = IconName("medicine-syrup")
    MEEPLE: IconName = IconName("meeple")
    MENORAH: IconName = IconName("menorah")
    MENU: IconName = IconName("menu")
    MENU_2: IconName = IconName("menu-2")
    MENU_DEEP: IconName = IconName("menu-deep")
    MENU_ORDER: IconName = IconName("menu-order")
    MESSAGE: IconName = IconName("message")
    MESSAGE_2: IconName = IconName("message-2")
    MESSAGE_2_BOLT: IconName = IconName("message-2-bolt")
    MESSAGE_2_CANCEL: IconName = IconName("message-2-cancel")
    MESSAGE_2_CHECK: IconName = IconName("message-2-check")
    MESSAGE_2_CODE: IconName = IconName("message-2-code")
    MESSAGE_2_COG: IconName = IconName("message-2-cog")
    MESSAGE_2_DOLLAR: IconName = IconName("message-2-dollar")
    MESSAGE_2_DOWN: IconName = IconName("message-2-down")
    MESSAGE_2_EXCLAMATION: IconName = IconName("message-2-exclamation")
    MESSAGE_2_HEART: IconName = IconName("message-2-heart")
    MESSAGE_2_MINUS: IconName = IconName("message-2-minus")
    MESSAGE_2_OFF: IconName = IconName("message-2-off")
    MESSAGE_2_PAUSE: IconName = IconName("message-2-pause")
    MESSAGE_2_PIN: IconName = IconName("message-2-pin")
    MESSAGE_2_PLUS: IconName = IconName("message-2-plus")
    MESSAGE_2_QUESTION: IconName = IconName("message-2-question")
    MESSAGE_2_SEARCH: IconName = IconName("message-2-search")
    MESSAGE_2_SHARE: IconName = IconName("message-2-share")
    MESSAGE_2_STAR: IconName = IconName("message-2-star")
    MESSAGE_2_UP: IconName = IconName("message-2-up")
    MESSAGE_2_X: IconName = IconName("message-2-x")
    MESSAGE_BOLT: IconName = IconName("message-bolt")
    MESSAGE_CANCEL: IconName = IconName("message-cancel")
    MESSAGE_CHATBOT: IconName = IconName("message-chatbot")
    MESSAGE_CHECK: IconName = IconName("message-check")
    MESSAGE_CIRCLE: IconName = IconName("message-circle")
    MESSAGE_CIRCLE_2: IconName = IconName("message-circle-2")
    MESSAGE_CIRCLE_2_FILLED: IconName = IconName("message-circle-2-filled")
    MESSAGE_CIRCLE_BOLT: IconName = IconName("message-circle-bolt")
    MESSAGE_CIRCLE_CANCEL: IconName = IconName("message-circle-cancel")
    MESSAGE_CIRCLE_CHECK: IconName = IconName("message-circle-check")
    MESSAGE_CIRCLE_CODE: IconName = IconName("message-circle-code")
    MESSAGE_CIRCLE_COG: IconName = IconName("message-circle-cog")
    MESSAGE_CIRCLE_DOLLAR: IconName = IconName("message-circle-dollar")
    MESSAGE_CIRCLE_DOWN: IconName = IconName("message-circle-down")
    MESSAGE_CIRCLE_EXCLAMATION: IconName = IconName("message-circle-exclamation")
    MESSAGE_CIRCLE_HEART: IconName = IconName("message-circle-heart")
    MESSAGE_CIRCLE_MINUS: IconName = IconName("message-circle-minus")
    MESSAGE_CIRCLE_OFF: IconName = IconName("message-circle-off")
    MESSAGE_CIRCLE_PAUSE: IconName = IconName("message-circle-pause")
    MESSAGE_CIRCLE_PIN: IconName = IconName("message-circle-pin")
    MESSAGE_CIRCLE_PLUS: IconName = IconName("message-circle-plus")
    MESSAGE_CIRCLE_QUESTION: IconName = IconName("message-circle-question")
    MESSAGE_CIRCLE_SEARCH: IconName = IconName("message-circle-search")
    MESSAGE_CIRCLE_SHARE: IconName = IconName("message-circle-share")
    MESSAGE_CIRCLE_STAR: IconName = IconName("message-circle-star")
    MESSAGE_CIRCLE_UP: IconName = IconName("message-circle-up")
    MESSAGE_CIRCLE_X: IconName = IconName("message-circle-x")
    MESSAGE_CODE: IconName = IconName("message-code")
    MESSAGE_COG: IconName = IconName("message-cog")
    MESSAGE_DOLLAR: IconName = IconName("message-dollar")
    MESSAGE_DOTS: IconName = IconName("message-dots")
    MESSAGE_DOWN: IconName = IconName("message-down")
    MESSAGE_EXCLAMATION: IconName = IconName("message-exclamation")
    MESSAGE_FORWARD: IconName = IconName("message-forward")
    MESSAGE_HEART: IconName = IconName("message-heart")
    MESSAGE_LANGUAGE: IconName = IconName("message-language")
    MESSAGE_MINUS: IconName = IconName("message-minus")
    MESSAGE_OFF: IconName = IconName("message-off")
    MESSAGE_PAUSE: IconName = IconName("message-pause")
    MESSAGE_PIN: IconName = IconName("message-pin")
    MESSAGE_PLUS: IconName = IconName("message-plus")
    MESSAGE_QUESTION: IconName = IconName("message-question")
    MESSAGE_REPORT: IconName = IconName("message-report")
    MESSAGE_SEARCH: IconName = IconName("message-search")
    MESSAGE_SHARE: IconName = IconName("message-share")
    MESSAGE_STAR: IconName = IconName("message-star")
    MESSAGE_UP: IconName = IconName("message-up")
    MESSAGE_X: IconName = IconName("message-x")
    MESSAGES: IconName = IconName("messages")
    MESSAGES_OFF: IconName = IconName("messages-off")
    METEOR: IconName = IconName("meteor")
    METEOR_OFF: IconName = IconName("meteor-off")
    MICHELIN_BIB_GOURMAND: IconName = IconName("michelin-bib-gourmand")
    MICHELIN_STAR: IconName = IconName("michelin-star")
    MICHELIN_STAR_GREEN: IconName = IconName("michelin-star-green")
    MICKEY: IconName = IconName("mickey")
    MICKEY_FILLED: IconName = IconName("mickey-filled")
    MICROPHONE: IconName = IconName("microphone")
    MICROPHONE_2: IconName = IconName("microphone-2")
    MICROPHONE_2_OFF: IconName = IconName("microphone-2-off")
    MICROPHONE_OFF: IconName = IconName("microphone-off")
    MICROSCOPE: IconName = IconName("microscope")
    MICROSCOPE_OFF: IconName = IconName("microscope-off")
    MICROWAVE: IconName = IconName("microwave")
    MICROWAVE_OFF: IconName = IconName("microwave-off")
    MILITARY_AWARD: IconName = IconName("military-award")
    MILITARY_RANK: IconName = IconName("military-rank")
    MILK: IconName = IconName("milk")
    MILK_OFF: IconName = IconName("milk-off")
    MILKSHAKE: IconName = IconName("milkshake")
    MINIMIZE: IconName = IconName("minimize")
    MINUS: IconName = IconName("minus")
    MINUS_VERTICAL: IconName = IconName("minus-vertical")
    MIST: IconName = IconName("mist")
    MIST_OFF: IconName = IconName("mist-off")
    MOBILEDATA: IconName = IconName("mobiledata")
    MOBILEDATA_OFF: IconName = IconName("mobiledata-off")
    MONEYBAG: IconName = IconName("moneybag")
    MOOD_ANGRY: IconName = IconName("mood-angry")
    MOOD_ANNOYED: IconName = IconName("mood-annoyed")
    MOOD_ANNOYED_2: IconName = IconName("mood-annoyed-2")
    MOOD_BOY: IconName = IconName("mood-boy")
    MOOD_CHECK: IconName = IconName("mood-check")
    MOOD_COG: IconName = IconName("mood-cog")
    MOOD_CONFUZED: IconName = IconName("mood-confuzed")
    MOOD_CONFUZED_FILLED: IconName = IconName("mood-confuzed-filled")
    MOOD_CRAZY_HAPPY: IconName = IconName("mood-crazy-happy")
    MOOD_CRY: IconName = IconName("mood-cry")
    MOOD_DOLLAR: IconName = IconName("mood-dollar")
    MOOD_EDIT: IconName = IconName("mood-edit")
    MOOD_EMPTY: IconName = IconName("mood-empty")
    MOOD_EMPTY_FILLED: IconName = IconName("mood-empty-filled")
    MOOD_HAPPY: IconName = IconName("mood-happy")
    MOOD_HAPPY_FILLED: IconName = IconName("mood-happy-filled")
    MOOD_HEART: IconName = IconName("mood-heart")
    MOOD_KID: IconName = IconName("mood-kid")
    MOOD_KID_FILLED: IconName = IconName("mood-kid-filled")
    MOOD_LOOK_LEFT: IconName = IconName("mood-look-left")
    MOOD_LOOK_RIGHT: IconName = IconName("mood-look-right")
    MOOD_MINUS: IconName = IconName("mood-minus")
    MOOD_NERD: IconName = IconName("mood-nerd")
    MOOD_NERVOUS: IconName = IconName("mood-nervous")
    MOOD_NEUTRAL: IconName = IconName("mood-neutral")
    MOOD_NEUTRAL_FILLED: IconName = IconName("mood-neutral-filled")
    MOOD_OFF: IconName = IconName("mood-off")
    MOOD_PIN: IconName = IconName("mood-pin")
    MOOD_PLUS: IconName = IconName("mood-plus")
    MOOD_SAD: IconName = IconName("mood-sad")
    MOOD_SAD_2: IconName = IconName("mood-sad-2")
    MOOD_SAD_DIZZY: IconName = IconName("mood-sad-dizzy")
    MOOD_SAD_FILLED: IconName = IconName("mood-sad-filled")
    MOOD_SAD_SQUINT: IconName = IconName("mood-sad-squint")
    MOOD_SEARCH: IconName = IconName("mood-search")
    MOOD_SHARE: IconName = IconName("mood-share")
    MOOD_SICK: IconName = IconName("mood-sick")
    MOOD_SILENCE: IconName = IconName("mood-silence")
    MOOD_SING: IconName = IconName("mood-sing")
    MOOD_SMILE: IconName = IconName("mood-smile")
    MOOD_SMILE_BEAM: IconName = IconName("mood-smile-beam")
    MOOD_SMILE_DIZZY: IconName = IconName("mood-smile-dizzy")
    MOOD_SMILE_FILLED: IconName = IconName("mood-smile-filled")
    MOOD_SUPRISED: IconName = IconName("mood-suprised")
    MOOD_TONGUE: IconName = IconName("mood-tongue")
    MOOD_TONGUE_WINK: IconName = IconName("mood-tongue-wink")
    MOOD_TONGUE_WINK_2: IconName = IconName("mood-tongue-wink-2")
    MOOD_UNAMUSED: IconName = IconName("mood-unamused")
    MOOD_UP: IconName = IconName("mood-up")
    MOOD_WINK: IconName = IconName("mood-wink")
    MOOD_WINK_2: IconName = IconName("mood-wink-2")
    MOOD_WRRR: IconName = IconName("mood-wrrr")
    MOOD_X: IconName = IconName("mood-x")
    MOOD_XD: IconName = IconName("mood-xd")
    MOON: IconName = IconName("moon")
    MOON_2: IconName = IconName("moon-2")
    MOON_FILLED: IconName = IconName("moon-filled")
    MOON_OFF: IconName = IconName("moon-off")
    MOON_STARS: IconName = IconName("moon-stars")
    MOPED: IconName = IconName("moped")
    MOTORBIKE: IconName = IconName("motorbike")
    MOUNTAIN: IconName = IconName("mountain")
    MOUNTAIN_OFF: IconName = IconName("mountain-off")
    MOUSE: IconName = IconName("mouse")
    MOUSE_2: IconName = IconName("mouse-2")
    MOUSE_OFF: IconName = IconName("mouse-off")
    MOUSTACHE: IconName = IconName("moustache")
    MOVIE: IconName = IconName("movie")
    MOVIE_OFF: IconName = IconName("movie-off")
    MUG: IconName = IconName("mug")
    MUG_OFF: IconName = IconName("mug-off")
    MULTIPLIER_0_5X: IconName = IconName("multiplier-0-5x")
    MULTIPLIER_1_5X: IconName = IconName("multiplier-1-5x")
    MULTIPLIER_1X: IconName = IconName("multiplier-1x")
    MULTIPLIER_2X: IconName = IconName("multiplier-2x")
    MUSHROOM: IconName = IconName("mushroom")
    MUSHROOM_FILLED: IconName = IconName("mushroom-filled")
    MUSHROOM_OFF: IconName = IconName("mushroom-off")
    MUSIC: IconName = IconName("music")
    MUSIC_OFF: IconName = IconName("music-off")
    NAVIGATION: IconName = IconName("navigation")
    NAVIGATION_FILLED: IconName = IconName("navigation-filled")
    NAVIGATION_NORTH: IconName = IconName("navigation-north")
    NAVIGATION_OFF: IconName = IconName("navigation-off")
    NEEDLE: IconName = IconName("needle")
    NEEDLE_THREAD: IconName = IconName("needle-thread")
    NETWORK: IconName = IconName("network")
    NETWORK_OFF: IconName = IconName("network-off")
    NEW_SECTION: IconName = IconName("new-section")
    NEWS: IconName = IconName("news")
    NEWS_OFF: IconName = IconName("news-off")
    NFC: IconName = IconName("nfc")
    NFC_OFF: IconName = IconName("nfc-off")
    NO_COPYRIGHT: IconName = IconName("no-copyright")
    NO_CREATIVE_COMMONS: IconName = IconName("no-creative-commons")
    NO_DERIVATIVES: IconName = IconName("no-derivatives")
    NORTH_STAR: IconName = IconName("north-star")
    NOTE: IconName = IconName("note")
    NOTE_OFF: IconName = IconName("note-off")
    NOTEBOOK: IconName = IconName("notebook")
    NOTEBOOK_OFF: IconName = IconName("notebook-off")
    NOTES: IconName = IconName("notes")
    NOTES_OFF: IconName = IconName("notes-off")
    NOTIFICATION: IconName = IconName("notification")
    NOTIFICATION_OFF: IconName = IconName("notification-off")
    NUMBER: IconName = IconName("number")
    NUMBER_0: IconName = IconName("number-0")
    NUMBER_1: IconName = IconName("number-1")
    NUMBER_2: IconName = IconName("number-2")
    NUMBER_3: IconName = IconName("number-3")
    NUMBER_4: IconName = IconName("number-4")
    NUMBER_5: IconName = IconName("number-5")
    NUMBER_6: IconName = IconName("number-6")
    NUMBER_7: IconName = IconName("number-7")
    NUMBER_8: IconName = IconName("number-8")
    NUMBER_9: IconName = IconName("number-9")
    NUMBERS: IconName = IconName("numbers")
    NURSE: IconName = IconName("nurse")
    OCTAGON: IconName = IconName("octagon")
    OCTAGON_FILLED: IconName = IconName("octagon-filled")
    OCTAGON_OFF: IconName = IconName("octagon-off")
    OCTAHEDRON: IconName = IconName("octahedron")
    OCTAHEDRON_OFF: IconName = IconName("octahedron-off")
    OCTAHEDRON_PLUS: IconName = IconName("octahedron-plus")
    OLD: IconName = IconName("old")
    OLYMPICS: IconName = IconName("olympics")
    OLYMPICS_OFF: IconName = IconName("olympics-off")
    OM: IconName = IconName("om")
    OMEGA: IconName = IconName("omega")
    OUTBOUND: IconName = IconName("outbound")
    OUTLET: IconName = IconName("outlet")
    OVAL: IconName = IconName("oval")
    OVAL_FILLED: IconName = IconName("oval-filled")
    OVAL_VERTICAL: IconName = IconName("oval-vertical")
    OVAL_VERTICAL_FILLED: IconName = IconName("oval-vertical-filled")
    OVERLINE: IconName = IconName("overline")
    PACKAGE: IconName = IconName("package")
    PACKAGE_EXPORT: IconName = IconName("package-export")
    PACKAGE_IMPORT: IconName = IconName("package-import")
    PACKAGE_OFF: IconName = IconName("package-off")
    PACKAGES: IconName = IconName("packages")
    PACMAN: IconName = IconName("pacman")
    PAGE_BREAK: IconName = IconName("page-break")
    PAINT: IconName = IconName("paint")
    PAINT_FILLED: IconName = IconName("paint-filled")
    PAINT_OFF: IconName = IconName("paint-off")
    PALETTE: IconName = IconName("palette")
    PALETTE_OFF: IconName = IconName("palette-off")
    PANORAMA_HORIZONTAL: IconName = IconName("panorama-horizontal")
    PANORAMA_HORIZONTAL_OFF: IconName = IconName("panorama-horizontal-off")
    PANORAMA_VERTICAL: IconName = IconName("panorama-vertical")
    PANORAMA_VERTICAL_OFF: IconName = IconName("panorama-vertical-off")
    PAPER_BAG: IconName = IconName("paper-bag")
    PAPER_BAG_OFF: IconName = IconName("paper-bag-off")
    PAPERCLIP: IconName = IconName("paperclip")
    PARACHUTE: IconName = IconName("parachute")
    PARACHUTE_OFF: IconName = IconName("parachute-off")
    PARENTHESES: IconName = IconName("parentheses")
    PARENTHESES_OFF: IconName = IconName("parentheses-off")
    PARKING: IconName = IconName("parking")
    PARKING_OFF: IconName = IconName("parking-off")
    PASSWORD: IconName = IconName("password")
    PAW: IconName = IconName("paw")
    PAW_FILLED: IconName = IconName("paw-filled")
    PAW_OFF: IconName = IconName("paw-off")
    PDF: IconName = IconName("pdf")
    PEACE: IconName = IconName("peace")
    PENCIL: IconName = IconName("pencil")
    PENCIL_MINUS: IconName = IconName("pencil-minus")
    PENCIL_OFF: IconName = IconName("pencil-off")
    PENCIL_PLUS: IconName = IconName("pencil-plus")
    PENNANT: IconName = IconName("pennant")
    PENNANT_2: IconName = IconName("pennant-2")
    PENNANT_2_FILLED: IconName = IconName("pennant-2-filled")
    PENNANT_FILLED: IconName = IconName("pennant-filled")
    PENNANT_OFF: IconName = IconName("pennant-off")
    PENTAGON: IconName = IconName("pentagon")
    PENTAGON_FILLED: IconName = IconName("pentagon-filled")
    PENTAGON_OFF: IconName = IconName("pentagon-off")
    PENTAGRAM: IconName = IconName("pentagram")
    PEPPER: IconName = IconName("pepper")
    PEPPER_OFF: IconName = IconName("pepper-off")
    PERCENTAGE: IconName = IconName("percentage")
    PERFUME: IconName = IconName("perfume")
    PERSPECTIVE: IconName = IconName("perspective")
    PERSPECTIVE_OFF: IconName = IconName("perspective-off")
    PHONE: IconName = IconName("phone")
    PHONE_CALL: IconName = IconName("phone-call")
    PHONE_CALLING: IconName = IconName("phone-calling")
    PHONE_CHECK: IconName = IconName("phone-check")
    PHONE_FILLED: IconName = IconName("phone-filled")
    PHONE_INCOMING: IconName = IconName("phone-incoming")
    PHONE_OFF: IconName = IconName("phone-off")
    PHONE_OUTGOING: IconName = IconName("phone-outgoing")
    PHONE_PAUSE: IconName = IconName("phone-pause")
    PHONE_PLUS: IconName = IconName("phone-plus")
    PHONE_X: IconName = IconName("phone-x")
    PHOTO: IconName = IconName("photo")
    PHOTO_AI: IconName = IconName("photo-ai")
    PHOTO_BOLT: IconName = IconName("photo-bolt")
    PHOTO_CANCEL: IconName = IconName("photo-cancel")
    PHOTO_CHECK: IconName = IconName("photo-check")
    PHOTO_CODE: IconName = IconName("photo-code")
    PHOTO_COG: IconName = IconName("photo-cog")
    PHOTO_DOLLAR: IconName = IconName("photo-dollar")
    PHOTO_DOWN: IconName = IconName("photo-down")
    PHOTO_EDIT: IconName = IconName("photo-edit")
    PHOTO_EXCLAMATION: IconName = IconName("photo-exclamation")
    PHOTO_FILLED: IconName = IconName("photo-filled")
    PHOTO_HEART: IconName = IconName("photo-heart")
    PHOTO_MINUS: IconName = IconName("photo-minus")
    PHOTO_OFF: IconName = IconName("photo-off")
    PHOTO_PAUSE: IconName = IconName("photo-pause")
    PHOTO_PIN: IconName = IconName("photo-pin")
    PHOTO_PLUS: IconName = IconName("photo-plus")
    PHOTO_QUESTION: IconName = IconName("photo-question")
    PHOTO_SEARCH: IconName = IconName("photo-search")
    PHOTO_SENSOR: IconName = IconName("photo-sensor")
    PHOTO_SENSOR_2: IconName = IconName("photo-sensor-2")
    PHOTO_SENSOR_3: IconName = IconName("photo-sensor-3")
    PHOTO_SHARE: IconName = IconName("photo-share")
    PHOTO_SHIELD: IconName = IconName("photo-shield")
    PHOTO_STAR: IconName = IconName("photo-star")
    PHOTO_UP: IconName = IconName("photo-up")
    PHOTO_X: IconName = IconName("photo-x")
    PHYSOTHERAPIST: IconName = IconName("physotherapist")
    PIANO: IconName = IconName("piano")
    PICK: IconName = IconName("pick")
    PICTURE_IN_PICTURE: IconName = IconName("picture-in-picture")
    PICTURE_IN_PICTURE_OFF: IconName = IconName("picture-in-picture-off")
    PICTURE_IN_PICTURE_ON: IconName = IconName("picture-in-picture-on")
    PICTURE_IN_PICTURE_TOP: IconName = IconName("picture-in-picture-top")
    PIG: IconName = IconName("pig")
    PIG_MONEY: IconName = IconName("pig-money")
    PIG_OFF: IconName = IconName("pig-off")
    PILCROW: IconName = IconName("pilcrow")
    PILL: IconName = IconName("pill")
    PILL_OFF: IconName = IconName("pill-off")
    PILLS: IconName = IconName("pills")
    PIN: IconName = IconName("pin")
    PIN_FILLED: IconName = IconName("pin-filled")
    PING_PONG: IconName = IconName("ping-pong")
    PINNED: IconName = IconName("pinned")
    PINNED_FILLED: IconName = IconName("pinned-filled")
    PINNED_OFF: IconName = IconName("pinned-off")
    PIZZA: IconName = IconName("pizza")
    PIZZA_OFF: IconName = IconName("pizza-off")
    PLACEHOLDER: IconName = IconName("placeholder")
    PLANE: IconName = IconName("plane")
    PLANE_ARRIVAL: IconName = IconName("plane-arrival")
    PLANE_DEPARTURE: IconName = IconName("plane-departure")
    PLANE_INFLIGHT: IconName = IconName("plane-inflight")
    PLANE_OFF: IconName = IconName("plane-off")
    PLANE_TILT: IconName = IconName("plane-tilt")
    PLANET: IconName = IconName("planet")
    PLANET_OFF: IconName = IconName("planet-off")
    PLANT: IconName = IconName("plant")
    PLANT_2: IconName = IconName("plant-2")
    PLANT_2_OFF: IconName = IconName("plant-2-off")
    PLANT_OFF: IconName = IconName("plant-off")
    PLAY_BASKETBALL: IconName = IconName("play-basketball")
    PLAY_CARD: IconName = IconName("play-card")
    PLAY_CARD_OFF: IconName = IconName("play-card-off")
    PLAY_FOOTBALL: IconName = IconName("play-football")
    PLAY_HANDBALL: IconName = IconName("play-handball")
    PLAY_VOLLEYBALL: IconName = IconName("play-volleyball")
    PLAYER_EJECT: IconName = IconName("player-eject")
    PLAYER_EJECT_FILLED: IconName = IconName("player-eject-filled")
    PLAYER_PAUSE: IconName = IconName("player-pause")
    PLAYER_PAUSE_FILLED: IconName = IconName("player-pause-filled")
    PLAYER_PLAY: IconName = IconName("player-play")
    PLAYER_PLAY_FILLED: IconName = IconName("player-play-filled")
    PLAYER_RECORD: IconName = IconName("player-record")
    PLAYER_RECORD_FILLED: IconName = IconName("player-record-filled")
    PLAYER_SKIP_BACK: IconName = IconName("player-skip-back")
    PLAYER_SKIP_BACK_FILLED: IconName = IconName("player-skip-back-filled")
    PLAYER_SKIP_FORWARD: IconName = IconName("player-skip-forward")
    PLAYER_SKIP_FORWARD_FILLED: IconName = IconName("player-skip-forward-filled")
    PLAYER_STOP: IconName = IconName("player-stop")
    PLAYER_STOP_FILLED: IconName = IconName("player-stop-filled")
    PLAYER_TRACK_NEXT: IconName = IconName("player-track-next")
    PLAYER_TRACK_NEXT_FILLED: IconName = IconName("player-track-next-filled")
    PLAYER_TRACK_PREV: IconName = IconName("player-track-prev")
    PLAYER_TRACK_PREV_FILLED: IconName = IconName("player-track-prev-filled")
    PLAYLIST: IconName = IconName("playlist")
    PLAYLIST_ADD: IconName = IconName("playlist-add")
    PLAYLIST_OFF: IconName = IconName("playlist-off")
    PLAYLIST_X: IconName = IconName("playlist-x")
    PLAYSTATION_CIRCLE: IconName = IconName("playstation-circle")
    PLAYSTATION_SQUARE: IconName = IconName("playstation-square")
    PLAYSTATION_TRIANGLE: IconName = IconName("playstation-triangle")
    PLAYSTATION_X: IconName = IconName("playstation-x")
    PLUG: IconName = IconName("plug")
    PLUG_CONNECTED: IconName = IconName("plug-connected")
    PLUG_CONNECTED_X: IconName = IconName("plug-connected-x")
    PLUG_OFF: IconName = IconName("plug-off")
    PLUG_X: IconName = IconName("plug-x")
    PLUS: IconName = IconName("plus")
    PLUS_EQUAL: IconName = IconName("plus-equal")
    PLUS_MINUS: IconName = IconName("plus-minus")
    PNG: IconName = IconName("png")
    PODIUM: IconName = IconName("podium")
    PODIUM_OFF: IconName = IconName("podium-off")
    POINT: IconName = IconName("point")
    POINT_FILLED: IconName = IconName("point-filled")
    POINT_OFF: IconName = IconName("point-off")
    POINTER: IconName = IconName("pointer")
    POINTER_BOLT: IconName = IconName("pointer-bolt")
    POINTER_CANCEL: IconName = IconName("pointer-cancel")
    POINTER_CHECK: IconName = IconName("pointer-check")
    POINTER_CODE: IconName = IconName("pointer-code")
    POINTER_COG: IconName = IconName("pointer-cog")
    POINTER_DOLLAR: IconName = IconName("pointer-dollar")
    POINTER_DOWN: IconName = IconName("pointer-down")
    POINTER_EXCLAMATION: IconName = IconName("pointer-exclamation")
    POINTER_HEART: IconName = IconName("pointer-heart")
    POINTER_MINUS: IconName = IconName("pointer-minus")
    POINTER_OFF: IconName = IconName("pointer-off")
    POINTER_PAUSE: IconName = IconName("pointer-pause")
    POINTER_PIN: IconName = IconName("pointer-pin")
    POINTER_PLUS: IconName = IconName("pointer-plus")
    POINTER_QUESTION: IconName = IconName("pointer-question")
    POINTER_SEARCH: IconName = IconName("pointer-search")
    POINTER_SHARE: IconName = IconName("pointer-share")
    POINTER_STAR: IconName = IconName("pointer-star")
    POINTER_UP: IconName = IconName("pointer-up")
    POINTER_X: IconName = IconName("pointer-x")
    POKEBALL: IconName = IconName("pokeball")
    POKEBALL_OFF: IconName = IconName("pokeball-off")
    POKER_CHIP: IconName = IconName("poker-chip")
    POLAROID: IconName = IconName("polaroid")
    POLAROID_FILLED: IconName = IconName("polaroid-filled")
    POLYGON: IconName = IconName("polygon")
    POLYGON_OFF: IconName = IconName("polygon-off")
    POO: IconName = IconName("poo")
    POOL: IconName = IconName("pool")
    POOL_OFF: IconName = IconName("pool-off")
    POWER: IconName = IconName("power")
    PRAY: IconName = IconName("pray")
    PREMIUM_RIGHTS: IconName = IconName("premium-rights")
    PRESCRIPTION: IconName = IconName("prescription")
    PRESENTATION: IconName = IconName("presentation")
    PRESENTATION_ANALYTICS: IconName = IconName("presentation-analytics")
    PRESENTATION_OFF: IconName = IconName("presentation-off")
    PRINTER: IconName = IconName("printer")
    PRINTER_OFF: IconName = IconName("printer-off")
    PRISM: IconName = IconName("prism")
    PRISM_OFF: IconName = IconName("prism-off")
    PRISM_PLUS: IconName = IconName("prism-plus")
    PRISON: IconName = IconName("prison")
    PROGRESS: IconName = IconName("progress")
    PROGRESS_ALERT: IconName = IconName("progress-alert")
    PROGRESS_BOLT: IconName = IconName("progress-bolt")
    PROGRESS_CHECK: IconName = IconName("progress-check")
    PROGRESS_DOWN: IconName = IconName("progress-down")
    PROGRESS_HELP: IconName = IconName("progress-help")
    PROGRESS_X: IconName = IconName("progress-x")
    PROMPT: IconName = IconName("prompt")
    PROPELLER: IconName = IconName("propeller")
    PROPELLER_OFF: IconName = IconName("propeller-off")
    PUMPKIN_SCARY: IconName = IconName("pumpkin-scary")
    PUZZLE: IconName = IconName("puzzle")
    PUZZLE_2: IconName = IconName("puzzle-2")
    PUZZLE_FILLED: IconName = IconName("puzzle-filled")
    PUZZLE_OFF: IconName = IconName("puzzle-off")
    PYRAMID: IconName = IconName("pyramid")
    PYRAMID_OFF: IconName = IconName("pyramid-off")
    PYRAMID_PLUS: IconName = IconName("pyramid-plus")
    QRCODE: IconName = IconName("qrcode")
    QRCODE_OFF: IconName = IconName("qrcode-off")
    QUESTION_MARK: IconName = IconName("question-mark")
    QUOTE: IconName = IconName("quote")
    QUOTE_OFF: IconName = IconName("quote-off")
    RADAR: IconName = IconName("radar")
    RADAR_2: IconName = IconName("radar-2")
    RADAR_OFF: IconName = IconName("radar-off")
    RADIO: IconName = IconName("radio")
    RADIO_OFF: IconName = IconName("radio-off")
    RADIOACTIVE: IconName = IconName("radioactive")
    RADIOACTIVE_FILLED: IconName = IconName("radioactive-filled")
    RADIOACTIVE_OFF: IconName = IconName("radioactive-off")
    RADIUS_BOTTOM_LEFT: IconName = IconName("radius-bottom-left")
    RADIUS_BOTTOM_RIGHT: IconName = IconName("radius-bottom-right")
    RADIUS_TOP_LEFT: IconName = IconName("radius-top-left")
    RADIUS_TOP_RIGHT: IconName = IconName("radius-top-right")
    RAINBOW: IconName = IconName("rainbow")
    RAINBOW_OFF: IconName = IconName("rainbow-off")
    RATING_12_PLUS: IconName = IconName("rating-12-plus")
    RATING_14_PLUS: IconName = IconName("rating-14-plus")
    RATING_16_PLUS: IconName = IconName("rating-16-plus")
    RATING_18_PLUS: IconName = IconName("rating-18-plus")
    RATING_21_PLUS: IconName = IconName("rating-21-plus")
    RAZOR: IconName = IconName("razor")
    RAZOR_ELECTRIC: IconName = IconName("razor-electric")
    RECEIPT: IconName = IconName("receipt")
    RECEIPT_2: IconName = IconName("receipt-2")
    RECEIPT_OFF: IconName = IconName("receipt-off")
    RECEIPT_REFUND: IconName = IconName("receipt-refund")
    RECEIPT_TAX: IconName = IconName("receipt-tax")
    RECHARGING: IconName = IconName("recharging")
    RECORD_MAIL: IconName = IconName("record-mail")
    RECORD_MAIL_OFF: IconName = IconName("record-mail-off")
    RECTANGLE: IconName = IconName("rectangle")
    RECTANGLE_FILLED: IconName = IconName("rectangle-filled")
    RECTANGLE_ROUNDED_BOTTOM: IconName = IconName("rectangle-rounded-bottom")
    RECTANGLE_ROUNDED_TOP: IconName = IconName("rectangle-rounded-top")
    RECTANGLE_VERTICAL: IconName = IconName("rectangle-vertical")
    RECTANGLE_VERTICAL_FILLED: IconName = IconName("rectangle-vertical-filled")
    RECTANGULAR_PRISM: IconName = IconName("rectangular-prism")
    RECTANGULAR_PRISM_OFF: IconName = IconName("rectangular-prism-off")
    RECTANGULAR_PRISM_PLUS: IconName = IconName("rectangular-prism-plus")
    RECYCLE: IconName = IconName("recycle")
    RECYCLE_OFF: IconName = IconName("recycle-off")
    REFRESH: IconName = IconName("refresh")
    REFRESH_ALERT: IconName = IconName("refresh-alert")
    REFRESH_DOT: IconName = IconName("refresh-dot")
    REFRESH_OFF: IconName = IconName("refresh-off")
    REGEX: IconName = IconName("regex")
    REGEX_OFF: IconName = IconName("regex-off")
    REGISTERED: IconName = IconName("registered")
    RELATION_MANY_TO_MANY: IconName = IconName("relation-many-to-many")
    RELATION_ONE_TO_MANY: IconName = IconName("relation-one-to-many")
    RELATION_ONE_TO_ONE: IconName = IconName("relation-one-to-one")
    RELOAD: IconName = IconName("reload")
    REPEAT: IconName = IconName("repeat")
    REPEAT_OFF: IconName = IconName("repeat-off")
    REPEAT_ONCE: IconName = IconName("repeat-once")
    REPLACE: IconName = IconName("replace")
    REPLACE_FILLED: IconName = IconName("replace-filled")
    REPLACE_OFF: IconName = IconName("replace-off")
    REPORT: IconName = IconName("report")
    REPORT_ANALYTICS: IconName = IconName("report-analytics")
    REPORT_MEDICAL: IconName = IconName("report-medical")
    REPORT_MONEY: IconName = IconName("report-money")
    REPORT_OFF: IconName = IconName("report-off")
    REPORT_SEARCH: IconName = IconName("report-search")
    RESERVED_LINE: IconName = IconName("reserved-line")
    RESIZE: IconName = IconName("resize")
    RESTORE: IconName = IconName("restore")
    REWIND_BACKWARD_10: IconName = IconName("rewind-backward-10")
    REWIND_BACKWARD_15: IconName = IconName("rewind-backward-15")
    REWIND_BACKWARD_20: IconName = IconName("rewind-backward-20")
    REWIND_BACKWARD_30: IconName = IconName("rewind-backward-30")
    REWIND_BACKWARD_40: IconName = IconName("rewind-backward-40")
    REWIND_BACKWARD_5: IconName = IconName("rewind-backward-5")
    REWIND_BACKWARD_50: IconName = IconName("rewind-backward-50")
    REWIND_BACKWARD_60: IconName = IconName("rewind-backward-60")
    REWIND_FORWARD_10: IconName = IconName("rewind-forward-10")
    REWIND_FORWARD_15: IconName = IconName("rewind-forward-15")
    REWIND_FORWARD_20: IconName = IconName("rewind-forward-20")
    REWIND_FORWARD_30: IconName = IconName("rewind-forward-30")
    REWIND_FORWARD_40: IconName = IconName("rewind-forward-40")
    REWIND_FORWARD_5: IconName = IconName("rewind-forward-5")
    REWIND_FORWARD_50: IconName = IconName("rewind-forward-50")
    REWIND_FORWARD_60: IconName = IconName("rewind-forward-60")
    RIBBON_HEALTH: IconName = IconName("ribbon-health")
    RINGS: IconName = IconName("rings")
    RIPPLE: IconName = IconName("ripple")
    RIPPLE_OFF: IconName = IconName("ripple-off")
    ROAD: IconName = IconName("road")
    ROAD_OFF: IconName = IconName("road-off")
    ROAD_SIGN: IconName = IconName("road-sign")
    ROBOT: IconName = IconName("robot")
    ROBOT_OFF: IconName = IconName("robot-off")
    ROCKET: IconName = IconName("rocket")
    ROCKET_OFF: IconName = IconName("rocket-off")
    ROLLER_SKATING: IconName = IconName("roller-skating")
    ROLLERCOASTER: IconName = IconName("rollercoaster")
    ROLLERCOASTER_OFF: IconName = IconName("rollercoaster-off")
    ROSETTE: IconName = IconName("rosette")
    ROSETTE_FILLED: IconName = IconName("rosette-filled")
    ROSETTE_NUMBER_0: IconName = IconName("rosette-number-0")
    ROSETTE_NUMBER_1: IconName = IconName("rosette-number-1")
    ROSETTE_NUMBER_2: IconName = IconName("rosette-number-2")
    ROSETTE_NUMBER_3: IconName = IconName("rosette-number-3")
    ROSETTE_NUMBER_4: IconName = IconName("rosette-number-4")
    ROSETTE_NUMBER_5: IconName = IconName("rosette-number-5")
    ROSETTE_NUMBER_6: IconName = IconName("rosette-number-6")
    ROSETTE_NUMBER_7: IconName = IconName("rosette-number-7")
    ROSETTE_NUMBER_8: IconName = IconName("rosette-number-8")
    ROSETTE_NUMBER_9: IconName = IconName("rosette-number-9")
    ROTATE: IconName = IconName("rotate")
    ROTATE_2: IconName = IconName("rotate-2")
    ROTATE_360: IconName = IconName("rotate-360")
    ROTATE_CLOCKWISE: IconName = IconName("rotate-clockwise")
    ROTATE_CLOCKWISE_2: IconName = IconName("rotate-clockwise-2")
    ROTATE_DOT: IconName = IconName("rotate-dot")
    ROTATE_RECTANGLE: IconName = IconName("rotate-rectangle")
    ROUTE: IconName = IconName("route")
    ROUTE_2: IconName = IconName("route-2")
    ROUTE_OFF: IconName = IconName("route-off")
    ROUTER: IconName = IconName("router")
    ROUTER_OFF: IconName = IconName("router-off")
    ROW_INSERT_BOTTOM: IconName = IconName("row-insert-bottom")
    ROW_INSERT_TOP: IconName = IconName("row-insert-top")
    ROW_REMOVE: IconName = IconName("row-remove")
    RSS: IconName = IconName("rss")
    RUBBER_STAMP: IconName = IconName("rubber-stamp")
    RUBBER_STAMP_OFF: IconName = IconName("rubber-stamp-off")
    RULER: IconName = IconName("ruler")
    RULER_2: IconName = IconName("ruler-2")
    RULER_2_OFF: IconName = IconName("ruler-2-off")
    RULER_3: IconName = IconName("ruler-3")
    RULER_MEASURE: IconName = IconName("ruler-measure")
    RULER_OFF: IconName = IconName("ruler-off")
    RUN: IconName = IconName("run")
    S_TURN_DOWN: IconName = IconName("s-turn-down")
    S_TURN_LEFT: IconName = IconName("s-turn-left")
    S_TURN_RIGHT: IconName = IconName("s-turn-right")
    S_TURN_UP: IconName = IconName("s-turn-up")
    SAILBOAT: IconName = IconName("sailboat")
    SAILBOAT_2: IconName = IconName("sailboat-2")
    SAILBOAT_OFF: IconName = IconName("sailboat-off")
    SALAD: IconName = IconName("salad")
    SALT: IconName = IconName("salt")
    SATELLITE: IconName = IconName("satellite")
    SATELLITE_OFF: IconName = IconName("satellite-off")
    SAUSAGE: IconName = IconName("sausage")
    SCALE: IconName = IconName("scale")
    SCALE_OFF: IconName = IconName("scale-off")
    SCALE_OUTLINE: IconName = IconName("scale-outline")
    SCALE_OUTLINE_OFF: IconName = IconName("scale-outline-off")
    SCAN: IconName = IconName("scan")
    SCAN_EYE: IconName = IconName("scan-eye")
    SCHEMA: IconName = IconName("schema")
    SCHEMA_OFF: IconName = IconName("schema-off")
    SCHOOL: IconName = IconName("school")
    SCHOOL_BELL: IconName = IconName("school-bell")
    SCHOOL_OFF: IconName = IconName("school-off")
    SCISSORS: IconName = IconName("scissors")
    SCISSORS_OFF: IconName = IconName("scissors-off")
    SCOOTER: IconName = IconName("scooter")
    SCOOTER_ELECTRIC: IconName = IconName("scooter-electric")
    SCOREBOARD: IconName = IconName("scoreboard")
    SCREEN_SHARE: IconName = IconName("screen-share")
    SCREEN_SHARE_OFF: IconName = IconName("screen-share-off")
    SCREENSHOT: IconName = IconName("screenshot")
    SCRIBBLE: IconName = IconName("scribble")
    SCRIBBLE_OFF: IconName = IconName("scribble-off")
    SCRIPT: IconName = IconName("script")
    SCRIPT_MINUS: IconName = IconName("script-minus")
    SCRIPT_PLUS: IconName = IconName("script-plus")
    SCRIPT_X: IconName = IconName("script-x")
    SCUBA_MASK: IconName = IconName("scuba-mask")
    SCUBA_MASK_OFF: IconName = IconName("scuba-mask-off")
    SDK: IconName = IconName("sdk")
    SEARCH: IconName = IconName("search")
    SEARCH_OFF: IconName = IconName("search-off")
    SECTION: IconName = IconName("section")
    SECTION_SIGN: IconName = IconName("section-sign")
    SEEDING: IconName = IconName("seeding")
    SEEDING_OFF: IconName = IconName("seeding-off")
    SELECT: IconName = IconName("select")
    SELECT_ALL: IconName = IconName("select-all")
    SELECTOR: IconName = IconName("selector")
    SEND: IconName = IconName("send")
    SEND_OFF: IconName = IconName("send-off")
    SEO: IconName = IconName("seo")
    SEPARATOR: IconName = IconName("separator")
    SEPARATOR_HORIZONTAL: IconName = IconName("separator-horizontal")
    SEPARATOR_VERTICAL: IconName = IconName("separator-vertical")
    SERVER: IconName = IconName("server")
    SERVER_2: IconName = IconName("server-2")
    SERVER_BOLT: IconName = IconName("server-bolt")
    SERVER_COG: IconName = IconName("server-cog")
    SERVER_OFF: IconName = IconName("server-off")
    SERVICEMARK: IconName = IconName("servicemark")
    SETTINGS: IconName = IconName("settings")
    SETTINGS_2: IconName = IconName("settings-2")
    SETTINGS_AUTOMATION: IconName = IconName("settings-automation")
    SETTINGS_BOLT: IconName = IconName("settings-bolt")
    SETTINGS_CANCEL: IconName = IconName("settings-cancel")
    SETTINGS_CHECK: IconName = IconName("settings-check")
    SETTINGS_CODE: IconName = IconName("settings-code")
    SETTINGS_COG: IconName = IconName("settings-cog")
    SETTINGS_DOLLAR: IconName = IconName("settings-dollar")
    SETTINGS_DOWN: IconName = IconName("settings-down")
    SETTINGS_EXCLAMATION: IconName = IconName("settings-exclamation")
    SETTINGS_FILLED: IconName = IconName("settings-filled")
    SETTINGS_HEART: IconName = IconName("settings-heart")
    SETTINGS_MINUS: IconName = IconName("settings-minus")
    SETTINGS_OFF: IconName = IconName("settings-off")
    SETTINGS_PAUSE: IconName = IconName("settings-pause")
    SETTINGS_PIN: IconName = IconName("settings-pin")
    SETTINGS_PLUS: IconName = IconName("settings-plus")
    SETTINGS_QUESTION: IconName = IconName("settings-question")
    SETTINGS_SEARCH: IconName = IconName("settings-search")
    SETTINGS_SHARE: IconName = IconName("settings-share")
    SETTINGS_STAR: IconName = IconName("settings-star")
    SETTINGS_UP: IconName = IconName("settings-up")
    SETTINGS_X: IconName = IconName("settings-x")
    SHADOW: IconName = IconName("shadow")
    SHADOW_OFF: IconName = IconName("shadow-off")
    SHAPE: IconName = IconName("shape")
    SHAPE_2: IconName = IconName("shape-2")
    SHAPE_3: IconName = IconName("shape-3")
    SHAPE_OFF: IconName = IconName("shape-off")
    SHARE: IconName = IconName("share")
    SHARE_2: IconName = IconName("share-2")
    SHARE_3: IconName = IconName("share-3")
    SHARE_OFF: IconName = IconName("share-off")
    SHI_JUMPING: IconName = IconName("shi-jumping")
    SHIELD: IconName = IconName("shield")
    SHIELD_BOLT: IconName = IconName("shield-bolt")
    SHIELD_CANCEL: IconName = IconName("shield-cancel")
    SHIELD_CHECK: IconName = IconName("shield-check")
    SHIELD_CHECK_FILLED: IconName = IconName("shield-check-filled")
    SHIELD_CHECKERED: IconName = IconName("shield-checkered")
    SHIELD_CHECKERED_FILLED: IconName = IconName("shield-checkered-filled")
    SHIELD_CHEVRON: IconName = IconName("shield-chevron")
    SHIELD_CODE: IconName = IconName("shield-code")
    SHIELD_COG: IconName = IconName("shield-cog")
    SHIELD_DOLLAR: IconName = IconName("shield-dollar")
    SHIELD_DOWN: IconName = IconName("shield-down")
    SHIELD_EXCLAMATION: IconName = IconName("shield-exclamation")
    SHIELD_FILLED: IconName = IconName("shield-filled")
    SHIELD_HALF: IconName = IconName("shield-half")
    SHIELD_HALF_FILLED: IconName = IconName("shield-half-filled")
    SHIELD_HEART: IconName = IconName("shield-heart")
    SHIELD_LOCK: IconName = IconName("shield-lock")
    SHIELD_LOCK_FILLED: IconName = IconName("shield-lock-filled")
    SHIELD_MINUS: IconName = IconName("shield-minus")
    SHIELD_OFF: IconName = IconName("shield-off")
    SHIELD_PAUSE: IconName = IconName("shield-pause")
    SHIELD_PIN: IconName = IconName("shield-pin")
    SHIELD_PLUS: IconName = IconName("shield-plus")
    SHIELD_QUESTION: IconName = IconName("shield-question")
    SHIELD_SEARCH: IconName = IconName("shield-search")
    SHIELD_SHARE: IconName = IconName("shield-share")
    SHIELD_STAR: IconName = IconName("shield-star")
    SHIELD_UP: IconName = IconName("shield-up")
    SHIELD_X: IconName = IconName("shield-x")
    SHIP: IconName = IconName("ship")
    SHIP_OFF: IconName = IconName("ship-off")
    SHIRT: IconName = IconName("shirt")
    SHIRT_FILLED: IconName = IconName("shirt-filled")
    SHIRT_OFF: IconName = IconName("shirt-off")
    SHIRT_SPORT: IconName = IconName("shirt-sport")
    SHOE: IconName = IconName("shoe")
    SHOE_OFF: IconName = IconName("shoe-off")
    SHOPPING_BAG: IconName = IconName("shopping-bag")
    SHOPPING_CART: IconName = IconName("shopping-cart")
    SHOPPING_CART_DISCOUNT: IconName = IconName("shopping-cart-discount")
    SHOPPING_CART_OFF: IconName = IconName("shopping-cart-off")
    SHOPPING_CART_PLUS: IconName = IconName("shopping-cart-plus")
    SHOPPING_CART_X: IconName = IconName("shopping-cart-x")
    SHOVEL: IconName = IconName("shovel")
    SHREDDER: IconName = IconName("shredder")
    SIGN_LEFT: IconName = IconName("sign-left")
    SIGN_LEFT_FILLED: IconName = IconName("sign-left-filled")
    SIGN_RIGHT: IconName = IconName("sign-right")
    SIGN_RIGHT_FILLED: IconName = IconName("sign-right-filled")
    SIGNAL_2G: IconName = IconName("signal-2g")
    SIGNAL_3G: IconName = IconName("signal-3g")
    SIGNAL_4G: IconName = IconName("signal-4g")
    SIGNAL_4G_PLUS: IconName = IconName("signal-4g-plus")
    SIGNAL_5G: IconName = IconName("signal-5g")
    SIGNAL_6G: IconName = IconName("signal-6g")
    SIGNAL_E: IconName = IconName("signal-e")
    SIGNAL_G: IconName = IconName("signal-g")
    SIGNAL_H: IconName = IconName("signal-h")
    SIGNAL_H_PLUS: IconName = IconName("signal-h-plus")
    SIGNAL_LTE: IconName = IconName("signal-lte")
    SIGNATURE: IconName = IconName("signature")
    SIGNATURE_OFF: IconName = IconName("signature-off")
    SITEMAP: IconName = IconName("sitemap")
    SITEMAP_OFF: IconName = IconName("sitemap-off")
    SKATEBOARD: IconName = IconName("skateboard")
    SKATEBOARD_OFF: IconName = IconName("skateboard-off")
    SKATEBOARDING: IconName = IconName("skateboarding")
    SKULL: IconName = IconName("skull")
    SLASH: IconName = IconName("slash")
    SLASHES: IconName = IconName("slashes")
    SLEIGH: IconName = IconName("sleigh")
    SLICE: IconName = IconName("slice")
    SLIDESHOW: IconName = IconName("slideshow")
    SMART_HOME: IconName = IconName("smart-home")
    SMART_HOME_OFF: IconName = IconName("smart-home-off")
    SMOKING: IconName = IconName("smoking")
    SMOKING_NO: IconName = IconName("smoking-no")
    SNOWFLAKE: IconName = IconName("snowflake")
    SNOWFLAKE_OFF: IconName = IconName("snowflake-off")
    SNOWMAN: IconName = IconName("snowman")
    SOCCER_FIELD: IconName = IconName("soccer-field")
    SOCIAL: IconName = IconName("social")
    SOCIAL_OFF: IconName = IconName("social-off")
    SOCK: IconName = IconName("sock")
    SOFA: IconName = IconName("sofa")
    SOFA_OFF: IconName = IconName("sofa-off")
    SOLAR_PANEL: IconName = IconName("solar-panel")
    SOLAR_PANEL_2: IconName = IconName("solar-panel-2")
    SORT_0_9: IconName = IconName("sort-0-9")
    SORT_9_0: IconName = IconName("sort-9-0")
    SORT_A_Z: IconName = IconName("sort-a-z")
    SORT_ASCENDING: IconName = IconName("sort-ascending")
    SORT_ASCENDING_2: IconName = IconName("sort-ascending-2")
    SORT_ASCENDING_LETTERS: IconName = IconName("sort-ascending-letters")
    SORT_ASCENDING_NUMBERS: IconName = IconName("sort-ascending-numbers")
    SORT_DESCENDING: IconName = IconName("sort-descending")
    SORT_DESCENDING_2: IconName = IconName("sort-descending-2")
    SORT_DESCENDING_LETTERS: IconName = IconName("sort-descending-letters")
    SORT_DESCENDING_NUMBERS: IconName = IconName("sort-descending-numbers")
    SORT_Z_A: IconName = IconName("sort-z-a")
    SOS: IconName = IconName("sos")
    SOUP: IconName = IconName("soup")
    SOUP_OFF: IconName = IconName("soup-off")
    SOURCE_CODE: IconName = IconName("source-code")
    SPACE: IconName = IconName("space")
    SPACE_OFF: IconName = IconName("space-off")
    SPACING_HORIZONTAL: IconName = IconName("spacing-horizontal")
    SPACING_VERTICAL: IconName = IconName("spacing-vertical")
    SPADE: IconName = IconName("spade")
    SPADE_FILLED: IconName = IconName("spade-filled")
    SPARKLES: IconName = IconName("sparkles")
    SPEAKERPHONE: IconName = IconName("speakerphone")
    SPEEDBOAT: IconName = IconName("speedboat")
    SPHERE: IconName = IconName("sphere")
    SPHERE_OFF: IconName = IconName("sphere-off")
    SPHERE_PLUS: IconName = IconName("sphere-plus")
    SPIDER: IconName = IconName("spider")
    SPIRAL: IconName = IconName("spiral")
    SPIRAL_OFF: IconName = IconName("spiral-off")
    SPORT_BILLARD: IconName = IconName("sport-billard")
    SPRAY: IconName = IconName("spray")
    SPY: IconName = IconName("spy")
    SPY_OFF: IconName = IconName("spy-off")
    SQL: IconName = IconName("sql")
    SQUARE: IconName = IconName("square")
    SQUARE_0_FILLED: IconName = IconName("square-0-filled")
    SQUARE_1_FILLED: IconName = IconName("square-1-filled")
    SQUARE_2_FILLED: IconName = IconName("square-2-filled")
    SQUARE_3_FILLED: IconName = IconName("square-3-filled")
    SQUARE_4_FILLED: IconName = IconName("square-4-filled")
    SQUARE_5_FILLED: IconName = IconName("square-5-filled")
    SQUARE_6_FILLED: IconName = IconName("square-6-filled")
    SQUARE_7_FILLED: IconName = IconName("square-7-filled")
    SQUARE_8_FILLED: IconName = IconName("square-8-filled")
    SQUARE_9_FILLED: IconName = IconName("square-9-filled")
    SQUARE_ARROW_DOWN: IconName = IconName("square-arrow-down")
    SQUARE_ARROW_LEFT: IconName = IconName("square-arrow-left")
    SQUARE_ARROW_RIGHT: IconName = IconName("square-arrow-right")
    SQUARE_ARROW_UP: IconName = IconName("square-arrow-up")
    SQUARE_ASTERISK: IconName = IconName("square-asterisk")
    SQUARE_CHECK: IconName = IconName("square-check")
    SQUARE_CHECK_FILLED: IconName = IconName("square-check-filled")
    SQUARE_CHEVRON_DOWN: IconName = IconName("square-chevron-down")
    SQUARE_CHEVRON_LEFT: IconName = IconName("square-chevron-left")
    SQUARE_CHEVRON_RIGHT: IconName = IconName("square-chevron-right")
    SQUARE_CHEVRON_UP: IconName = IconName("square-chevron-up")
    SQUARE_CHEVRONS_DOWN: IconName = IconName("square-chevrons-down")
    SQUARE_CHEVRONS_LEFT: IconName = IconName("square-chevrons-left")
    SQUARE_CHEVRONS_RIGHT: IconName = IconName("square-chevrons-right")
    SQUARE_CHEVRONS_UP: IconName = IconName("square-chevrons-up")
    SQUARE_DOT: IconName = IconName("square-dot")
    SQUARE_F0: IconName = IconName("square-f0")
    SQUARE_F0_FILLED: IconName = IconName("square-f0-filled")
    SQUARE_F1: IconName = IconName("square-f1")
    SQUARE_F1_FILLED: IconName = IconName("square-f1-filled")
    SQUARE_F2: IconName = IconName("square-f2")
    SQUARE_F2_FILLED: IconName = IconName("square-f2-filled")
    SQUARE_F3: IconName = IconName("square-f3")
    SQUARE_F3_FILLED: IconName = IconName("square-f3-filled")
    SQUARE_F4: IconName = IconName("square-f4")
    SQUARE_F4_FILLED: IconName = IconName("square-f4-filled")
    SQUARE_F5: IconName = IconName("square-f5")
    SQUARE_F5_FILLED: IconName = IconName("square-f5-filled")
    SQUARE_F6: IconName = IconName("square-f6")
    SQUARE_F6_FILLED: IconName = IconName("square-f6-filled")
    SQUARE_F7: IconName = IconName("square-f7")
    SQUARE_F7_FILLED: IconName = IconName("square-f7-filled")
    SQUARE_F8: IconName = IconName("square-f8")
    SQUARE_F8_FILLED: IconName = IconName("square-f8-filled")
    SQUARE_F9: IconName = IconName("square-f9")
    SQUARE_F9_FILLED: IconName = IconName("square-f9-filled")
    SQUARE_FORBID: IconName = IconName("square-forbid")
    SQUARE_FORBID_2: IconName = IconName("square-forbid-2")
    SQUARE_HALF: IconName = IconName("square-half")
    SQUARE_KEY: IconName = IconName("square-key")
    SQUARE_LETTER_A: IconName = IconName("square-letter-a")
    SQUARE_LETTER_B: IconName = IconName("square-letter-b")
    SQUARE_LETTER_C: IconName = IconName("square-letter-c")
    SQUARE_LETTER_D: IconName = IconName("square-letter-d")
    SQUARE_LETTER_E: IconName = IconName("square-letter-e")
    SQUARE_LETTER_F: IconName = IconName("square-letter-f")
    SQUARE_LETTER_G: IconName = IconName("square-letter-g")
    SQUARE_LETTER_H: IconName = IconName("square-letter-h")
    SQUARE_LETTER_I: IconName = IconName("square-letter-i")
    SQUARE_LETTER_J: IconName = IconName("square-letter-j")
    SQUARE_LETTER_K: IconName = IconName("square-letter-k")
    SQUARE_LETTER_L: IconName = IconName("square-letter-l")
    SQUARE_LETTER_M: IconName = IconName("square-letter-m")
    SQUARE_LETTER_N: IconName = IconName("square-letter-n")
    SQUARE_LETTER_O: IconName = IconName("square-letter-o")
    SQUARE_LETTER_P: IconName = IconName("square-letter-p")
    SQUARE_LETTER_Q: IconName = IconName("square-letter-q")
    SQUARE_LETTER_R: IconName = IconName("square-letter-r")
    SQUARE_LETTER_S: IconName = IconName("square-letter-s")
    SQUARE_LETTER_T: IconName = IconName("square-letter-t")
    SQUARE_LETTER_U: IconName = IconName("square-letter-u")
    SQUARE_LETTER_V: IconName = IconName("square-letter-v")
    SQUARE_LETTER_W: IconName = IconName("square-letter-w")
    SQUARE_LETTER_X: IconName = IconName("square-letter-x")
    SQUARE_LETTER_Y: IconName = IconName("square-letter-y")
    SQUARE_LETTER_Z: IconName = IconName("square-letter-z")
    SQUARE_MINUS: IconName = IconName("square-minus")
    SQUARE_NUMBER_0: IconName = IconName("square-number-0")
    SQUARE_NUMBER_1: IconName = IconName("square-number-1")
    SQUARE_NUMBER_2: IconName = IconName("square-number-2")
    SQUARE_NUMBER_3: IconName = IconName("square-number-3")
    SQUARE_NUMBER_4: IconName = IconName("square-number-4")
    SQUARE_NUMBER_5: IconName = IconName("square-number-5")
    SQUARE_NUMBER_6: IconName = IconName("square-number-6")
    SQUARE_NUMBER_7: IconName = IconName("square-number-7")
    SQUARE_NUMBER_8: IconName = IconName("square-number-8")
    SQUARE_NUMBER_9: IconName = IconName("square-number-9")
    SQUARE_OFF: IconName = IconName("square-off")
    SQUARE_PLUS: IconName = IconName("square-plus")
    SQUARE_ROOT: IconName = IconName("square-root")
    SQUARE_ROOT_2: IconName = IconName("square-root-2")
    SQUARE_ROTATED: IconName = IconName("square-rotated")
    SQUARE_ROTATED_FILLED: IconName = IconName("square-rotated-filled")
    SQUARE_ROTATED_FORBID: IconName = IconName("square-rotated-forbid")
    SQUARE_ROTATED_FORBID_2: IconName = IconName("square-rotated-forbid-2")
    SQUARE_ROTATED_OFF: IconName = IconName("square-rotated-off")
    SQUARE_ROUNDED: IconName = IconName("square-rounded")
    SQUARE_ROUNDED_ARROW_DOWN: IconName = IconName("square-rounded-arrow-down")
    SQUARE_ROUNDED_ARROW_DOWN_FILLED: IconName = IconName(
        "square-rounded-arrow-down-filled"
    )
    SQUARE_ROUNDED_ARROW_LEFT: IconName = IconName("square-rounded-arrow-left")
    SQUARE_ROUNDED_ARROW_LEFT_FILLED: IconName = IconName(
        "square-rounded-arrow-left-filled"
    )
    SQUARE_ROUNDED_ARROW_RIGHT: IconName = IconName("square-rounded-arrow-right")
    SQUARE_ROUNDED_ARROW_RIGHT_FILLED: IconName = IconName(
        "square-rounded-arrow-right-filled"
    )
    SQUARE_ROUNDED_ARROW_UP: IconName = IconName("square-rounded-arrow-up")
    SQUARE_ROUNDED_ARROW_UP_FILLED: IconName = IconName(
        "square-rounded-arrow-up-filled"
    )
    SQUARE_ROUNDED_CHECK: IconName = IconName("square-rounded-check")
    SQUARE_ROUNDED_CHECK_FILLED: IconName = IconName("square-rounded-check-filled")
    SQUARE_ROUNDED_CHEVRON_DOWN: IconName = IconName("square-rounded-chevron-down")
    SQUARE_ROUNDED_CHEVRON_DOWN_FILLED: IconName = IconName(
        "square-rounded-chevron-down-filled"
    )
    SQUARE_ROUNDED_CHEVRON_LEFT: IconName = IconName("square-rounded-chevron-left")
    SQUARE_ROUNDED_CHEVRON_LEFT_FILLED: IconName = IconName(
        "square-rounded-chevron-left-filled"
    )
    SQUARE_ROUNDED_CHEVRON_RIGHT: IconName = IconName("square-rounded-chevron-right")
    SQUARE_ROUNDED_CHEVRON_RIGHT_FILLED: IconName = IconName(
        "square-rounded-chevron-right-filled"
    )
    SQUARE_ROUNDED_CHEVRON_UP: IconName = IconName("square-rounded-chevron-up")
    SQUARE_ROUNDED_CHEVRON_UP_FILLED: IconName = IconName(
        "square-rounded-chevron-up-filled"
    )
    SQUARE_ROUNDED_CHEVRONS_DOWN: IconName = IconName("square-rounded-chevrons-down")
    SQUARE_ROUNDED_CHEVRONS_DOWN_FILLED: IconName = IconName(
        "square-rounded-chevrons-down-filled"
    )
    SQUARE_ROUNDED_CHEVRONS_LEFT: IconName = IconName("square-rounded-chevrons-left")
    SQUARE_ROUNDED_CHEVRONS_LEFT_FILLED: IconName = IconName(
        "square-rounded-chevrons-left-filled"
    )
    SQUARE_ROUNDED_CHEVRONS_RIGHT: IconName = IconName("square-rounded-chevrons-right")
    SQUARE_ROUNDED_CHEVRONS_RIGHT_FILLED: IconName = IconName(
        "square-rounded-chevrons-right-filled"
    )
    SQUARE_ROUNDED_CHEVRONS_UP: IconName = IconName("square-rounded-chevrons-up")
    SQUARE_ROUNDED_CHEVRONS_UP_FILLED: IconName = IconName(
        "square-rounded-chevrons-up-filled"
    )
    SQUARE_ROUNDED_FILLED: IconName = IconName("square-rounded-filled")
    SQUARE_ROUNDED_LETTER_A: IconName = IconName("square-rounded-letter-a")
    SQUARE_ROUNDED_LETTER_B: IconName = IconName("square-rounded-letter-b")
    SQUARE_ROUNDED_LETTER_C: IconName = IconName("square-rounded-letter-c")
    SQUARE_ROUNDED_LETTER_D: IconName = IconName("square-rounded-letter-d")
    SQUARE_ROUNDED_LETTER_E: IconName = IconName("square-rounded-letter-e")
    SQUARE_ROUNDED_LETTER_F: IconName = IconName("square-rounded-letter-f")
    SQUARE_ROUNDED_LETTER_G: IconName = IconName("square-rounded-letter-g")
    SQUARE_ROUNDED_LETTER_H: IconName = IconName("square-rounded-letter-h")
    SQUARE_ROUNDED_LETTER_I: IconName = IconName("square-rounded-letter-i")
    SQUARE_ROUNDED_LETTER_J: IconName = IconName("square-rounded-letter-j")
    SQUARE_ROUNDED_LETTER_K: IconName = IconName("square-rounded-letter-k")
    SQUARE_ROUNDED_LETTER_L: IconName = IconName("square-rounded-letter-l")
    SQUARE_ROUNDED_LETTER_M: IconName = IconName("square-rounded-letter-m")
    SQUARE_ROUNDED_LETTER_N: IconName = IconName("square-rounded-letter-n")
    SQUARE_ROUNDED_LETTER_O: IconName = IconName("square-rounded-letter-o")
    SQUARE_ROUNDED_LETTER_P: IconName = IconName("square-rounded-letter-p")
    SQUARE_ROUNDED_LETTER_Q: IconName = IconName("square-rounded-letter-q")
    SQUARE_ROUNDED_LETTER_R: IconName = IconName("square-rounded-letter-r")
    SQUARE_ROUNDED_LETTER_S: IconName = IconName("square-rounded-letter-s")
    SQUARE_ROUNDED_LETTER_T: IconName = IconName("square-rounded-letter-t")
    SQUARE_ROUNDED_LETTER_U: IconName = IconName("square-rounded-letter-u")
    SQUARE_ROUNDED_LETTER_V: IconName = IconName("square-rounded-letter-v")
    SQUARE_ROUNDED_LETTER_W: IconName = IconName("square-rounded-letter-w")
    SQUARE_ROUNDED_LETTER_X: IconName = IconName("square-rounded-letter-x")
    SQUARE_ROUNDED_LETTER_Y: IconName = IconName("square-rounded-letter-y")
    SQUARE_ROUNDED_LETTER_Z: IconName = IconName("square-rounded-letter-z")
    SQUARE_ROUNDED_MINUS: IconName = IconName("square-rounded-minus")
    SQUARE_ROUNDED_NUMBER_0: IconName = IconName("square-rounded-number-0")
    SQUARE_ROUNDED_NUMBER_0_FILLED: IconName = IconName(
        "square-rounded-number-0-filled"
    )
    SQUARE_ROUNDED_NUMBER_1: IconName = IconName("square-rounded-number-1")
    SQUARE_ROUNDED_NUMBER_1_FILLED: IconName = IconName(
        "square-rounded-number-1-filled"
    )
    SQUARE_ROUNDED_NUMBER_2: IconName = IconName("square-rounded-number-2")
    SQUARE_ROUNDED_NUMBER_2_FILLED: IconName = IconName(
        "square-rounded-number-2-filled"
    )
    SQUARE_ROUNDED_NUMBER_3: IconName = IconName("square-rounded-number-3")
    SQUARE_ROUNDED_NUMBER_3_FILLED: IconName = IconName(
        "square-rounded-number-3-filled"
    )
    SQUARE_ROUNDED_NUMBER_4: IconName = IconName("square-rounded-number-4")
    SQUARE_ROUNDED_NUMBER_4_FILLED: IconName = IconName(
        "square-rounded-number-4-filled"
    )
    SQUARE_ROUNDED_NUMBER_5: IconName = IconName("square-rounded-number-5")
    SQUARE_ROUNDED_NUMBER_5_FILLED: IconName = IconName(
        "square-rounded-number-5-filled"
    )
    SQUARE_ROUNDED_NUMBER_6: IconName = IconName("square-rounded-number-6")
    SQUARE_ROUNDED_NUMBER_6_FILLED: IconName = IconName(
        "square-rounded-number-6-filled"
    )
    SQUARE_ROUNDED_NUMBER_7: IconName = IconName("square-rounded-number-7")
    SQUARE_ROUNDED_NUMBER_7_FILLED: IconName = IconName(
        "square-rounded-number-7-filled"
    )
    SQUARE_ROUNDED_NUMBER_8: IconName = IconName("square-rounded-number-8")
    SQUARE_ROUNDED_NUMBER_8_FILLED: IconName = IconName(
        "square-rounded-number-8-filled"
    )
    SQUARE_ROUNDED_NUMBER_9: IconName = IconName("square-rounded-number-9")
    SQUARE_ROUNDED_NUMBER_9_FILLED: IconName = IconName(
        "square-rounded-number-9-filled"
    )
    SQUARE_ROUNDED_PLUS: IconName = IconName("square-rounded-plus")
    SQUARE_ROUNDED_PLUS_FILLED: IconName = IconName("square-rounded-plus-filled")
    SQUARE_ROUNDED_X: IconName = IconName("square-rounded-x")
    SQUARE_ROUNDED_X_FILLED: IconName = IconName("square-rounded-x-filled")
    SQUARE_TOGGLE: IconName = IconName("square-toggle")
    SQUARE_TOGGLE_HORIZONTAL: IconName = IconName("square-toggle-horizontal")
    SQUARE_X: IconName = IconName("square-x")
    SQUARES_DIAGONAL: IconName = IconName("squares-diagonal")
    SQUARES_FILLED: IconName = IconName("squares-filled")
    STACK: IconName = IconName("stack")
    STACK_2: IconName = IconName("stack-2")
    STACK_3: IconName = IconName("stack-3")
    STACK_POP: IconName = IconName("stack-pop")
    STACK_PUSH: IconName = IconName("stack-push")
    STAIRS: IconName = IconName("stairs")
    STAIRS_DOWN: IconName = IconName("stairs-down")
    STAIRS_UP: IconName = IconName("stairs-up")
    STAR: IconName = IconName("star")
    STAR_FILLED: IconName = IconName("star-filled")
    STAR_HALF: IconName = IconName("star-half")
    STAR_HALF_FILLED: IconName = IconName("star-half-filled")
    STAR_OFF: IconName = IconName("star-off")
    STARS: IconName = IconName("stars")
    STARS_FILLED: IconName = IconName("stars-filled")
    STARS_OFF: IconName = IconName("stars-off")
    STATUS_CHANGE: IconName = IconName("status-change")
    STEAM: IconName = IconName("steam")
    STEERING_WHEEL: IconName = IconName("steering-wheel")
    STEERING_WHEEL_OFF: IconName = IconName("steering-wheel-off")
    STEP_INTO: IconName = IconName("step-into")
    STEP_OUT: IconName = IconName("step-out")
    STEREO_GLASSES: IconName = IconName("stereo-glasses")
    STETHOSCOPE: IconName = IconName("stethoscope")
    STETHOSCOPE_OFF: IconName = IconName("stethoscope-off")
    STICKER: IconName = IconName("sticker")
    STORM: IconName = IconName("storm")
    STORM_OFF: IconName = IconName("storm-off")
    STRETCHING: IconName = IconName("stretching")
    STRETCHING_2: IconName = IconName("stretching-2")
    STRIKETHROUGH: IconName = IconName("strikethrough")
    SUBMARINE: IconName = IconName("submarine")
    SUBSCRIPT: IconName = IconName("subscript")
    SUBTASK: IconName = IconName("subtask")
    SUM: IconName = IconName("sum")
    SUM_OFF: IconName = IconName("sum-off")
    SUN: IconName = IconName("sun")
    SUN_FILLED: IconName = IconName("sun-filled")
    SUN_HIGH: IconName = IconName("sun-high")
    SUN_LOW: IconName = IconName("sun-low")
    SUN_MOON: IconName = IconName("sun-moon")
    SUN_OFF: IconName = IconName("sun-off")
    SUN_WIND: IconName = IconName("sun-wind")
    SUNGLASSES: IconName = IconName("sunglasses")
    SUNRISE: IconName = IconName("sunrise")
    SUNSET: IconName = IconName("sunset")
    SUNSET_2: IconName = IconName("sunset-2")
    SUPERSCRIPT: IconName = IconName("superscript")
    SVG: IconName = IconName("svg")
    SWIMMING: IconName = IconName("swimming")
    SWIPE: IconName = IconName("swipe")
    SWITCH: IconName = IconName("switch")
    SWITCH_2: IconName = IconName("switch-2")
    SWITCH_3: IconName = IconName("switch-3")
    SWITCH_HORIZONTAL: IconName = IconName("switch-horizontal")
    SWITCH_VERTICAL: IconName = IconName("switch-vertical")
    SWORD: IconName = IconName("sword")
    SWORD_OFF: IconName = IconName("sword-off")
    SWORDS: IconName = IconName("swords")
    TABLE: IconName = IconName("table")
    TABLE_ALIAS: IconName = IconName("table-alias")
    TABLE_COLUMN: IconName = IconName("table-column")
    TABLE_DOWN: IconName = IconName("table-down")
    TABLE_EXPORT: IconName = IconName("table-export")
    TABLE_FILLED: IconName = IconName("table-filled")
    TABLE_HEART: IconName = IconName("table-heart")
    TABLE_IMPORT: IconName = IconName("table-import")
    TABLE_MINUS: IconName = IconName("table-minus")
    TABLE_OFF: IconName = IconName("table-off")
    TABLE_OPTIONS: IconName = IconName("table-options")
    TABLE_PLUS: IconName = IconName("table-plus")
    TABLE_ROW: IconName = IconName("table-row")
    TABLE_SHARE: IconName = IconName("table-share")
    TABLE_SHORTCUT: IconName = IconName("table-shortcut")
    TAG: IconName = IconName("tag")
    TAG_OFF: IconName = IconName("tag-off")
    TAGS: IconName = IconName("tags")
    TAGS_OFF: IconName = IconName("tags-off")
    TALLYMARK_1: IconName = IconName("tallymark-1")
    TALLYMARK_2: IconName = IconName("tallymark-2")
    TALLYMARK_3: IconName = IconName("tallymark-3")
    TALLYMARK_4: IconName = IconName("tallymark-4")
    TALLYMARKS: IconName = IconName("tallymarks")
    TANK: IconName = IconName("tank")
    TARGET: IconName = IconName("target")
    TARGET_ARROW: IconName = IconName("target-arrow")
    TARGET_OFF: IconName = IconName("target-off")
    TEAPOT: IconName = IconName("teapot")
    TELESCOPE: IconName = IconName("telescope")
    TELESCOPE_OFF: IconName = IconName("telescope-off")
    TEMPERATURE: IconName = IconName("temperature")
    TEMPERATURE_CELSIUS: IconName = IconName("temperature-celsius")
    TEMPERATURE_FAHRENHEIT: IconName = IconName("temperature-fahrenheit")
    TEMPERATURE_MINUS: IconName = IconName("temperature-minus")
    TEMPERATURE_OFF: IconName = IconName("temperature-off")
    TEMPERATURE_PLUS: IconName = IconName("temperature-plus")
    TEMPLATE: IconName = IconName("template")
    TEMPLATE_OFF: IconName = IconName("template-off")
    TENT: IconName = IconName("tent")
    TENT_OFF: IconName = IconName("tent-off")
    TERMINAL: IconName = IconName("terminal")
    TERMINAL_2: IconName = IconName("terminal-2")
    TEST_PIPE: IconName = IconName("test-pipe")
    TEST_PIPE_2: IconName = IconName("test-pipe-2")
    TEST_PIPE_OFF: IconName = IconName("test-pipe-off")
    TEX: IconName = IconName("tex")
    TEXT_CAPTION: IconName = IconName("text-caption")
    TEXT_COLOR: IconName = IconName("text-color")
    TEXT_DECREASE: IconName = IconName("text-decrease")
    TEXT_DIRECTION_LTR: IconName = IconName("text-direction-ltr")
    TEXT_DIRECTION_RTL: IconName = IconName("text-direction-rtl")
    TEXT_INCREASE: IconName = IconName("text-increase")
    TEXT_ORIENTATION: IconName = IconName("text-orientation")
    TEXT_PLUS: IconName = IconName("text-plus")
    TEXT_RECOGNITION: IconName = IconName("text-recognition")
    TEXT_RESIZE: IconName = IconName("text-resize")
    TEXT_SIZE: IconName = IconName("text-size")
    TEXT_SPELLCHECK: IconName = IconName("text-spellcheck")
    TEXT_WRAP: IconName = IconName("text-wrap")
    TEXT_WRAP_DISABLED: IconName = IconName("text-wrap-disabled")
    TEXTURE: IconName = IconName("texture")
    THEATER: IconName = IconName("theater")
    THERMOMETER: IconName = IconName("thermometer")
    THUMB_DOWN: IconName = IconName("thumb-down")
    THUMB_DOWN_FILLED: IconName = IconName("thumb-down-filled")
    THUMB_DOWN_OFF: IconName = IconName("thumb-down-off")
    THUMB_UP: IconName = IconName("thumb-up")
    THUMB_UP_FILLED: IconName = IconName("thumb-up-filled")
    THUMB_UP_OFF: IconName = IconName("thumb-up-off")
    TIC_TAC: IconName = IconName("tic-tac")
    TICKET: IconName = IconName("ticket")
    TICKET_OFF: IconName = IconName("ticket-off")
    TIE: IconName = IconName("tie")
    TILDE: IconName = IconName("tilde")
    TILT_SHIFT: IconName = IconName("tilt-shift")
    TILT_SHIFT_OFF: IconName = IconName("tilt-shift-off")
    TIME_DURATION_0: IconName = IconName("time-duration-0")
    TIME_DURATION_10: IconName = IconName("time-duration-10")
    TIME_DURATION_15: IconName = IconName("time-duration-15")
    TIME_DURATION_30: IconName = IconName("time-duration-30")
    TIME_DURATION_45: IconName = IconName("time-duration-45")
    TIME_DURATION_5: IconName = IconName("time-duration-5")
    TIME_DURATION_60: IconName = IconName("time-duration-60")
    TIME_DURATION_90: IconName = IconName("time-duration-90")
    TIME_DURATION_OFF: IconName = IconName("time-duration-off")
    TIMELINE: IconName = IconName("timeline")
    TIMELINE_EVENT: IconName = IconName("timeline-event")
    TIMELINE_EVENT_EXCLAMATION: IconName = IconName("timeline-event-exclamation")
    TIMELINE_EVENT_MINUS: IconName = IconName("timeline-event-minus")
    TIMELINE_EVENT_PLUS: IconName = IconName("timeline-event-plus")
    TIMELINE_EVENT_TEXT: IconName = IconName("timeline-event-text")
    TIMELINE_EVENT_X: IconName = IconName("timeline-event-x")
    TIR: IconName = IconName("tir")
    TOGGLE_LEFT: IconName = IconName("toggle-left")
    TOGGLE_RIGHT: IconName = IconName("toggle-right")
    TOILET_PAPER: IconName = IconName("toilet-paper")
    TOILET_PAPER_OFF: IconName = IconName("toilet-paper-off")
    TOML: IconName = IconName("toml")
    TOOL: IconName = IconName("tool")
    TOOLS: IconName = IconName("tools")
    TOOLS_KITCHEN: IconName = IconName("tools-kitchen")
    TOOLS_KITCHEN_2: IconName = IconName("tools-kitchen-2")
    TOOLS_KITCHEN_2_OFF: IconName = IconName("tools-kitchen-2-off")
    TOOLS_KITCHEN_OFF: IconName = IconName("tools-kitchen-off")
    TOOLS_OFF: IconName = IconName("tools-off")
    TOOLTIP: IconName = IconName("tooltip")
    TOPOLOGY_BUS: IconName = IconName("topology-bus")
    TOPOLOGY_COMPLEX: IconName = IconName("topology-complex")
    TOPOLOGY_FULL: IconName = IconName("topology-full")
    TOPOLOGY_FULL_HIERARCHY: IconName = IconName("topology-full-hierarchy")
    TOPOLOGY_RING: IconName = IconName("topology-ring")
    TOPOLOGY_RING_2: IconName = IconName("topology-ring-2")
    TOPOLOGY_RING_3: IconName = IconName("topology-ring-3")
    TOPOLOGY_STAR: IconName = IconName("topology-star")
    TOPOLOGY_STAR_2: IconName = IconName("topology-star-2")
    TOPOLOGY_STAR_3: IconName = IconName("topology-star-3")
    TOPOLOGY_STAR_RING: IconName = IconName("topology-star-ring")
    TOPOLOGY_STAR_RING_2: IconName = IconName("topology-star-ring-2")
    TOPOLOGY_STAR_RING_3: IconName = IconName("topology-star-ring-3")
    TORII: IconName = IconName("torii")
    TORNADO: IconName = IconName("tornado")
    TOURNAMENT: IconName = IconName("tournament")
    TOWER: IconName = IconName("tower")
    TOWER_OFF: IconName = IconName("tower-off")
    TRACK: IconName = IconName("track")
    TRACTOR: IconName = IconName("tractor")
    TRADEMARK: IconName = IconName("trademark")
    TRAFFIC_CONE: IconName = IconName("traffic-cone")
    TRAFFIC_CONE_OFF: IconName = IconName("traffic-cone-off")
    TRAFFIC_LIGHTS: IconName = IconName("traffic-lights")
    TRAFFIC_LIGHTS_OFF: IconName = IconName("traffic-lights-off")
    TRAIN: IconName = IconName("train")
    TRANSFER_IN: IconName = IconName("transfer-in")
    TRANSFER_OUT: IconName = IconName("transfer-out")
    TRANSFORM: IconName = IconName("transform")
    TRANSFORM_FILLED: IconName = IconName("transform-filled")
    TRANSITION_BOTTOM: IconName = IconName("transition-bottom")
    TRANSITION_LEFT: IconName = IconName("transition-left")
    TRANSITION_RIGHT: IconName = IconName("transition-right")
    TRANSITION_TOP: IconName = IconName("transition-top")
    TRASH: IconName = IconName("trash")
    TRASH_FILLED: IconName = IconName("trash-filled")
    TRASH_OFF: IconName = IconName("trash-off")
    TRASH_X: IconName = IconName("trash-x")
    TRASH_X_FILLED: IconName = IconName("trash-x-filled")
    TREADMILL: IconName = IconName("treadmill")
    TREE: IconName = IconName("tree")
    TREES: IconName = IconName("trees")
    TREKKING: IconName = IconName("trekking")
    TRENDING_DOWN: IconName = IconName("trending-down")
    TRENDING_DOWN_2: IconName = IconName("trending-down-2")
    TRENDING_DOWN_3: IconName = IconName("trending-down-3")
    TRENDING_UP: IconName = IconName("trending-up")
    TRENDING_UP_2: IconName = IconName("trending-up-2")
    TRENDING_UP_3: IconName = IconName("trending-up-3")
    TRIANGLE: IconName = IconName("triangle")
    TRIANGLE_FILLED: IconName = IconName("triangle-filled")
    TRIANGLE_INVERTED: IconName = IconName("triangle-inverted")
    TRIANGLE_INVERTED_FILLED: IconName = IconName("triangle-inverted-filled")
    TRIANGLE_OFF: IconName = IconName("triangle-off")
    TRIANGLE_SQUARE_CIRCLE: IconName = IconName("triangle-square-circle")
    TRIANGLES: IconName = IconName("triangles")
    TRIDENT: IconName = IconName("trident")
    TROLLEY: IconName = IconName("trolley")
    TROPHY: IconName = IconName("trophy")
    TROPHY_FILLED: IconName = IconName("trophy-filled")
    TROPHY_OFF: IconName = IconName("trophy-off")
    TROWEL: IconName = IconName("trowel")
    TRUCK: IconName = IconName("truck")
    TRUCK_DELIVERY: IconName = IconName("truck-delivery")
    TRUCK_LOADING: IconName = IconName("truck-loading")
    TRUCK_OFF: IconName = IconName("truck-off")
    TRUCK_RETURN: IconName = IconName("truck-return")
    TXT: IconName = IconName("txt")
    TYPOGRAPHY: IconName = IconName("typography")
    TYPOGRAPHY_OFF: IconName = IconName("typography-off")
    UFO: IconName = IconName("ufo")
    UFO_OFF: IconName = IconName("ufo-off")
    UMBRELLA: IconName = IconName("umbrella")
    UMBRELLA_FILLED: IconName = IconName("umbrella-filled")
    UMBRELLA_OFF: IconName = IconName("umbrella-off")
    UNDERLINE: IconName = IconName("underline")
    UNLINK: IconName = IconName("unlink")
    UPLOAD: IconName = IconName("upload")
    URGENT: IconName = IconName("urgent")
    USB: IconName = IconName("usb")
    USER: IconName = IconName("user")
    USER_BOLT: IconName = IconName("user-bolt")
    USER_CANCEL: IconName = IconName("user-cancel")
    USER_CHECK: IconName = IconName("user-check")
    USER_CIRCLE: IconName = IconName("user-circle")
    USER_CODE: IconName = IconName("user-code")
    USER_COG: IconName = IconName("user-cog")
    USER_DOLLAR: IconName = IconName("user-dollar")
    USER_DOWN: IconName = IconName("user-down")
    USER_EDIT: IconName = IconName("user-edit")
    USER_EXCLAMATION: IconName = IconName("user-exclamation")
    USER_HEART: IconName = IconName("user-heart")
    USER_MINUS: IconName = IconName("user-minus")
    USER_OFF: IconName = IconName("user-off")
    USER_PAUSE: IconName = IconName("user-pause")
    USER_PIN: IconName = IconName("user-pin")
    USER_PLUS: IconName = IconName("user-plus")
    USER_QUESTION: IconName = IconName("user-question")
    USER_SEARCH: IconName = IconName("user-search")
    USER_SHARE: IconName = IconName("user-share")
    USER_SHIELD: IconName = IconName("user-shield")
    USER_STAR: IconName = IconName("user-star")
    USER_UP: IconName = IconName("user-up")
    USER_X: IconName = IconName("user-x")
    USERS: IconName = IconName("users")
    USERS_GROUP: IconName = IconName("users-group")
    USERS_MINUS: IconName = IconName("users-minus")
    USERS_PLUS: IconName = IconName("users-plus")
    UV_INDEX: IconName = IconName("uv-index")
    UX_CIRCLE: IconName = IconName("ux-circle")
    VACCINE: IconName = IconName("vaccine")
    VACCINE_BOTTLE: IconName = IconName("vaccine-bottle")
    VACCINE_BOTTLE_OFF: IconName = IconName("vaccine-bottle-off")
    VACCINE_OFF: IconName = IconName("vaccine-off")
    VACUUM_CLEANER: IconName = IconName("vacuum-cleaner")
    VARIABLE: IconName = IconName("variable")
    VARIABLE_MINUS: IconName = IconName("variable-minus")
    VARIABLE_OFF: IconName = IconName("variable-off")
    VARIABLE_PLUS: IconName = IconName("variable-plus")
    VECTOR: IconName = IconName("vector")
    VECTOR_BEZIER: IconName = IconName("vector-bezier")
    VECTOR_BEZIER_2: IconName = IconName("vector-bezier-2")
    VECTOR_BEZIER_ARC: IconName = IconName("vector-bezier-arc")
    VECTOR_BEZIER_CIRCLE: IconName = IconName("vector-bezier-circle")
    VECTOR_OFF: IconName = IconName("vector-off")
    VECTOR_SPLINE: IconName = IconName("vector-spline")
    VECTOR_TRIANGLE: IconName = IconName("vector-triangle")
    VECTOR_TRIANGLE_OFF: IconName = IconName("vector-triangle-off")
    VENUS: IconName = IconName("venus")
    VERSIONS: IconName = IconName("versions")
    VERSIONS_FILLED: IconName = IconName("versions-filled")
    VERSIONS_OFF: IconName = IconName("versions-off")
    VIDEO: IconName = IconName("video")
    VIDEO_MINUS: IconName = IconName("video-minus")
    VIDEO_OFF: IconName = IconName("video-off")
    VIDEO_PLUS: IconName = IconName("video-plus")
    VIEW_360: IconName = IconName("view-360")
    VIEW_360_OFF: IconName = IconName("view-360-off")
    VIEWFINDER: IconName = IconName("viewfinder")
    VIEWFINDER_OFF: IconName = IconName("viewfinder-off")
    VIEWPORT_NARROW: IconName = IconName("viewport-narrow")
    VIEWPORT_WIDE: IconName = IconName("viewport-wide")
    VINYL: IconName = IconName("vinyl")
    VIP: IconName = IconName("vip")
    VIP_OFF: IconName = IconName("vip-off")
    VIRUS: IconName = IconName("virus")
    VIRUS_OFF: IconName = IconName("virus-off")
    VIRUS_SEARCH: IconName = IconName("virus-search")
    VOCABULARY: IconName = IconName("vocabulary")
    VOCABULARY_OFF: IconName = IconName("vocabulary-off")
    VOLCANO: IconName = IconName("volcano")
    VOLUME: IconName = IconName("volume")
    VOLUME_2: IconName = IconName("volume-2")
    VOLUME_3: IconName = IconName("volume-3")
    VOLUME_OFF: IconName = IconName("volume-off")
    WALK: IconName = IconName("walk")
    WALL: IconName = IconName("wall")
    WALL_OFF: IconName = IconName("wall-off")
    WALLET: IconName = IconName("wallet")
    WALLET_OFF: IconName = IconName("wallet-off")
    WALLPAPER: IconName = IconName("wallpaper")
    WALLPAPER_OFF: IconName = IconName("wallpaper-off")
    WAND: IconName = IconName("wand")
    WAND_OFF: IconName = IconName("wand-off")
    WASH: IconName = IconName("wash")
    WASH_DRY: IconName = IconName("wash-dry")
    WASH_DRY_1: IconName = IconName("wash-dry-1")
    WASH_DRY_2: IconName = IconName("wash-dry-2")
    WASH_DRY_3: IconName = IconName("wash-dry-3")
    WASH_DRY_A: IconName = IconName("wash-dry-a")
    WASH_DRY_DIP: IconName = IconName("wash-dry-dip")
    WASH_DRY_F: IconName = IconName("wash-dry-f")
    WASH_DRY_FLAT: IconName = IconName("wash-dry-flat")
    WASH_DRY_HANG: IconName = IconName("wash-dry-hang")
    WASH_DRY_OFF: IconName = IconName("wash-dry-off")
    WASH_DRY_P: IconName = IconName("wash-dry-p")
    WASH_DRY_SHADE: IconName = IconName("wash-dry-shade")
    WASH_DRY_W: IconName = IconName("wash-dry-w")
    WASH_DRYCLEAN: IconName = IconName("wash-dryclean")
    WASH_DRYCLEAN_OFF: IconName = IconName("wash-dryclean-off")
    WASH_ECO: IconName = IconName("wash-eco")
    WASH_GENTLE: IconName = IconName("wash-gentle")
    WASH_HAND: IconName = IconName("wash-hand")
    WASH_MACHINE: IconName = IconName("wash-machine")
    WASH_OFF: IconName = IconName("wash-off")
    WASH_PRESS: IconName = IconName("wash-press")
    WASH_TEMPERATURE_1: IconName = IconName("wash-temperature-1")
    WASH_TEMPERATURE_2: IconName = IconName("wash-temperature-2")
    WASH_TEMPERATURE_3: IconName = IconName("wash-temperature-3")
    WASH_TEMPERATURE_4: IconName = IconName("wash-temperature-4")
    WASH_TEMPERATURE_5: IconName = IconName("wash-temperature-5")
    WASH_TEMPERATURE_6: IconName = IconName("wash-temperature-6")
    WASH_TUMBLE_DRY: IconName = IconName("wash-tumble-dry")
    WASH_TUMBLE_OFF: IconName = IconName("wash-tumble-off")
    WATERPOLO: IconName = IconName("waterpolo")
    WAVE_SAW_TOOL: IconName = IconName("wave-saw-tool")
    WAVE_SINE: IconName = IconName("wave-sine")
    WAVE_SQUARE: IconName = IconName("wave-square")
    WEBHOOK: IconName = IconName("webhook")
    WEBHOOK_OFF: IconName = IconName("webhook-off")
    WEIGHT: IconName = IconName("weight")
    WHEELCHAIR: IconName = IconName("wheelchair")
    WHEELCHAIR_OFF: IconName = IconName("wheelchair-off")
    WHIRL: IconName = IconName("whirl")
    WIFI: IconName = IconName("wifi")
    WIFI_0: IconName = IconName("wifi-0")
    WIFI_1: IconName = IconName("wifi-1")
    WIFI_2: IconName = IconName("wifi-2")
    WIFI_OFF: IconName = IconName("wifi-off")
    WIND: IconName = IconName("wind")
    WIND_OFF: IconName = IconName("wind-off")
    WINDMILL: IconName = IconName("windmill")
    WINDMILL_FILLED: IconName = IconName("windmill-filled")
    WINDMILL_OFF: IconName = IconName("windmill-off")
    WINDOW: IconName = IconName("window")
    WINDOW_MAXIMIZE: IconName = IconName("window-maximize")
    WINDOW_MINIMIZE: IconName = IconName("window-minimize")
    WINDOW_OFF: IconName = IconName("window-off")
    WINDSOCK: IconName = IconName("windsock")
    WIPER: IconName = IconName("wiper")
    WIPER_WASH: IconName = IconName("wiper-wash")
    WOMAN: IconName = IconName("woman")
    WOOD: IconName = IconName("wood")
    WORLD: IconName = IconName("world")
    WORLD_BOLT: IconName = IconName("world-bolt")
    WORLD_CANCEL: IconName = IconName("world-cancel")
    WORLD_CHECK: IconName = IconName("world-check")
    WORLD_CODE: IconName = IconName("world-code")
    WORLD_COG: IconName = IconName("world-cog")
    WORLD_DOLLAR: IconName = IconName("world-dollar")
    WORLD_DOWN: IconName = IconName("world-down")
    WORLD_DOWNLOAD: IconName = IconName("world-download")
    WORLD_EXCLAMATION: IconName = IconName("world-exclamation")
    WORLD_HEART: IconName = IconName("world-heart")
    WORLD_LATITUDE: IconName = IconName("world-latitude")
    WORLD_LONGITUDE: IconName = IconName("world-longitude")
    WORLD_MINUS: IconName = IconName("world-minus")
    WORLD_OFF: IconName = IconName("world-off")
    WORLD_PAUSE: IconName = IconName("world-pause")
    WORLD_PIN: IconName = IconName("world-pin")
    WORLD_PLUS: IconName = IconName("world-plus")
    WORLD_QUESTION: IconName = IconName("world-question")
    WORLD_SEARCH: IconName = IconName("world-search")
    WORLD_SHARE: IconName = IconName("world-share")
    WORLD_STAR: IconName = IconName("world-star")
    WORLD_UP: IconName = IconName("world-up")
    WORLD_UPLOAD: IconName = IconName("world-upload")
    WORLD_WWW: IconName = IconName("world-www")
    WORLD_X: IconName = IconName("world-x")
    WRECKING_BALL: IconName = IconName("wrecking-ball")
    WRITING: IconName = IconName("writing")
    WRITING_OFF: IconName = IconName("writing-off")
    WRITING_SIGN: IconName = IconName("writing-sign")
    WRITING_SIGN_OFF: IconName = IconName("writing-sign-off")
    X: IconName = IconName("x")
    XBOX_A: IconName = IconName("xbox-a")
    XBOX_B: IconName = IconName("xbox-b")
    XBOX_X: IconName = IconName("xbox-x")
    XBOX_Y: IconName = IconName("xbox-y")
    XD: IconName = IconName("xd")
    YIN_YANG: IconName = IconName("yin-yang")
    YIN_YANG_FILLED: IconName = IconName("yin-yang-filled")
    YOGA: IconName = IconName("yoga")
    ZEPPELIN: IconName = IconName("zeppelin")
    ZEPPELIN_OFF: IconName = IconName("zeppelin-off")
    ZIP: IconName = IconName("zip")
    ZODIAC_AQUARIUS: IconName = IconName("zodiac-aquarius")
    ZODIAC_ARIES: IconName = IconName("zodiac-aries")
    ZODIAC_CANCER: IconName = IconName("zodiac-cancer")
    ZODIAC_CAPRICORN: IconName = IconName("zodiac-capricorn")
    ZODIAC_GEMINI: IconName = IconName("zodiac-gemini")
    ZODIAC_LEO: IconName = IconName("zodiac-leo")
    ZODIAC_LIBRA: IconName = IconName("zodiac-libra")
    ZODIAC_PISCES: IconName = IconName("zodiac-pisces")
    ZODIAC_SAGITTARIUS: IconName = IconName("zodiac-sagittarius")
    ZODIAC_SCORPIO: IconName = IconName("zodiac-scorpio")
    ZODIAC_TAURUS: IconName = IconName("zodiac-taurus")
    ZODIAC_VIRGO: IconName = IconName("zodiac-virgo")
    ZOOM_CANCEL: IconName = IconName("zoom-cancel")
    ZOOM_CHECK: IconName = IconName("zoom-check")
    ZOOM_CHECK_FILLED: IconName = IconName("zoom-check-filled")
    ZOOM_CODE: IconName = IconName("zoom-code")
    ZOOM_EXCLAMATION: IconName = IconName("zoom-exclamation")
    ZOOM_FILLED: IconName = IconName("zoom-filled")
    ZOOM_IN: IconName = IconName("zoom-in")
    ZOOM_IN_AREA: IconName = IconName("zoom-in-area")
    ZOOM_IN_AREA_FILLED: IconName = IconName("zoom-in-area-filled")
    ZOOM_IN_FILLED: IconName = IconName("zoom-in-filled")
    ZOOM_MONEY: IconName = IconName("zoom-money")
    ZOOM_OUT: IconName = IconName("zoom-out")
    ZOOM_OUT_AREA: IconName = IconName("zoom-out-area")
    ZOOM_OUT_FILLED: IconName = IconName("zoom-out-filled")
    ZOOM_PAN: IconName = IconName("zoom-pan")
    ZOOM_QUESTION: IconName = IconName("zoom-question")
    ZOOM_REPLACE: IconName = IconName("zoom-replace")
    ZOOM_RESET: IconName = IconName("zoom-reset")
    ZZZ: IconName = IconName("zzz")
    ZZZ_OFF: IconName = IconName("zzz-off")
